@@ -3,12 +3,20 @@
 #include <X11/Xutil.h>
 #include <X11/cursorfont.h>
 
-#if defined (apollo) || defined (__FreeBSD__)
-#include <stdlib.h>
+#if STDC_HEADERS
+#  include <stdlib.h>
 #else
-#include <malloc.h>
+#  if HAVE_MALLOC_H
+#    include <malloc.h>
+#  endif
 #endif
+
+#if HAVE_STRING_H
 #include <string.h>
+#else
+#include <strings.h>
+#endif
+
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/param.h>
@@ -31,6 +39,10 @@
  
 extern Browser br;
 
+#if !HAVE_STRDUP
+extern FCT (char*, strdup, (char*) );
+#endif
+
 /*-------------------------------------------------------------------------
 */
 static ScopeType compute_scope(infos)
@@ -284,16 +296,14 @@ void browser_add(s, rec)
     extern char  *getcwd();
     
     br.parse_flag = (rec) ? RECURSIVE : NO_RECURSIVE;
-/*    
-#ifdef linux
+#if HAVE_GETCWD
+    (void) getcwd ( pathname, MAXPATHLEN );
+#else
     if ( getwd ( pathname ) == 0 ) {
       (void) fprintf ( stderr, "Can't getwd\n" );
       return;
     }
-#else	
-*/
-    (void) getcwd ( pathname, MAXPATHLEN );
-/* #endif */
+#endif
     here = (char *) malloc(strlen(pathname) + 1);
     if (! here) return;
     (void) strcpy (here, pathname);
@@ -301,18 +311,16 @@ void browser_add(s, rec)
     (void) stat ( s, &st );
     if ( S_ISDIR(st.st_mode) != 0 ) {
       (void) chdir(s);
-/*      
-#ifdef linux
+#if HAVE_GETCWD
+      (void) getcwd ( pathname, MAXPATHLEN );
+#else
       if ( getwd ( pathname ) == 0 ) {
 	(void) fprintf ( stderr, "Can't getwd\n" );
 	(void) chdir(here);
 	free(here);
 	return;
       }
-#else	
-*/
-      (void) getcwd ( pathname, MAXPATHLEN );
-/* #endif */
+#endif
       LoadDir ( pathname );
     }
     else if (S_ISREG(st.st_mode) && GoodSuffix (s)) {
@@ -323,9 +331,16 @@ void browser_add(s, rec)
       else if (p == pathname)
 	sprintf(pathname, "/%s", s);
       else {
+	char c = *p;
+	
 	*p = 0;
 	(void) chdir(s);
-	sprintf(pathname + strlen(pathname), "/%s", p+1);
+	*p = c;
+	
+	if (*s == '/')
+	  strcpy(pathname, s);
+	else
+	  sprintf(pathname + strlen(pathname), "/%s", p+1);
       }
       parse_file (pathname); 
     }
@@ -378,7 +393,9 @@ static int browser_select_x(prefix, t, w_x, x_plength)
     
     while (*t != 0) {
       if (! HIDED(*t)) {
-	if (! strncmp(prefix, *t, plen)) {
+	int d = strncmp(prefix, *t, plen);
+	
+	if (d == 0) {
 	  BWin *b_x = &br.tbw[w_x];
 	  
 	  UpdateTitle (*t - x_plength);
@@ -389,8 +406,10 @@ static int browser_select_x(prefix, t, w_x, x_plength)
 	  UpdateTextItem ( b_x -> text, b_x -> select );
 	  SelectItem ( b_x, 5, 5, w_x );
 	  
-	  return 1;
+	  return strlen(*t);
 	}
+	if (d < 0)
+	  return 0;
 	i += 1;
       }
       t += 1;
@@ -435,13 +454,19 @@ static int browser_x_entry(prefix, save)
     char * prefix;
     char ** save;
 {
-  unsigned plen = strlen(prefix);
-  unsigned rang = 0;
+  if (save) {
+    unsigned plen = strlen(prefix);
+    char ** p;
  
-  if (save)
-    for (rang = 0; *save; save += 1, rang += 1)
-      if (! strncmp(*save, prefix, plen))
-	return rang;
+    for (p = save; *p; p += 1) {
+      int d = strncmp(*p, prefix, plen);
+      
+      if (d == 0)
+	return p - save;
+      if (d > 0)
+	return -1;
+    }
+  }
   
   return -1;
 }
