@@ -988,7 +988,7 @@ static Object builtin_strtok(a)
      Instruction ** a;
 {
   static char * memo = 0;
-  static removedchar = 0;
+  static char removedchar = 0;
   char * s1 = (char *) Eval(a[0]);
   char * s2 = (char *) Eval(a[1]);
   char * p, c;
@@ -1188,8 +1188,8 @@ static Object builtin_load_file(a)
   int previous_yyinflag = yyinflag;
   int previous_numlig = numlig;
   char * previous_yyinfilename = yyinfilename;
-  char *smaclib = 0;
 #ifdef XCORAL_LIB_DIR
+  char *smaclib = 0;
   char * xcoral_lib = 0;
 #endif
   yyinfilename = (char *) Eval(*a);
@@ -1233,21 +1233,22 @@ static Object builtin_load_file(a)
   yyinflag = 1;
   numlig = 0;
   {
-    jmp_buf save_env;
-
-    COPY_ENV(save_env, come_back);
+    jmp_buf * spcome_back = pCome_Back;
+    jmp_buf come_back;
+    
     switch (setjmp(come_back)) {
     case NO_JMP:
+      pCome_Back = &come_back;
       load_file();
       break;
     case JMP_ERROR:
       /* Erreur d'execution */
       fclose(yyin);
       yyin = previous_yyin;
-      COPY_ENV(come_back, save_env);
-      longjmp(come_back, JMP_ERROR);
+      pCome_Back = spcome_back;
+      longjmp(*spcome_back, JMP_ERROR);
     }
-    COPY_ENV(come_back, save_env);
+    pCome_Back = spcome_back;
   }
 #ifdef XCORAL_LIB_DIR
   if (xcoral_lib) free(xcoral_lib);
@@ -1513,9 +1514,9 @@ static Object builtin_function_list(ignore)
 {
   if (! fi_end)
     while (HashTable_Iter(IdentifierHashTable, &fi_item, &fi_entry), fi_item) {
-      Function * f;
+      Function * f = Identifier__FunctionDef((Identifier *) HashItem__Data(fi_item));
       
-      if (f = Identifier__FunctionDef((Identifier *) HashItem__Data(fi_item)))
+      if (f != 0)
 	return (Object) f;
     }
   
