@@ -59,6 +59,7 @@ struct Function {
   Type * _valtype;
   Object * _masks;
   int _profile_count;
+  int _without_unterminal_return;
 };
 typedef struct Function Function;
 
@@ -73,6 +74,7 @@ extern FCT (Function *, Function__Function,
 #define Function__IsBuiltin(f)		(! (f)->_masks)
 #define Function__BuiltinDef(f)		((f)->_def._builtin_def)
 #define Function__UserDef(f)		((f)->_def._user_def)
+#define Function__WithoutUnterminalReturn(f)	((f)->_without_unterminal_return)
 
 extern FCT(void, Function__UpdateDef,(Function * this, Instruction *));
 extern FCT(void, Function__VerifyNotActive,(Function * this));
