@@ -39,7 +39,12 @@
 
 
 #include <stdio.h>
+
+#if HAVE_STRING_H
 #include <string.h>
+#else
+#include <strings.h>
+#endif
 
 #include "FunctionCall.h"
 #include "funcall.h"
@@ -99,24 +104,31 @@ static Object funcall_user_function(currentarg, narg, function)
 
   {
     memo_functions_called previous_function_called;
-    jmp_buf save_env;
 
     previous_function_called.previous = Last_Function_Called;
     previous_function_called.last_function_called = (Object) function;
     Last_Function_Called = &previous_function_called;
-      
-    COPY_ENV(save_env, current_env);
     
-    switch (setjmp(current_env)) {
-    case NO_JMP :
+    if (Function__WithoutUnterminalReturn(function))
       Eval(Function__UserDef(function));
-      break;
-    case JMP_ERROR :
-      longjmp(save_env, JMP_ERROR);
+    else {
+      jmp_buf * spcurrent_env = pCurrent_Env;
+      jmp_buf current_env;
+          
+      switch (setjmp(current_env)) {
+      case NO_JMP :
+	pCurrent_Env = &current_env;
+      	Eval(Function__UserDef(function));
+	break;
+      case JMP_ERROR :
+	pCurrent_Env = spcurrent_env;
+	longjmp(*spcurrent_env, JMP_ERROR);
+      }
+      
+      pCurrent_Env = spcurrent_env;
     }
-
+    
     Last_Function_Called = previous_function_called.previous;
-    COPY_ENV(current_env, save_env);
   }
   
   Stack_Pointer = Frame_Pointer;
@@ -162,24 +174,25 @@ void call_user_function_from_xcoral(function, narg, args)
     
     {
       memo_functions_called previous_function_called;
-      jmp_buf save_env;
+      jmp_buf * spcurrent_env = pCurrent_Env;
+      jmp_buf current_env;
       
       previous_function_called.previous = Last_Function_Called;
       previous_function_called.last_function_called = (Object) function;
       Last_Function_Called = &previous_function_called;
       
-      COPY_ENV(save_env, current_env);
-      
       switch (setjmp(current_env)) {
       case NO_JMP :
-	Eval(Function__UserDef(function));
+	pCurrent_Env = &current_env;
+ 	Eval(Function__UserDef(function));
 	break;
       case JMP_ERROR :
-	longjmp(save_env, JMP_ERROR);
+	pCurrent_Env = spcurrent_env;
+	longjmp(*spcurrent_env, JMP_ERROR);
       }
       
       Last_Function_Called = previous_function_called.previous;
-      COPY_ENV(current_env, save_env);
+      pCurrent_Env = spcurrent_env;
     }
     
     Stack_Pointer = Frame_Pointer;
@@ -242,9 +255,6 @@ void call_builtin_function_of_xcoral(function, narg)
     return;
   }
       
-  Function_Name = 0;
-  Last_Function_Called = 0;
-      
   (*(Function__BuiltinDef(function)))((Instruction **) 0);
 }
 
