@@ -49,10 +49,11 @@ struct Return {
 
   Instruction * _value;
   FCT( Object,(* _convert),(Object));
+  int _terminal;
 };
 typedef struct Return Return;
 
-extern FCT( Return *,Return__Return,(Instruction * value)	);
+extern FCT( Return *,Return__Return,(Instruction * value, int term)	);
 
 extern void Init_Return();
 
