@@ -79,30 +79,32 @@ static Object While__Eval(this)
   if (body)
     if (this->_hasbreakcont) {
       Object * stackpointer = Stack_Pointer;
-      jmp_buf save_env;
+      JMP_TYPE jmptype;
+      jmp_buf * spcurrent_env = pCurrent_Env;
+      jmp_buf current_env;
       
-      COPY_ENV(save_env, current_env);
       while(Eval(test)) {
-	switch (setjmp(current_env)) {
+	switch (jmptype = (JMP_TYPE) setjmp(current_env)) {
 	case NO_JMP :
+	  pCurrent_Env = &current_env;
 	  Eval(body);
 	  break;
-	case JMP_RETURN:
-	  longjmp(save_env, JMP_RETURN);
 	case JMP_CONTINUE:
 	  Stack_Pointer = stackpointer;
 	  goto etiq_cont;
 	case JMP_BREAK:
 	  Stack_Pointer = stackpointer;
 	  goto etiq_break;
-	case JMP_ERROR :
-	  longjmp(save_env, JMP_ERROR);
+	default:
+	  Stack_Pointer = stackpointer;
+	  pCurrent_Env = spcurrent_env;
+	  longjmp(*spcurrent_env, jmptype);
 	}
       etiq_cont: ;
-	COPY_ENV(current_env, save_env);	/* pour le test */
+	pCurrent_Env = spcurrent_env;	/* pour le test */
       }
     etiq_break:
-      COPY_ENV(current_env, save_env);
+      pCurrent_Env = spcurrent_env;
     }
     else
       while(Eval(test)) Eval(body);
@@ -149,30 +151,32 @@ static Object DoWhile__Eval(this)
   if (body)
     if (this->_hasbreakcont) {
       Object * stackpointer = Stack_Pointer;
-      jmp_buf save_env;
+      JMP_TYPE jmptype;
+      jmp_buf * spcurrent_env = pCurrent_Env;
+      jmp_buf current_env;
       
-      COPY_ENV(save_env, current_env);
       do {
-	switch (setjmp(current_env)) {
+	switch (jmptype = (JMP_TYPE) setjmp(current_env)) {
 	case NO_JMP :
+	  pCurrent_Env = &current_env;
 	  Eval(body);
 	  break;
-	case JMP_RETURN:
-	  longjmp(save_env, JMP_RETURN);
 	case JMP_CONTINUE:
 	  Stack_Pointer = stackpointer;
 	  goto etiq_cont;
 	case JMP_BREAK:
 	  Stack_Pointer = stackpointer;
 	  goto etiq_break;
-	case JMP_ERROR :
-	  longjmp(save_env, JMP_ERROR);
+	default:
+	  Stack_Pointer = stackpointer;
+	  pCurrent_Env = spcurrent_env;
+	  longjmp(*spcurrent_env, jmptype);
 	}
       etiq_cont: 
-	COPY_ENV(current_env, save_env);	/* pour le test */
+	pCurrent_Env = spcurrent_env;	/* pour le test */
       } while (Eval(test));
     etiq_break:
-      COPY_ENV(current_env, save_env);
+      pCurrent_Env = spcurrent_env;
     }
     else
       do Eval(body); while(Eval(test));
