@@ -63,7 +63,13 @@ char err_msg[MSG_SIZE];
 
 /* le contexte de retour */
 
-jmp_buf come_back;
+jmp_buf * pCome_Back;
+
+
+/* pour reperer les returns terminaux */
+
+int Is_Terminal;
+int Has_Unterminal_Return;
 
 
 /* Le mode debug */
@@ -133,11 +139,12 @@ void Error_Full_Stack()
   *err_msg = 0;
 #endif
   printf_function_called();
-  Reinit_Error();
-  longjmp(come_back, JMP_ERROR);
+  longjmp(*pCome_Back, JMP_ERROR);
 }
 
+#ifdef XCORAL
 static char mess[MSG_SIZE];
+#endif
 
 void Internal_Error(msg)
      char * msg;
@@ -151,8 +158,7 @@ void Internal_Error(msg)
   *err_msg = 0;
 #endif
   printf_function_called();
-  Reinit_Error();
-  longjmp(come_back, JMP_ERROR);
+  longjmp(*pCome_Back, JMP_ERROR);
 }
 
 void Error(msg)
@@ -167,8 +173,7 @@ void Error(msg)
   *err_msg = 0;
 #endif
   printf_function_called();
-  Reinit_Error();
-  longjmp(come_back, JMP_ERROR);
+  longjmp(*pCome_Back, JMP_ERROR);
 }
 
 void Fatal_Error(msg)
@@ -224,12 +229,3 @@ void accept_ctrl_c()
     error_ctrl_c(0);
   }
 }
-
-
-/**/
-
-void Reinit_Error()
-{
-  Function_Name = 0;
-  Last_Function_Called = 0;
-}
