@@ -104,6 +104,7 @@ Instruction * make_funcall(l)
 	      ? "at least " : "",
 	      Function__NbreArg(fct));
       Error(err_msg);
+      result = 0;	/* to not have warning */
     }
     else {
       int nargtheo = Function__NbreArg(fct);
@@ -159,6 +160,7 @@ Instruction * make_funcall(l)
       sprintf(err_msg, "%d arguments at least %d required",
 	      nbrearg, TypeFunction__NbreArg(tfct));
       Error(err_msg);
+      result = 0;	/* to not have warning */
     }
     else {
       int index;
@@ -183,8 +185,10 @@ Instruction * make_funcall(l)
 						       args, nbrearg);
     }
   }
-  else
+  else {
     Error("illegal function call");
+    result = 0;	/* to not have warning */
+  }
   
   free(l->info);
   free(l);
