@@ -235,11 +235,14 @@ void function_definition(valtype, funcname, params, body)
 
   Return_Value_Type = valtype;
   Function_Name = funcname;
+  Is_Terminal = 1;
+  Has_Unterminal_Return = 0;
   
   Function__UpdateDef(Identifier__FunctionDef(identifier), MAKE(body));
 
   Return_Value_Type = 0;
   Function_Name = 0;
+  Is_Terminal = 0;
 
   /* on oublie toutes les variables locales */
 
@@ -476,7 +479,7 @@ int make_typedef_oldfunction_def()
   do { params = params->previous; }
   while (params->fct == make_declaration);
   
-  if (params->previous->fct == (InstrFct) preserve_list)
+  if (params->previous->fct == preserve_list)
     if (! (params->previous->info &&
 	   ((List *) params->previous->info)->next &&
 	   (params = ((List *) params->previous->info)->next->next)))
