@@ -45,6 +45,6 @@
 #include "fctdecl.h"
 #include "list.h"
 
-extern FCT( Object, make_identifier,(List *)	);
+extern FCT( Instruction *, make_identifier,(List *)	);
 
 #endif
