@@ -40,10 +40,12 @@
 
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <pwd.h>
 
 #include "smac.h"
 #include "error.h"
+#include "stack.h"
 
 extern FILE * yyin;
 
@@ -100,13 +102,18 @@ void main()
   /* Lecture de stdin jusqu'a la fin de fichier */
 
   for (;;) {
+    jmp_buf come_back;
+    
     if (! (setjmp(come_back))) {
+      pCome_Back = &come_back;
       load_file();
       /* ya eu une erreur de lecture */
       if (*err_msg)
 	Error(err_msg);
     }
-    /* ya eu erreur */
     putchar('\n');
+    pCome_Back = 0;
+    Last_Function_Called = 0;
+    Stack_Empty(Var_Stack);
   }
 }
