@@ -288,7 +288,7 @@ void memo_switch()
     free(bloc);
   }
 
-  AddLast(Memo, List__List((InstrFct) make_switch, m));
+  AddLast(Memo, List__List(make_switch, m));
 }
 
 
@@ -308,7 +308,7 @@ void memo_switch()
 
 Object begin_of_list = (Object) "begin_of_list";
 
-void preserve_list() { /* sert juste de marque */ }
+Instruction * preserve_list(ignore) List * ignore; { /* sert juste de marque */ return 0; }
 
 void forget_list()
 {
@@ -345,7 +345,7 @@ void end_of_list()
   do { Memo = Memo->previous;} while (((Object) Memo->info) != begin_of_list);
 
   Memo->info = (void *) Memo->next;
-  Memo->fct = (InstrFct) preserve_list;
+  Memo->fct = preserve_list;
   Memo->next->previous = 0;
   Memo->next = 0;
 }
@@ -361,8 +361,8 @@ void end_of_list()
                     fct, info : fabrication d'un int ou d'un char sinon
 */
 
-void array_dims() { /* sert juste de marque */ }
-void array_dim() { /* sert juste de marque */ }
+Instruction * array_dims(ignore) List * ignore; { /* sert juste de marque */ return 0; }
+Instruction * array_dim(ignore) List * ignore; { /* sert juste de marque */  return 0; }
 
 void array_abstract_declarator()
 {
@@ -385,9 +385,9 @@ void array_abstract_declarator()
       Memo->fct = 0;
 
     Memo = Memo->previous;
-  } while (Memo->fct == ((InstrFct) array_dim));
+  } while (Memo->fct == array_dim);
 
-  l = List__List((InstrFct) array_dims, last);
+  l = List__List(array_dims, last);
   Memo->next->previous = 0;
   Memo->next = 0;
 
@@ -423,7 +423,7 @@ Type * the_typed_var(varname)
   List * ltype;
   
   while (Memo->fct != (InstrFct) make_typedef) {
-    if (Memo->fct == (InstrFct) make_identifier) {
+    if (Memo->fct == make_identifier) {
       List * var = Memo;
       *varname = (char *) var->info;
 
@@ -433,11 +433,11 @@ Type * the_typed_var(varname)
       free(var);
     }
     else {
-      if (Memo->fct == (InstrFct) preserve_list) {
+      if (Memo->fct == preserve_list) {
 	/* L'identifier est dedans */
 	List * l = (List *) Memo->info;
 	
-	while (l->fct != (InstrFct) make_identifier)
+	while (l->fct != make_identifier)
 	  l = l->next;
 	*varname = (char *) l->info;
 
@@ -511,7 +511,7 @@ void typed_param()
   info = List * 1er param-type, les suivants par next
 */
 
-void function_parameter_type_list() { /* juste une marque */ }
+Instruction * function_parameter_type_list(ignore) List * ignore; { /* juste une marque */ return 0; }
 
 /* Nouvelle syntaxe, contient des ignored/typed_params */
 
@@ -521,7 +521,7 @@ void end_function_parameter_type_list()
     Memo = Memo->previous;
 
   Memo->info = (void *) Memo->next;
-  Memo->fct = (InstrFct) function_parameter_type_list;
+  Memo->fct = function_parameter_type_list;
   Memo->next->previous = 0;
   Memo->next = 0;
 }
@@ -538,7 +538,7 @@ void end_identifier_list()
   }
 
   Memo->info = (void *) Memo->next;
-  Memo->fct = (InstrFct) function_parameter_type_list;
+  Memo->fct = function_parameter_type_list;
   Memo->next->previous = 0;
   Memo->next = 0;
 }
@@ -591,11 +591,11 @@ void declaration()
   if (((Object) ((List *) m[2])->info) == no_initializer)
     m[2] = 0;
 
-  if ((Memo->previous->fct == (InstrFct) preserve_list) &&
+  if ((Memo->previous->fct == preserve_list) &&
       ((List *) Memo->previous->info)->next &&
       ((List *) Memo->previous->info)->next->next &&
       (((List *) Memo->previous->info)->next->next->fct ==
-       (InstrFct) function_parameter_type_list)) {
+       function_parameter_type_list)) {
     
     /*
        Une declaration de fonction complexe de la forme
@@ -621,8 +621,8 @@ void declaration()
     AddLast(Memo, List__List(make_function_declaration, m));
   }
   
-  else if ((Memo->fct == (InstrFct) function_parameter_type_list) &&
-	   (Memo->previous->fct == (InstrFct) make_identifier)) {
+  else if ((Memo->fct == function_parameter_type_list) &&
+	   (Memo->previous->fct == make_identifier)) {
     
     /*
        Une declaration de fonction simple
