@@ -44,6 +44,7 @@
 
 #include <stdio.h>
 #include "y.tab.h"
+#include "fctdecl.h"
 
 char yytext[8196];
 
@@ -54,6 +55,8 @@ static int previous_char;
 char previous_tchar[256];
 static int pt_file = 0;
 
+FCT(int, ie_getc,());
+
 void smac_read_new_file()
 {
   int c = ie_getc();
@@ -67,8 +70,6 @@ void smac_read_new_file()
 extern char err_msg[];
 extern int yyinflag;
 
-extern FCT(int, yyerror, (char *)	);
-
 int ie_getc()
 {
   if (yyinflag) {
@@ -105,6 +106,8 @@ int ie_getc()
 
 #endif
 
+extern FCT(int, yyerror, (char *)	);
+
 int key_err(k)
      char * k;
 {
@@ -125,7 +128,7 @@ int eof_error()
   return(SYNTAX_ERROR);
 }
 
-static lex_error(c)
+static int lex_error(c)
     int c;
 {
   char msg[2];
@@ -337,8 +340,13 @@ int yylex()
 	while ((c = ie_getc()) != '"') {
 	  if (! c)
 	    return eof_error();
-	  else if ((*p++ = c) == '\\')
+	  else if ((*p++ = c) == '\\') {
 	    *p++ = ie_getc();
+	    if (p[-1] == '\n') {
+	      numlig += 1;
+	      p -= 2;
+	    }
+	  }
 	}
 	
 	*p = c;
