@@ -42,7 +42,12 @@
 /* Les operateurs */
 
 #include <stdio.h>
+
+#if HAVE_STRING_H
 #include <string.h>
+#else
+#include <strings.h>
+#endif
 
 #include "operator.h"
 #include "list.h"
@@ -94,10 +99,10 @@ Instruction * make_oper_ampersand(l)
   if (place->fct == make_string)
     return MAKE(place);
   
-  if (place->fct == ((InstrFct) make_identifier))
+  if (place->fct == make_identifier)
     return var_reference(place);
 
-  if (place->fct == ((InstrFct) make_oper_asterisk)) {
+  if (place->fct == make_oper_asterisk) {
     /* &*X = X */
     Instruction * result = MAKE((List *) place->info);
     
@@ -108,7 +113,7 @@ Instruction * make_oper_ampersand(l)
     return result;
   }
 
-  if (place->fct == ((InstrFct) make_array_access))
+  if (place->fct == make_array_access)
     return array_reference(place);
 
   Error("illegal reference");
