@@ -39,7 +39,13 @@
 
 
 #include <stdio.h>
+#include <stdlib.h>
+
+#if HAVE_STRING_H
 #include <string.h>
+#else
+#include <strings.h>
+#endif
 
 /*#include "error.h"*/
 #include "FunctionCall.h"
@@ -153,8 +159,21 @@ char * ie_load_file(buff, filename)
   clear_ctrl_c();
   rerun_profile();
   
-  if (! setjmp(come_back))
-    load_file();
+  {
+    jmp_buf come_back;
+    memo_functions_called * save_last_function_called = Last_Function_Called;
+    Object * save_stack_pointer = Stack_Pointer;
+    Object * save_frame_pointer = Frame_Pointer;
+    
+    if (! setjmp(come_back)) {
+      pCome_Back = &come_back;
+      load_file();
+    }
+    pCome_Back = 0;
+    Last_Function_Called = save_last_function_called;
+    Stack_Pointer = save_stack_pointer;
+    Frame_Pointer = save_frame_pointer;
+  }
 
   stop_profile();
   fclose(yyin);
@@ -199,8 +218,21 @@ char * ie_eval_region(buff)
   clear_ctrl_c();
   rerun_profile();
   
-  if (! setjmp(come_back))
-    load_file();
+  {
+    jmp_buf come_back;
+    memo_functions_called * save_last_function_called = Last_Function_Called;
+    Object * save_stack_pointer = Stack_Pointer;
+    Object * save_frame_pointer = Frame_Pointer;
+    
+    if (! setjmp(come_back)) {
+      pCome_Back = &come_back;
+      load_file();
+    }
+    pCome_Back = 0;
+    Last_Function_Called = save_last_function_called;
+    Stack_Pointer = save_stack_pointer;
+    Frame_Pointer = save_frame_pointer;
+  }
 
   stop_profile();
   yyinfilename = 0;
@@ -241,8 +273,21 @@ char * ie_eval_expression(buff, expr)
   clear_ctrl_c();
   rerun_profile();
   
-  if (! setjmp(come_back))
-    load_file();
+  {
+    jmp_buf come_back;
+    memo_functions_called * save_last_function_called = Last_Function_Called;
+    Object * save_stack_pointer = Stack_Pointer;
+    Object * save_frame_pointer = Frame_Pointer;
+    
+    if (! setjmp(come_back)) {
+      pCome_Back = &come_back;
+      load_file();
+    }
+    pCome_Back = 0;
+    Last_Function_Called = save_last_function_called;
+    Stack_Pointer = save_stack_pointer;
+    Frame_Pointer = save_frame_pointer;
+  }
 
   stop_profile();
   i_buffer_courant = i_minibuffer = 0;
@@ -254,7 +299,12 @@ char * ie_eval_expression(buff, expr)
 
 
 /* appel d'une fonction ou non builtin, par exemple indent_line, s'il
-   y a des arguments, ceux-ci ne peuvent etre que des int ou char */
+   y a des arguments, ceux-ci ne peuvent etre que des int ou char.
+   
+   Attention on peut avoir xcoral appelle smac qui appelle xcoral qui
+   appelle smac !
+   c'est le cas avec select_class qui appelle smac pour colorier
+*/
 
 char * ie_call_function(buff, fctname, narg, args)
      char * buff;
@@ -262,6 +312,11 @@ char * ie_call_function(buff, fctname, narg, args)
      int narg;
      int * args;
 {
+  Identifier * ident = find_identifier(fctname);
+  Function * fdef;
+  jmp_buf * spcome_back = pCome_Back;
+  jmp_buf come_back;
+
   ClearSelectionIfNeeded(buff);
   
   i_buffer_courant = buff;
@@ -272,34 +327,36 @@ char * ie_call_function(buff, fctname, narg, args)
   i_curseur = i_curseur_sup = 0;
   clear_ctrl_c();
 
-  if (! setjmp(come_back)) {
-    Identifier * ident = find_identifier(fctname);
-    Function * fdef;
-
-    if ((! ident) ||
-	(! (fdef = Identifier__FunctionDef(ident)))) {
-      sprintf(err_msg, "%s is not a function name", fctname);
-      return err_msg;
-    }
-    else {
-      accept_ctrl_c();
-      rerun_profile();
-      if (! setjmp(come_back))
-	if (Function__IsBuiltin(fdef))
-	  call_builtin_function_of_xcoral(fdef, narg);
-	else
-	  call_user_function_from_xcoral(fdef, narg, args);
-      stop_profile();
-      ignore_ctrl_c();
-    }
+  if ((! ident) ||
+      ((fdef = Identifier__FunctionDef(ident)) == 0)) {
+    sprintf(err_msg, "%s is not a function name", fctname);
+    return err_msg;
   }
   
+  accept_ctrl_c();
+  rerun_profile();
+  switch (setjmp(come_back)) {
+  case NO_JMP:
+    pCome_Back = &come_back;
+    
+    if (Function__IsBuiltin(fdef))
+      call_builtin_function_of_xcoral(fdef, narg);
+    else
+      call_user_function_from_xcoral(fdef, narg, args);
+    break;
+  case JMP_ERROR:
+    if ((pCome_Back = spcome_back) != 0)
+      longjmp(*spcome_back, JMP_ERROR);
+  }
+  pCome_Back = spcome_back;
+  
+  stop_profile();
+  ignore_ctrl_c();
+  
   i_buffer_courant = 0;
   i_curseur = i_curseur_sup = 0;
   
   Reinit_Control();
-  Reinit_Error();
-  Reinit_Stack();
   
   return (*err_msg) ? err_msg : 0;
 }
@@ -1580,6 +1637,33 @@ Object builtin_color_area(a)
   return 0;
 }
 
+Object builtin_uncolor_area(a)
+     Instruction ** a;
+{
+  extern FCT(void, ie_uncolor_area,(char *, int, int));
+  int start = (int) Eval(a[0]);
+  int end = (int) Eval(a[1]);
+
+  ignore_ctrl_c();
+  ie_uncolor_area(i_buffer_courant, start, end);
+  accept_ctrl_c();
+  
+  return 0;
+}
+
+Object builtin_current_buffer_is_colored(a)
+     Instruction ** a;
+{
+  extern FCT(int, ie_current_buffer_is_colored,(char *));
+  Object result;
+
+  ignore_ctrl_c();
+  result = ie_current_buffer_is_colored(i_buffer_courant);
+  accept_ctrl_c();
+  
+  return result;
+}
+
 
 /* region */
 
@@ -1804,7 +1888,6 @@ Object builtin_usleep(a)
   return 0;
 }
 
-#ifndef LIONEL
 #include "../result_types.h"
 #include "../file_dict.h"
 #include "../class_dict.h"
@@ -2843,7 +2926,14 @@ Object builtin_browser_hide_function(a)
   
   return 0;
 }
-#endif
+
+Object builtin_smaclib_dir(a)
+    Instruction ** a;
+{
+  ignore_ctrl_c();
+  return strdup_end(XCORAL_LIB_DIR);
+}
+
 
 /* */
 
@@ -2853,6 +2943,9 @@ void Init_Smac_Xcoral()
   static Type * string_string_string[3];
   static Type * string_string_int[3];
   static Type * int_int_string[3];
+  static Type * pString;
+  static Type * pInt;
+  static Type * string_pint[2];
     
   string_string_int[0] = string_string_int[1] = Type_String;
   string_string_int[2] = Type_Int;
@@ -2867,6 +2960,11 @@ void Init_Smac_Xcoral()
   int_int_string[0] = int_int_string[1] = Type_Int;
   int_int_string[2] = Type_String;
     
+  pString = Type__Type(Type_String, T_Pointer, sizeof(char **));
+  pInt = Type__Type(Type_Int, T_Pointer, sizeof(int *));
+  string_pint[0] = Type_String;
+  string_pint[1] = pInt;
+    
   new_builtin("current_position", Type_Int, 0, 0, builtin_current_position);
   new_builtin("current_char", Type_Char, 0, 0, builtin_current_char);
   new_builtin("previous_char", Type_Char, 0, 0, builtin_previous_char);
@@ -2970,6 +3068,10 @@ void Init_Smac_Xcoral()
   new_builtin("remove_colors", Type_Void, 0, 0, builtin_remove_colors);
   new_builtin("color_area", Type_Void, 3, int_int_string,
 	      builtin_color_area);
+  new_builtin("uncolor_area", Type_Void, 2, int_int_string,
+	      builtin_uncolor_area);
+  new_builtin("current_buffer_is_colored", Type_Int, 0, 0,
+	      builtin_current_buffer_is_colored);
   
   new_builtin("mark_position", Type_Int, 0, 0, builtin_mark_position);
   new_builtin("cut_region", Type_Void, 0, 0, builtin_cut_region);
@@ -2996,118 +3098,107 @@ void Init_Smac_Xcoral()
   new_builtin("usleep", Type_Void, 1, &Type_Int, builtin_usleep);
   new_builtin("current_mode", Type_String, 0, 0, builtin_current_mode);
   
-#ifndef LIONEL
-  {
-    static Type * pString;
-    static Type * pInt;
-    static Type * string_pint[2];
-    
-    pString = Type__Type(Type_String, T_Pointer, sizeof(char **));
-    pInt = Type__Type(Type_Int, T_Pointer, sizeof(int *));
-    string_pint[0] = Type_String;
-    string_pint[1] = pInt;
-    
-    new_builtin("browser_set_pp", Type_Void, 2, string_string_string,
-		builtin_browser_set_pp);
-    new_builtin("browser_set_pp_options", Type_Void, 2, string_string_string,
-		builtin_browser_set_pp_options);
-    HashTable__Add(builtin_fct_nbre_arg_min,
-		   new_builtin("browser_add", Type_Void, 2, 
-			       &string_string_int[1], builtin_browser_add),
-		   1 + 1);
-    HashTable__Add(builtin_fct_nbre_arg_min,
-		   new_builtin("browser_del", Type_Void, 1, 
-			       &Type_String, builtin_browser_del),
-		   0 + 1);
-    HashTable__Add(builtin_fct_nbre_arg_min,
-		   new_builtin("browser_class_file", Type_String, 2, 
-			       string_pint, builtin_browser_class_file),
-		   1 + 1);
-    new_builtin("browser_class_parents", pString, 1, &Type_String,
-		builtin_browser_class_parents);
-    new_builtin("browser_class_children", pString, 1, &Type_String,
-		builtin_browser_class_children);
-    new_builtin("browser_class_methods", pString, 1, &Type_String,
-		builtin_browser_class_methods);
-    new_builtin("browser_class_attributes", pString, 1, &Type_String,
-		builtin_browser_class_attributes);
-    new_builtin("browser_class_flags", Type_String, 1, &Type_String,
-		builtin_browser_class_flags); 
-    new_builtin("browser_functions", pString, 1, &Type_String,
-		builtin_browser_functions);
-    new_builtin("browser_globals", pString, 1, &Type_String,
-		builtin_browser_globals);
-    new_builtin("browser_select_class", Type_Int, 1, &Type_String,
-		builtin_browser_select_class); 
-    new_builtin("browser_select_method", Type_Int, 1, &Type_String,
-		builtin_browser_select_method); 
-    new_builtin("browser_select_attribute", Type_Int, 1, &Type_String,
-		builtin_browser_select_attribute); 
-    new_builtin("browser_select_function", Type_Int, 1, &Type_String,
-		builtin_browser_select_function); 
-    new_builtin("browser_select_global", Type_Int, 1, &Type_String,
-		builtin_browser_select_global); 
-    new_builtin("browser_edit", Type_Void, 0, 0, builtin_browser_edit); 
-    new_builtin("browser_class_entry", Type_Int, 1, &Type_String,
-		builtin_browser_class_entry); 
-    new_builtin("browser_function_entry", Type_Int, 1, &Type_String,
-		builtin_browser_function_entry); 
-    new_builtin("browser_global_entry", Type_Int, 1, &Type_String,
-		builtin_browser_global_entry); 
-    new_builtin("browser_file_entry", Type_Int, 1, &Type_String,
-		builtin_browser_file_entry); 
-    new_builtin("browser_class", Type_String, 1, &Type_Int,
-		builtin_browser_class); 
-    new_builtin("browser_function", Type_String, 1, &Type_Int,
-		builtin_browser_function); 
-    new_builtin("browser_global", Type_String, 1, &Type_Int,
-		builtin_browser_global); 
-    new_builtin("browser_file", Type_String, 1, &Type_Int,
-		builtin_browser_file); 
-    new_builtin("browser_dump", Type_Int, 1, &Type_String,
-		builtin_browser_dump); 
-    new_builtin("browser_restore", Type_Int, 1, &Type_String,
-		builtin_browser_restore); 
-    new_builtin("browser_show_all", Type_Void, 0, 0,
-		builtin_browser_show_all); 
-    new_builtin("browser_hide_private_members", Type_Void, 0, 0,
-		builtin_browser_hide_private_members); 
-    new_builtin("browser_hide_protected_and_private_members", Type_Void, 0, 0,
-		builtin_browser_hide_protected_and_private_members); 
-    new_builtin("browser_show_protected_and_private_members", Type_Void, 0, 0,
-		builtin_browser_show_protected_and_private_members); 
-    new_builtin("browser_hide_inherited_members", Type_Void, 0, 0,
-		builtin_browser_hide_inherited_members); 
-    new_builtin("browser_show_inherited_members", Type_Void, 0, 0,
-		builtin_browser_show_inherited_members); 
-    new_builtin("browser_hide_internal_types", Type_Void, 0, 0,
-		builtin_browser_hide_internal_types); 
-    new_builtin("browser_show_internal_types", Type_Void, 0, 0,
-		builtin_browser_show_internal_types); 
-    new_builtin("browser_hide_static_functions", Type_Void, 0, 0,
-		builtin_browser_hide_static_functions); 
-    new_builtin("browser_show_static_functions", Type_Void, 0, 0,
-		builtin_browser_show_static_functions); 
-    new_builtin("browser_hide_static_globals", Type_Void, 0, 0,
-		builtin_browser_hide_static_globals); 
-    new_builtin("browser_show_static_globals", Type_Void, 0, 0,
-		builtin_browser_show_static_globals); 
-    new_builtin("browser_hide_children_of", Type_Void, 1, &Type_String,
-		builtin_browser_hide_children_of); 
-    new_builtin("browser_show_children_of", Type_Void, 1, &Type_String,
-		builtin_browser_show_children_of); 
-    new_builtin("browser_hide_class", Type_Void, 1, &Type_String,
-		builtin_browser_hide_class); 
-    new_builtin("browser_show_class", Type_Void, 1, &Type_String,
-		builtin_browser_show_class); 
-    new_builtin("browser_hide_global", Type_Void, 1, &Type_String,
-		builtin_browser_hide_global); 
-    new_builtin("browser_show_global", Type_Void, 1, &Type_String,
-		builtin_browser_show_global); 
-    new_builtin("browser_hide_function", Type_Void, 1, &Type_String,
-		builtin_browser_hide_function); 
-    new_builtin("browser_show_function", Type_Void, 1, &Type_String,
-		builtin_browser_show_function); 
-}
-#endif
+  new_builtin("browser_set_pp", Type_Void, 2, string_string_string,
+	      builtin_browser_set_pp);
+  new_builtin("browser_set_pp_options", Type_Void, 2, string_string_string,
+	      builtin_browser_set_pp_options);
+  HashTable__Add(builtin_fct_nbre_arg_min,
+		 new_builtin("browser_add", Type_Void, 2, 
+			     &string_string_int[1], builtin_browser_add),
+		 1 + 1);
+  HashTable__Add(builtin_fct_nbre_arg_min,
+		 new_builtin("browser_del", Type_Void, 1, 
+			     &Type_String, builtin_browser_del),
+		 0 + 1);
+  HashTable__Add(builtin_fct_nbre_arg_min,
+		 new_builtin("browser_class_file", Type_String, 2, 
+			     string_pint, builtin_browser_class_file),
+		 1 + 1);
+  new_builtin("browser_class_parents", pString, 1, &Type_String,
+	      builtin_browser_class_parents);
+  new_builtin("browser_class_children", pString, 1, &Type_String,
+	      builtin_browser_class_children);
+  new_builtin("browser_class_methods", pString, 1, &Type_String,
+	      builtin_browser_class_methods);
+  new_builtin("browser_class_attributes", pString, 1, &Type_String,
+	      builtin_browser_class_attributes);
+  new_builtin("browser_class_flags", Type_String, 1, &Type_String,
+	      builtin_browser_class_flags); 
+  new_builtin("browser_functions", pString, 1, &Type_String,
+	      builtin_browser_functions);
+  new_builtin("browser_globals", pString, 1, &Type_String,
+	      builtin_browser_globals);
+  new_builtin("browser_select_class", Type_Int, 1, &Type_String,
+	      builtin_browser_select_class); 
+  new_builtin("browser_select_method", Type_Int, 1, &Type_String,
+	      builtin_browser_select_method); 
+  new_builtin("browser_select_attribute", Type_Int, 1, &Type_String,
+	      builtin_browser_select_attribute); 
+  new_builtin("browser_select_function", Type_Int, 1, &Type_String,
+	      builtin_browser_select_function); 
+  new_builtin("browser_select_global", Type_Int, 1, &Type_String,
+	      builtin_browser_select_global); 
+  new_builtin("browser_edit", Type_Void, 0, 0, builtin_browser_edit); 
+  new_builtin("browser_class_entry", Type_Int, 1, &Type_String,
+	      builtin_browser_class_entry); 
+  new_builtin("browser_function_entry", Type_Int, 1, &Type_String,
+	      builtin_browser_function_entry); 
+  new_builtin("browser_global_entry", Type_Int, 1, &Type_String,
+	      builtin_browser_global_entry); 
+  new_builtin("browser_file_entry", Type_Int, 1, &Type_String,
+	      builtin_browser_file_entry); 
+  new_builtin("browser_class", Type_String, 1, &Type_Int,
+	      builtin_browser_class); 
+  new_builtin("browser_function", Type_String, 1, &Type_Int,
+	      builtin_browser_function); 
+  new_builtin("browser_global", Type_String, 1, &Type_Int,
+	      builtin_browser_global); 
+  new_builtin("browser_file", Type_String, 1, &Type_Int,
+	      builtin_browser_file); 
+  new_builtin("browser_dump", Type_Int, 1, &Type_String,
+	      builtin_browser_dump); 
+  new_builtin("browser_restore", Type_Int, 1, &Type_String,
+	      builtin_browser_restore); 
+  new_builtin("browser_show_all", Type_Void, 0, 0,
+	      builtin_browser_show_all); 
+  new_builtin("browser_hide_private_members", Type_Void, 0, 0,
+	      builtin_browser_hide_private_members); 
+  new_builtin("browser_hide_protected_and_private_members", Type_Void, 0, 0,
+	      builtin_browser_hide_protected_and_private_members); 
+  new_builtin("browser_show_protected_and_private_members", Type_Void, 0, 0,
+	      builtin_browser_show_protected_and_private_members); 
+  new_builtin("browser_hide_inherited_members", Type_Void, 0, 0,
+	      builtin_browser_hide_inherited_members); 
+  new_builtin("browser_show_inherited_members", Type_Void, 0, 0,
+	      builtin_browser_show_inherited_members); 
+  new_builtin("browser_hide_internal_types", Type_Void, 0, 0,
+	      builtin_browser_hide_internal_types); 
+  new_builtin("browser_show_internal_types", Type_Void, 0, 0,
+	      builtin_browser_show_internal_types); 
+  new_builtin("browser_hide_static_functions", Type_Void, 0, 0,
+	      builtin_browser_hide_static_functions); 
+  new_builtin("browser_show_static_functions", Type_Void, 0, 0,
+	      builtin_browser_show_static_functions); 
+  new_builtin("browser_hide_static_globals", Type_Void, 0, 0,
+	      builtin_browser_hide_static_globals); 
+  new_builtin("browser_show_static_globals", Type_Void, 0, 0,
+	      builtin_browser_show_static_globals); 
+  new_builtin("browser_hide_children_of", Type_Void, 1, &Type_String,
+	      builtin_browser_hide_children_of); 
+  new_builtin("browser_show_children_of", Type_Void, 1, &Type_String,
+	      builtin_browser_show_children_of); 
+  new_builtin("browser_hide_class", Type_Void, 1, &Type_String,
+	      builtin_browser_hide_class); 
+  new_builtin("browser_show_class", Type_Void, 1, &Type_String,
+	      builtin_browser_show_class); 
+  new_builtin("browser_hide_global", Type_Void, 1, &Type_String,
+	      builtin_browser_hide_global); 
+  new_builtin("browser_show_global", Type_Void, 1, &Type_String,
+	      builtin_browser_show_global); 
+  new_builtin("browser_hide_function", Type_Void, 1, &Type_String,
+	      builtin_browser_hide_function); 
+  new_builtin("browser_show_function", Type_Void, 1, &Type_String,
+	      builtin_browser_show_function); 
+  
+  new_builtin("smaclib_dir", Type_String, 0, 0, builtin_smaclib_dir);
 }
