@@ -37,6 +37,13 @@
 
    ######################################################################## */
 
+#if HAVE_STRING_H
+#include <string.h>
+#else
+#include <strings.h>
+#endif
+#include <stdio.h>
+
 #include "proto_decl.h"
 
 #include "result_types.h"
@@ -48,8 +55,6 @@
 #include "browser_pars.h"
 #include "browser_util.h"
 
-#include <string.h>
-#include <stdio.h>
 
 
 /*------------------------------------------------------------------------------
