@@ -42,17 +42,25 @@
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <X11/cursorfont.h>
-#if defined (apollo) || defined (__FreeBSD__)
-#include <stdlib.h>
+
+#if STDC_HEADERS
+#  include <stdlib.h>
 #else
-#include <malloc.h>
+#  if HAVE_MALLOC_H
+#    include <malloc.h>
+#  endif
 #endif
+
+#if HAVE_STRING_H
 #include <string.h>
+#else
+#include <strings.h>
+#endif
+
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <X11/Xatom.h>
 
-
 #include "options.h"
 #include "xcoral.h"
 #include "browser_init.h"
@@ -77,6 +85,7 @@ extern char *b_name[];
 int flag_visit = False;
 
 FCT (static void, AddFiles, () );
+FCT (static void, SmacLibFiles, () );
 FCT (void, ButtonEdit, () );
 FCT (static void, ButtonInVisitWindow, (BWin *bwin, XButtonEvent *ev) );
 FCT (static int, ClassSelect, (BWin *bwin) );
@@ -94,6 +103,11 @@ FCT (void, SelectItem, (BWin *bwin, int x, int y, int i) );
 FCT (void, UpdateTitle, (char *name) );
 FCT (void, RefreshPpButton,() );
 FCT (static void, TitleVisit, (char *name) );
+FCT (static void, SmacLibFiles, () );
+
+#if !HAVE_STRDUP
+extern FCT (char*, strdup, (char*) );
+#endif
 
 /*
 **	Function name : ExposeBrowser
@@ -107,7 +121,8 @@ int ExposeBrowser ( ev )
 {
     int i;
     int width, expose_flag;
-    
+
+#ifdef WITH_BR_TITLE
     if ( ev -> xexpose.window == br.title ) {
 	if ( br.title_name != 0 )
 	  UpdateTitle ( br.title_name );
@@ -124,6 +139,7 @@ int ExposeBrowser ( ev )
 	}
 	return True;
     }
+#endif
     
     if ( ev -> xexpose.window == br.main ) {
 	Display3D ( dpy, ev -> xexpose.window, br.ts, br.bs, 1, 0 );
@@ -169,11 +185,18 @@ int ExposeBrowser ( ev )
 		     br.font -> ascent + (B_INTER / 2), "Add", 3 );
 	return True;
     }
+    if ( ev -> xexpose.window == br.smac ) {
+	Display3D ( dpy, ev -> xexpose.window, br.ts, br.bs, 1, 0 ); 
+	XDrawString ( dpy, ev -> xexpose.window, br.gc, 
+		     ( br.button_width - XTextWidth ( br.font, "Smac", 4 )) / 2,
+		     br.font -> ascent + (B_INTER / 2), "Smac", 4 );
+	return True;
+    }
     if ( ev -> xexpose.window == br.del ) {
 	Display3D ( dpy, ev -> xexpose.window, br.ts, br.bs, 1, 0 );
 	XDrawString ( dpy, ev -> xexpose.window, br.gc, 
-		     ( br.button_width - XTextWidth ( br.font, "Del", 3 )) / 2,
-		     br.font -> ascent + (B_INTER / 2), "Del", 3 );
+		     ( br.button_width - XTextWidth ( br.font, "Rem", 3 )) / 2,
+		     br.font -> ascent + (B_INTER / 2), "Rem", 3 );
 	return True;
     }
     if ( ev -> xexpose.window == br.edit ) {
@@ -222,10 +245,10 @@ int ExposeBrowser ( ev )
 	    }
 	    else {
 	      if ((i == 0) && (strcmp ( br.mode -> name, "Java" ) == 0)) {
-		width = XTextWidth ( br.font, "Class", strlen ("Class"));
+		width = XTextWidth ( br.font, "Classes", strlen ("Classes"));
 		XDrawString ( dpy, ev -> xexpose.window, br.gc, 
 			     (br.tbw[i].f_width - width)/2, br.font -> ascent + (B_INTER / 2),            
-			     "Class", strlen ("Class"));
+			     "Classes", strlen ("Classes"));
 	      }
 	      else {
 		width = XTextWidth ( br.font, b_name [i], strlen (b_name [i]));
@@ -323,6 +346,7 @@ int ButtonBrowser ( ev )
     if ( (w == br.close) 
 	||  (w == br.rec) 
 	||  (w == br.add) 
+	||  (w == br.smac) 
 	|| ( w == br.del) 
 	|| ( w == br.dec) 
 	|| ( w == br.pp) 
@@ -366,6 +390,8 @@ int ButtonBrowser ( ev )
 	  ButtonEdit ();
 	else if ( w == br.add )
 	  ManageFiles ( B_ADD );
+	else if ( w == br.smac )
+	  SmacLibFiles ();
 	else if ( w == br.del )
 	  ManageFiles ( B_DEL );
 	else if ( w == br.close )
@@ -501,12 +527,12 @@ static void ManageFiles ( op )
 	    *(tmp + len ) = '\0'; /* On vire le newline */
 	    del_filename =  (char *) malloc ( (unsigned) len + 2 );
 	    (void) strcpy ( del_filename, tmp );
-	    buf = (char *) malloc ( (unsigned) len + 32 );
-	    (void) sprintf ( buf, "Remove file selected [y/n/all] : "  );
+	    buf = (char *) malloc ( (unsigned) len + 64 );
+	    (void) sprintf ( buf, "Remove browser data for the selected file  [y/n] : "  );
 	    tmp = (char *) GetStringFromDB ( buf, False );
 	    if ( (tmp == 0) || (strncmp(tmp, "y", 1) == 0 )) 
 	      RemoveFiles ( del_filename );
-	    else if ( strcmp ( tmp, "all" ) == 0 ) 
+	    else if ( strncmp ( tmp, "all",3) == 0 ) 
 	      RemoveFiles ( (char *) 0 );
 	    if ( del_filename != 0 )
 	      (void) free ( del_filename );
@@ -514,10 +540,9 @@ static void ManageFiles ( op )
 	      (void) free ( buf );
 	}
 	else {
-	    tmp = (char *) GetStringFromDB ( "Delete all files [y/n] : ", True );
-	    if ( (tmp == 0) || (strncmp(tmp, "y", 1) == 0 )
-		|| (strncmp(tmp, "all", 3)) == 0 )
-	      RemoveFiles ( (char *) 0 );
+	    tmp = (char *) GetStringFromDB ( "Remove all browser data [y/n] : ", True );
+	    if ( (tmp==0) || (strncmp(tmp, "y", 1)==0) || (strncmp(tmp, "all", 3)==0))
+	      RemoveFiles ((char *)0);
 	}
     }
     else 
@@ -561,6 +586,41 @@ static void AddFiles ()
     }
 }
 
+/*
+**	Function name : SmacLibFiles
+**
+**	Description :
+**	Input :
+**	Output :
+*/
+static void SmacLibFiles()
+{
+    char *s;
+    struct stat st;
+    char smacdir[MAXPATHLEN];
+    
+    (void) chdir ( br.dir );
+    (void) sprintf(smacdir,"%s",XCORAL_LIB_DIR);
+    s = &smacdir[0];
+    
+    if ( (s != 0) && (strlen (s) != 0 ) && (*s != '\007') ) {
+	(void) stat ( s, &st );
+	if ( S_ISDIR(st.st_mode) != 0 ) {
+	    XDefineCursor ( dpy, br.frame, 
+			   XCreateFontCursor ( dpy, XC_watch ) );
+	    XFlush (dpy ); 
+#ifdef DEBUG
+	    (void) fprintf ( stderr, "dir : %s\n", s );
+#endif
+	    LoadDir ( s );
+	    XUndefineCursor ( dpy, br.frame );
+	    SetBrowserDir ( s );
+	}
+	(void) RefreshBrowserInfos ();
+    }
+}
+
+
 /*
 **	Function name : RemoveFiles
 **
@@ -666,20 +726,16 @@ void RefreshBrowserInfos ()
     br.tbw[W_PARENT].select = br.tbw[W_CHILD].select = br.tbw[W_METHOD].select = 0;
     br.tbw[W_ATTRIBUTES].select = br.tbw[W_GLOBALS].select = 0;
     
-    if ( (strcmp ( br.mode -> name, "C++mode" ) == 0)
-	|| (strcmp ( br.mode -> name, "Java" ) == 0)) {
-	i = 0;
-    }
-    else if ( strcmp ( br.mode -> name, "C-mode" ) == 0 ) {
-	i = C_FIRST_WIN;
-    }
-    else
+    if ( (strcmp ( br.mode -> name, "C++mode" ) != 0)
+	&& (strcmp ( br.mode -> name, "Java" ) != 0)
+	&& (strcmp ( br.mode -> name, "C-mode" ) != 0)) {
       return;
-    
+    }
+
     if ( br.stat == B_UNMAP )
       return;
 
-    for ( ;i < (B_NB_WIN - 1); i++ )
+    for (i=0;i < (B_NB_WIN - 1); i++ )
       {
 	while ( XCheckWindowEvent ( dpy,
 				   br.tbw[i].text -> window , ExposureMask, &event ));
@@ -694,6 +750,9 @@ void RefreshBrowserInfos ()
 	case W_PARENT:
 	case W_CHILD:
 	case W_METHOD:
+	  if (strcmp ( br.mode -> name, "C-mode" ) != 0)
+	    KillText ( dpy, br.tbw[i].text );
+	  break;
 	case W_ATTRIBUTES:
 	  KillText ( dpy, br.tbw[i].text ); 
 	  break;
@@ -718,6 +777,7 @@ void ButtonEdit ()
     EdWin *ew;
     char *filename;
     extern EdWin *CreateWindow ();
+    extern int _startup;
     Text *text;
     int line;
     
@@ -740,8 +800,10 @@ void ButtonEdit ()
     if ( (filename != 0) && (strcmp(filename, "NoName")!=0) ) {
 	(void) strcpy ( ew -> text -> current_dir, br.dir );
 	line = br.tbw[W_VISIT].text -> no_current_line;
-	if ( LoadFile ( ew -> text, filename, NEW ) != -1 )
+	if ( LoadFile ( ew -> text, filename, NEW ) != -1 ) {
 	  GotoLineNumber ( ew ->text, line );
+	  _startup = True; /* Un petit hack des familles pour la couleur */
+	}
 	else 
 	  return;
     }
@@ -882,8 +944,9 @@ static int ClassSelect ( bwin )
     br.tbw[W_ATTRIBUTES].select = 0;
     ClearPage ( br.tbw[W_ATTRIBUTES].text );
     FirstPage ( br.tbw[W_ATTRIBUTES].text ); 
-    
+
     tmp = ( char **)  get_parents_list ( class_name, 0);
+    KillText(dpy, br.tbw[W_PARENT].text);
     ExtractInfos ( tmp, W_PARENT );
     if ( tmp != 0 )
       free ( (char *) tmp );
@@ -891,9 +954,10 @@ static int ClassSelect ( bwin )
     br.tbw[W_PARENT].select = 0;
     ClearPage ( br.tbw[W_PARENT].text );
     FirstPage ( br.tbw[W_PARENT].text ); 
-    
+
     FirstPage ( br.tbw[W_CHILD].text );
     tmp = ( char **)  get_sons_list ( class_name);
+    KillText(dpy, br.tbw[W_CHILD].text);
     free(class_name);
     ExtractInfos ( tmp, W_CHILD );
     if ( tmp != 0 )
@@ -917,12 +981,14 @@ static int ClassSelect ( bwin )
 void UpdateTitle ( name )
     char *name;
 {
+#ifdef WITH_BR_TITLE
     if ( name == 0 )
       return;
     XClearWindow ( dpy, br.title );
     XDrawString ( dpy, br.title, br.gc,
 		 B_INTER, br.font -> ascent + (B_INTER/2), name, strlen ( name ));
     Display3D ( dpy,br.title , br.ts, br.bs, 1, 0 );
+#endif
     
     if ( br.title_name != 0 ) {
 	if ( strcmp ( br.title_name, name ) == 0 )
@@ -1214,7 +1280,8 @@ static void EditFile ( bwin, name )
       ClearBuffer ( bwin -> buf );
       if ( LoadFile ( bwin ->text, name, NEW ) != -1 ) {
 	ShowScrollFrame ( dpy, bwin ->text -> swin );
-	FirstPage ( bwin ->text ); 
+	FirstPage ( bwin ->text );
+	ColorBuffer (bwin ->text);
 	TitleVisit ( name );
       }
       else {
@@ -1259,6 +1326,7 @@ static void ButtonInVisitWindow ( bwin, ev )
   char *msg;
   extern Window w_sel;
   EdWin **t;
+  Time selection_time;
   
   switch ( ev -> button ) {
   case Button1:
@@ -1276,7 +1344,7 @@ static void ButtonInVisitWindow ( bwin, ev )
       UpdatePage ( bwin -> text );
     }
     TextCursorOn ( bwin -> text );
-    (void) HandleSelection (bwin -> text, ev);
+    selection_time = HandleSelection (bwin -> text, ev);
     if (bwin -> text -> selection -> select == True) {
       /* Il faut effacer la derniere selection si elle existe */
       for ( t = TWin; t < TWin + MAXWIN; t++ ) {
@@ -1292,7 +1360,8 @@ static void ButtonInVisitWindow ( bwin, ev )
 	}
       }
       w_sel = ev -> window;
-      XSetSelectionOwner ( dpy, XA_PRIMARY, w_sel, ev -> time);
+/*      XSetSelectionOwner ( dpy, XA_PRIMARY, w_sel, ev -> time); */
+      XSetSelectionOwner ( dpy, XA_PRIMARY, w_sel, selection_time);
       if ( w_sel == XGetSelectionOwner ( dpy, XA_PRIMARY )) {
 #ifdef DEBUG
 	(void) fprintf (stderr, "Selection owner OK\n");
