@@ -52,22 +52,40 @@
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 
-#ifdef apollo
-#include <sys/dir.h>
-#define dirent direct
+#if HAVE_DIRENT_H
+#  include <dirent.h>
+#  define NAMLEN(dirent) strlen((dirent)->d_name)
 #else
-#include <dirent.h>
+#  define dirent direct
+#  define NAMLEN(dirent) (dirent)->d_namlen
+#  if HAVE_SYS_NDIR_H
+#    include <sys/ndir.h>
+#  endif
+#  if HAVE_SYS_DIR_H
+#    include <sys/dir.h>
+#  endif
+#  if HAVE_NDIR_H
+#    include <ndir.h>
+#  endif
 #endif
 
+#if HAVE_STRING_H
 #include <string.h>
+#else
+#include <strings.h>
+#endif
+
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/param.h>
-#ifndef __FreeBSD__
-#include <malloc.h>
-#endif
-#include <stdlib.h>
 
+#if STDC_HEADERS
+#  include <stdlib.h>
+#else
+#  if HAVE_MALLOC_H
+#    include <malloc.h>
+#  endif
+#endif
 
 #include "options.h"
 #include "mode.h"
@@ -81,7 +99,7 @@ extern Display  	*dpy;
 Browser		br;
 
 char *b_name[] = {
-	"Types",
+	"Classes/Types",
  	"Parents",	"Children", "Methods",
 	"Attributes", "Globals",
 	"Functions", "Files","Visit", 0
@@ -173,14 +191,21 @@ void InitBrowser ()
 				    GetOpGeo(OP_B_X), 
 				    GetOpGeo(OP_B_Y),
 				    br.width, br.height, 0, black, black );
+#ifdef WITH_BR_TITLE
     br.title = XCreateSimpleWindow (dpy, br.frame, 
 				    0, 0, br.width, br.title_height, 0 , black, br.bg );
     br.main = XCreateSimpleWindow (dpy, br.frame, 
 				   0, br.title_height, br.width, br.height - br.title_height, 0, black, br.bg );
+#else
+    br.main = XCreateSimpleWindow (dpy, br.frame, 
+				   0, 0, br.width, br.height, 0, black, br.bg );
+#endif
     
     XSelectInput ( dpy, br.frame, ExposureMask | StructureNotifyMask 
 		  | KeyPressMask );
+#ifdef WITH_BR_TITLE
     XSelectInput ( dpy, br.title, ExposureMask );
+#endif
     XSelectInput ( dpy, br.main, ExposureMask | VisibilityChangeMask  );
     
     sizehints.flags = PSize |  PMinSize | PMaxSize;
@@ -212,7 +237,11 @@ void InitBrowser ()
     br.parse_flag = NO_RECURSIVE;
     br_start = (char *) getenv ( "XCORAL_PARSE_PATH" );
     if ( br_start != 0 ) {
+#if HAVE_GETCWD
 	(void) getcwd ( pathname, MAXPATHLEN );
+#else
+	(void) getwd  ( pathname );
+#endif
 	br.parse_flag = RECURSIVE;
 	ParseDir ( br_start, pathname );
     }
@@ -374,19 +403,20 @@ static void BrowserButtons ()
 				    br.button_width, br.button_height, 0, black, br.bg );
     br.hide = XCreateSimpleWindow (dpy, br.main, 0, 0,
 				   br.button_width, br.button_height, 0, black, br.bg );
-    
+    br.smac = XCreateSimpleWindow (dpy, br.main, 0, 0,
+				  br.button_width,br.button_height, 0, black, br.bg );
+   
     XSelectInput ( dpy, br.dec, ExposureMask | ButtonPressMask | ButtonReleaseMask );
     XSelectInput ( dpy, br.add, ExposureMask | ButtonPressMask | ButtonReleaseMask);
+    XSelectInput ( dpy, br.smac, ExposureMask | ButtonPressMask | ButtonReleaseMask);
     XSelectInput ( dpy, br.del, ExposureMask | ButtonPressMask | ButtonReleaseMask);
     XSelectInput ( dpy, br.edit, ExposureMask | ButtonPressMask | ButtonReleaseMask);
     XSelectInput ( dpy, br.close, ExposureMask | ButtonPressMask | ButtonReleaseMask);
     XSelectInput ( dpy, br.rec, ExposureMask | ButtonPressMask | ButtonReleaseMask);
-#ifndef LIONEl
     XSelectInput ( dpy, br.pp, ExposureMask | ButtonPressMask | ButtonReleaseMask);
     XSelectInput ( dpy, br.dump, ExposureMask | ButtonPressMask | ButtonReleaseMask);
     XSelectInput ( dpy, br.restore, ExposureMask | ButtonPressMask | ButtonReleaseMask);
     XSelectInput ( dpy, br.hide, ExposureMask | ButtonPressMask | ButtonReleaseMask);
-#endif    
 }
 
 /*
@@ -419,7 +449,7 @@ void LoadDir ( dir )
 	    buf = dp->d_name;			
 	}
 	else {
-	    buf = (char *) malloc ( (unsigned) (strlen ( dir ) + strlen ( dp->d_name ) + 4) );
+	    buf = (char *) malloc ( (unsigned) (strlen (dir) + NAMLEN(dp) + 4) );
 	    (void) sprintf ( buf, "%s/%s", dir, dp->d_name );
 	}
 	(void) stat ( buf , &st );
@@ -494,7 +524,8 @@ static void BrowserTextWindows ()
 	}
 	else {
 	    frame = XCreateSimpleWindow (dpy, br.main, B_INTER,
-					 B_INTER, br.width, br.height, 0, black, br.bg ); 
+					 (2*B_INTER)+br.button_height,
+					 br.width, br.height, 0, black, br.bg ); 
 	    XSelectInput ( dpy, frame, ExposureMask | ButtonReleaseMask );
 	}
 	
@@ -734,30 +765,45 @@ void ConfigBrowser ( width, height )
     br.width = width;
     br.height = height;
     
+#ifdef WITH_BR_TITLE
     XMoveResizeWindow ( dpy, br.title, 0, 0, br.width, br.title_height );
     XResizeWindow ( dpy, br.main, br. width, br.height - br.title_height );
+#else
+    XResizeWindow ( dpy, br.main, br. width, br.height );
+#endif
     
     ConfigFiles (); 
-    if ( (strcmp ( br.mode -> name, "C++mode" ) == 0)
-	|| (strcmp ( br.mode -> name, "Java" ) == 0)) {
-	ConfigClass ();
+    ConfigClass ();
+    ConfigAttributes ();
+    ConfigParent ();
+    ConfigChild ();
+    ConfigMethod ();
+    ConfigProc ();
+    ConfigGlobals ();
+    
+/*    if (strcmp (br.mode -> name, "C++mode")==0) {
 	ConfigParent ();
 	ConfigChild ();
 	ConfigMethod ();
 	ConfigProc ();
-	ConfigAttributes ();
 	ConfigGlobals ();
     }
-    else if ( strcmp ( br.mode -> name, "C-mode" ) == 0 ) {
+    else if (strcmp (br.mode -> name, "C-mode")==0) {
+	ConfigGlobals ();
 	ConfigProc ();
     }
+    else if (strcmp (br.mode -> name, "Java")==0) {
+	ConfigParent ();
+	ConfigChild ();
+	ConfigMethod ();
+    }
     else {
 	(void) fprintf ( stderr, "Browser mode error\n" );
 	return;
     }
-    
-    /* Les bouttons */
-    y = GetBWheight(W_FILES) + ( 2 * B_INTER);
+*/    
+
+    y = B_INTER;
     
     XMoveWindow ( dpy, br.close, B_INTER, y );
     XMoveWindow ( dpy, br.dump, B_INTER + 2 + br.button_width, y );
@@ -769,6 +815,7 @@ void ConfigBrowser ( width, height )
     XMoveWindow ( dpy, br.pp,B_INTER + ( 7 * (2 + br.button_width)) , y );
     XMoveWindow ( dpy, br.hide,B_INTER + ( 8 * (2 + br.button_width)) , y );
     XMoveWindow ( dpy, br.edit,B_INTER + ( 9 * (2 + br.button_width)) , y );
+    XMoveWindow ( dpy, br.smac, B_INTER + ( 10 * (2 + br.button_width)), y );
 }
 
 
@@ -815,12 +862,28 @@ static void ConfigClass ()
 {
     BWin *bwin = &br.tbw[W_CLASS];
     
-    bwin -> x = B_INTER;
-    bwin -> y = B_INTER;
+    bwin -> y = (2*B_INTER) + br.button_height;
     bwin -> f_width = (br.width - ( 4*B_INTER )) / 3;
-    bwin -> f_height = GetBWheight(W_FILES);
+
+    if (strcmp ( br.mode -> name, "C++mode" ) == 0) {
+      bwin -> x = B_INTER;
+      bwin -> f_height = (2*GetBWheight(W_FILES))+B_INTER;
+    }
+    else if (strcmp ( br.mode -> name, "C-mode" ) == 0) {
+      bwin -> x = (2*B_INTER) + GetBWwidth(W_FILES);
+      bwin -> f_height = GetBWheight(W_FILES);
+    }
+    else if (strcmp ( br.mode -> name, "Java" ) == 0) {
+      bwin -> x = B_INTER;
+      bwin -> f_height = GetBWheight(W_FILES);
+    }
+    else
+      (void) fprintf ( stderr, "1 Browser mode error\n" );
+
+    XMoveResizeWindow ( dpy, bwin -> frame,
+		       bwin -> x, bwin -> y,
+		       bwin -> f_width, bwin -> f_height );
     
-    XResizeWindow ( dpy, bwin -> frame, bwin -> f_width, bwin -> f_height );
     XResizeWindow ( dpy, bwin -> title, bwin -> f_width, br.title_height ); 
     
     bwin -> m_width = bwin -> f_width - (2*B_SPACE);
@@ -841,10 +904,10 @@ static void ConfigParent ()
 {
     BWin *bwin = &br.tbw[W_PARENT];
     
-    bwin -> x = GetBWwidth(W_CLASS) + ( 2 * B_INTER );
-    bwin -> y = B_INTER;
-    bwin -> f_width = GetBWwidth(W_CLASS);
-    bwin -> f_height = ( GetBWheight(W_CLASS) - B_INTER ) / 2;
+    bwin -> x = GetBWwidth(W_FILES) + (2 * B_INTER);
+    bwin -> y = (2*B_INTER) + br.button_height;
+    bwin -> f_width = GetBWwidth(W_FILES);
+    bwin -> f_height = (GetBWheight(W_FILES) - B_INTER) / 2;
     
     XMoveResizeWindow ( dpy, bwin -> frame,
 		       bwin -> x, bwin -> y,
@@ -852,7 +915,7 @@ static void ConfigParent ()
     
     XResizeWindow ( dpy, bwin -> title, bwin -> f_width, br.title_height ); 
     
-    bwin -> m_width = GetBWmwidth(W_CLASS);
+    bwin -> m_width = GetBWmwidth(W_FILES);
     bwin -> m_height = bwin -> f_height - br.title_height - (2*B_SPACE);
     XResizeWindow ( dpy, bwin -> main, bwin -> m_width, bwin -> m_height );
     
@@ -871,8 +934,8 @@ static void ConfigChild ()
 {
     BWin *bwin =  &br.tbw[W_CHILD];
     
-    bwin -> x = GetBWwidth(W_CLASS) + ( 2 * B_INTER );
-    bwin -> y = GetBWheight(W_PARENT) + ( 2 * B_INTER);
+    bwin -> x = GetBWwidth(W_PARENT) + ( 2 * B_INTER );
+    bwin -> y = GetBWheight(W_PARENT) + ( 3 * B_INTER) + br.button_height;
     bwin -> f_width = GetBWwidth(W_PARENT);
     bwin -> f_height = GetBWheight(W_PARENT);
     
@@ -889,7 +952,6 @@ static void ConfigChild ()
     ConfigScroll ( &br.tbw[W_CHILD] );
 }
 
-
 /*
 **	Function name : ConfigFiles
 **
@@ -902,28 +964,40 @@ static void ConfigFiles ()
 {
     BWin *bwin = &br.tbw[W_FILES];
     
-    if (strcmp ( br.mode -> name, "C++mode" ) == 0){
+    if (strcmp (br.mode -> name, "C++mode") == 0) { 
 	bwin -> f_width = (br.width - ( 4*B_INTER )) / 3;
 	bwin -> f_height = 
+#ifdef WITH_BR_TITLE
 	  (br.height - 5 * B_INTER - br.title_height - br.button_height) / 3;
+#else
+	  (br.height - 5 * B_INTER - br.button_height) / 3;
+#endif
 	bwin -> x = ( 3 * B_INTER ) + ( (br.width - ( 4*B_INTER )) *2/ 3);
-	bwin -> y = B_INTER;
+	bwin -> y = (2*B_INTER)+br.button_height;
     }
-    else if ( (strcmp ( br.mode -> name, "Java" ) == 0)) {
+    else if (strcmp (br.mode -> name, "Java") == 0) {
 	bwin -> f_width = (br.width - ( 4*B_INTER )) / 3;
 	bwin -> f_height = 
+#ifdef WITH_BR_TITLE
 	  (br.height - (4 * B_INTER) - br.title_height - br.button_height) / 2;
+#else
+	  (br.height - (4 * B_INTER) - br.button_height) / 2;
+#endif
 	bwin -> x = ( 3 * B_INTER ) + ( (br.width - ( 4*B_INTER )) *2/ 3);
-	bwin -> y = B_INTER;
+	bwin -> y = (2*B_INTER)+br.button_height;
     }
-    else if ( strcmp ( br.mode -> name, "C-mode" ) == 0 ){
-	bwin -> f_width = (br.width - ( 3*B_INTER )) / 2;
-	bwin -> f_height = (br.height - ( 3*B_INTER ) - br.title_height - br.button_height );
-	bwin -> x = B_INTER;
-	bwin -> y = B_INTER;
+    else if (strcmp (br.mode -> name, "C-mode")==0) {
+	bwin -> f_width = (br.width - ( 4*B_INTER )) / 3;
+#ifdef WITH_BR_TITLE
+	bwin -> f_height = (br.height - ( 4*B_INTER ) - br.title_height - br.button_height );
+#else
+	bwin -> f_height = (br.height - ( 4*B_INTER ) - br.button_height )/2;
+#endif
+	bwin -> x = (3*B_INTER)+(2*bwin -> f_width);
+	bwin -> y = B_INTER + br.button_height + B_INTER;
     }
     else
-      (void) fprintf ( stderr, "Browser mode error\n" );
+      (void) fprintf ( stderr, "2 Browser mode error\n" );
     
     XMoveResizeWindow ( dpy, bwin -> frame, 
 		       bwin -> x, bwin -> y,
@@ -952,7 +1026,7 @@ static void ConfigMethod ()
     (void) fprintf ( stderr, "Config Methods\n" );
 #endif
     bwin -> x = B_INTER;
-    bwin -> y = GetBWy(W_CLASS) + GetBWheight(W_CLASS)
+    bwin -> y = GetBWy(W_CLASS) + GetBWheight(W_CLASS) + B_INTER;
       + br.button_height + ( 2 * B_INTER );
     bwin -> f_width = br.width - (3 * B_INTER) - GetBWwidth(W_FILES);
     bwin -> f_height = GetBWheight(W_FILES);
@@ -983,24 +1057,24 @@ static void ConfigProc ()
 {
     BWin *bwin = &br.tbw[W_PROC];
     
-    if ( (strcmp ( br.mode -> name, "C++mode" ) == 0)
-	|| (strcmp ( br.mode -> name, "Java" ) == 0)) {
-	bwin -> x = B_INTER;
-	bwin -> y = GetBWy(W_METHOD) + GetBWheight(W_METHOD) + B_INTER;
-	bwin -> f_width = GetBWwidth(W_METHOD);
+    if (strcmp(br.mode -> name, "C++mode") == 0) {
+	bwin -> x = B_INTER + GetBWwidth(W_CLASS) + B_INTER;
+	bwin -> y = B_INTER + br.button_height + B_INTER + GetBWheight(W_FILES) + B_INTER;
+	bwin -> f_width = GetBWwidth(W_FILES);
 	bwin -> f_height = GetBWheight(W_FILES);
 	bwin -> m_width = bwin -> f_width - ( 2 * B_SPACE );
     }
     else if ( strcmp ( br.mode -> name, "C-mode" ) == 0 ){
-	bwin -> x = (2 *B_INTER) + GetBWwidth(W_FILES);
-	bwin -> y = B_INTER;
+	bwin -> x = B_INTER;
+	bwin -> y = B_INTER + br.button_height + B_INTER;
 	bwin -> f_width = GetBWwidth(W_FILES);
-	bwin -> f_height = GetBWheight(W_FILES);
+	bwin -> f_height = (2*GetBWheight(W_FILES))+B_INTER;
 	bwin -> m_width = GetBWmwidth(W_FILES);
     }
-    else
-      (void) fprintf ( stderr, "Browser mode error\n" );
-    
+    else {
+      /* Java mode */
+      return;
+    }
     
     XMoveResizeWindow ( dpy, bwin -> frame,
 		       bwin -> x, bwin -> y,
@@ -1027,10 +1101,23 @@ static void ConfigAttributes ()
 {
     BWin *bwin = &br.tbw[W_ATTRIBUTES];
     
-    bwin -> x = GetBWx(W_FILES);
-    bwin -> y = GetBWy(W_METHOD);
-    bwin -> f_width = GetBWwidth(W_FILES);
-    bwin -> f_height = GetBWheight(W_METHOD);
+    
+    if ( (strcmp ( br.mode -> name, "C++mode" ) == 0)
+	|| (strcmp ( br.mode -> name, "Java" ) == 0)) {
+      bwin -> x = GetBWx(W_FILES);
+      bwin -> y = (3*B_INTER)+GetBWheight(W_CLASS)+br.button_height;
+      bwin -> f_width = GetBWwidth(W_FILES);
+      bwin -> f_height = GetBWheight(W_FILES);
+    }
+    else if ( strcmp ( br.mode -> name, "C-mode" ) == 0 ){
+      bwin -> x = (2*B_INTER)+GetBWwidth(W_FILES);
+      bwin -> y = (3*B_INTER)+GetBWheight(W_FILES)+br.button_height;
+      bwin -> f_width = GetBWwidth(W_FILES);
+      bwin -> f_height = GetBWheight(W_FILES);
+    }
+    else
+      (void) fprintf ( stderr, "4 Browser mode error\n" );
+    
     bwin -> m_width = bwin -> f_width - ( 2 * B_SPACE );
     
     XMoveResizeWindow ( dpy, bwin -> frame,
@@ -1057,10 +1144,23 @@ static void ConfigGlobals ()
 {
     BWin *bwin = &br.tbw[W_GLOBALS];
     
-    bwin -> x = GetBWx(W_ATTRIBUTES);
-    bwin -> y = GetBWy(W_PROC);
-    bwin -> f_width = GetBWwidth(W_ATTRIBUTES);
-    bwin -> f_height = GetBWheight(W_PROC);
+    if (strcmp(br.mode -> name, "C++mode") == 0) {
+      bwin -> x = GetBWx(W_FILES);
+      bwin -> y = GetBWy(W_PROC);
+      bwin -> f_width = GetBWwidth(W_FILES);
+      bwin -> f_height = GetBWheight(W_PROC);
+    }
+    else if (strcmp (br.mode -> name, "C-mode") == 0) {
+      bwin -> x = GetBWx(W_FILES);
+      bwin -> y = (3*B_INTER)+GetBWheight(W_FILES)+br.button_height;
+      bwin -> f_width = GetBWwidth(W_FILES);
+      bwin -> f_height = GetBWheight(W_FILES);
+    }
+    else {
+      /* Java mode */
+      return;
+    }
+    
     bwin -> m_width = bwin -> f_width - ( 2 * B_SPACE );
     
     XMoveResizeWindow ( dpy, bwin -> frame,
@@ -1118,21 +1218,24 @@ void DisplayBrowser()
     if ( strcmp ( br.mode -> name, "default" ) == 0 )
       br.mode = (Mode *) GetMode ("C++mode");
     
-    if ( (strcmp ( br.mode -> name, "C++mode" ) == 0)
+/*    if ( (strcmp ( br.mode -> name, "C++mode" ) == 0)
 	|| (strcmp ( br.mode -> name, "Java" ) == 0)) {
 	i = 0;
     }
     else if ( strcmp ( br.mode -> name, "C-mode" ) == 0 ){
-	i = C_FIRST_WIN;
+      i = C_FIRST_WIN;
     }
     else
       (void) fprintf ( stderr, "Browser mode error\n" );
-    
+*/    
     XMapWindow ( dpy, br.main );
+#ifdef WITH_BR_TITLE
     XMapWindow ( dpy, br.title );
+#endif
     XMapWindow ( dpy, br.close );
     XMapWindow ( dpy, br.rec );
     XMapWindow ( dpy, br.add );
+    XMapWindow ( dpy, br.smac );
     XMapWindow ( dpy, br.del );
     XMapWindow ( dpy, br.dec );      
     XMapWindow ( dpy, br.edit );
@@ -1141,12 +1244,16 @@ void DisplayBrowser()
     XMapWindow ( dpy, br.restore );
     XMapWindow ( dpy, br.hide );
     XMapRaised ( dpy, br.frame );
-    
-    for ( ;i < B_NB_WIN; i++ ) { 
+
+    for (i=0 ;i < B_NB_WIN; i++ ) { 
       if ((strcmp ( br.mode -> name, "Java" ) == 0)) {
 	if ((i == W_GLOBALS) || (i == W_PROC))
 	  continue;
       }
+      if ((strcmp ( br.mode -> name, "C-mode" ) == 0)) {
+	if ((i == W_METHOD) ||(i == W_PARENT) || (i == W_CHILD))
+	  continue;
+      }
       XMapSubwindows ( dpy, br.tbw[i].main ); 
       XMapSubwindows ( dpy, br.tbw[i].frame ); 
       XMapWindow ( dpy, br.tbw[i].main ); 
