@@ -55,8 +55,8 @@
 #define DEC_MODE	0
 
 #define B_BUTTON_WIDTH 	60
-#define B_INTER		10
-#define B_SPACE		5
+#define B_INTER		5
+#define B_SPACE		2
 
 #define W_CLASS	0
 #define W_PARENT	1
@@ -98,9 +98,13 @@ typedef struct _BWin {
 typedef struct _Browser {
 	int		width, height;	/* Larguer hauteur du browser */
 	unsigned long 	fg, bg, text_fg, text_bg;/* Les couleurs */
+#ifdef WITH_BR_TITLE
 	Window		frame, title, main;	/* Les fenetres principales */
+#else
+	Window		frame, main;	/* Les fenetres principales */
+#endif
 	char 		*title_name;	/* L'objet selectionne */
-	Window		dec,add, del, close, edit,pp;	/* Les boutons */
+	Window		dec,add, smac,del, close, edit,pp;	/* Les boutons */
 	Window		dump, restore, hide;	/* Les boutons */
 	BWin		tbw [B_NB_WIN];	/* Les fenetres de texte */
 	Buf 		*filebuf;	/* Pour les noms de fichiers */
