@@ -56,6 +56,7 @@
 #include "page.h"
 #include "ctr_version.h"
 #include "main_events.h"
+#include "tbox.h"
 
 char *menu_names[] = { 
 	"File", "Window", "Edit", "Modes", "Search", "Region", "Font", "Misc", 0
@@ -101,8 +102,8 @@ static char *mode_menu [] = {
 	"Select Html mode",
 
         "Select Perl mode",
-	"Select Ada mode",
-	"Select Fortran mode",
+/*	"Select Ada mode",
+	"Select Fortran mode", */
 	
 	"Select shell-script mode",
 	"Execute a sub Shell",
@@ -132,8 +133,9 @@ static char *mark_menu [] = {
 	"Paste region              ^y",
 	"Indent region          Esc i",
 	"Eval region            Esc e",
-	"Color buffer            ^x a",
-	"Color region                ",
+	"Highlight text buffer   ^x a",
+	"Highlight text region       ",
+	"No highlighting text        ",
 	"Current line to top    Esc t",
 	0
 };
@@ -159,6 +161,7 @@ static char *font_menu [] = {
 	"Courier bold 14",
 	"Courier medium 10",
 	"Courier medium 12",
+/*	"Default (fixed) 13", */
 	"Courier medium 14",
 	"Courier medium 18",
 	"Helvetica 10",
@@ -190,21 +193,16 @@ static char *font_names [] = {
 };
 
 static char *misc_menu [] = {
-/*  
-	"New C++ class",
-	"New C++ method",
-	"New C function",
-	"New include header",
-*/
-  "Programming util...",
-  "Rcs commands...",
-  "Latex commands...",
-  "Html commands...",
-  "Misc commands...",
-  "User commands...",
-  "Load and eval file",
+  "Programming util... ",
+  "Rcs commands...     ",
+  "Latex commands...   ",
+  "Html commands...    ",
+  "Misc commands...    ",
+  "User commands...    ",
+  "Load and eval file  ",
   "Eval expression ^x^e",
-  "Xcoral release",
+  "Hanoi towers demo   ",
+  "Authors",
   "Help",
 0
 };
@@ -216,7 +214,6 @@ char **item_names [] = {
 	mode_menu,
 	search_menu,
 	mark_menu,
-/*	version_menu, */
 	font_menu,
 	misc_menu,
 	0
@@ -250,7 +247,6 @@ static void (*f_edit []) () = {
   DeleteBytesFromCutBuffer,
   PasteSelection,
   DisplayKillBuffer,
-/*  Yank, */
   0
 };
 
@@ -263,8 +259,8 @@ static void (*f_mode []) () = {
 	SetHtmlMode,
 
         SetPerlMode,
-	SetAdaMode,
-	SetFortranMode,
+/*	SetAdaMode,
+	SetFortranMode, */
 	
 	SetshellMode,
 	SetShellMode,
@@ -296,6 +292,7 @@ static void (*f_mark []) () = {
 	EvalRegion,
 	ColorBuffer,
 	ColorRegion,
+	RemoveColors,
 	CurrentLineToTopFromMenu,
 	0
 };
@@ -320,12 +317,6 @@ static void (*f_font []) () = {
 };
 
 static void (*f_misc []) () = {
-/*  
-	ClassHeader,
-	MethodHeader,
-	FunctionHeader,
-	IncludeHeader,
-*/
   ProgrammingUtil,
   RcsCommands,
   LatexMacros,
@@ -334,7 +325,8 @@ static void (*f_misc []) () = {
   UserCommands,
   LoadAndEvalFile,
   EvalExpressionFromMenu,
-  Version,
+  Hanoi,  
+  DisplayTrombines,
   DisplayManBox,
   0
 };
