@@ -45,16 +45,41 @@
 #include <X11/Xatom.h>
 #include <X11/keysym.h>
 #include <ctype.h>
-#include <string.h>
-#include <sys/time.h>
 #include <signal.h>
+#include <sys/types.h>
 
-#ifndef apollo
-#ifdef __FreeBSD__
-#include <stdlib.h>
-#else /* !__FreeBSD__ */
-#include <malloc.h>
+#if HAVE_STRING_H
+#include <string.h>
+#else
+#include <strings.h>
 #endif
+
+#if STDC_HEADERS
+#  include <stdlib.h>
+#else
+#  if HAVE_MALLOC_H
+#    include <malloc.h>
+#  endif
+#endif
+
+#if HAVE_UNISTD_H
+#  include <unistd.h>
+#endif
+
+#if HAVE_POLL
+#  include <stropts.h>
+#  include <poll.h>
+#endif
+
+#if TIME_WITH_SYS_TIME
+#  include <sys/time.h>
+#  include <time.h>
+#else
+#  if HAVE_SYS_TIME_H
+#    include <sys/time.h>
+#  else
+#    include <time.h>
+#  endif
 #endif
 
 #include "main_text.h"
@@ -72,7 +97,7 @@ extern Display *dpy;
 static int toggle_del = 0;
 extern char *ie_call_function();
 
-FCT (static void, donothing, () );
+FCT (static RETSIGTYPE, donothing, () );
 
 static char *cut_buffer = 0;
 static int n_cb = 0;
@@ -718,7 +743,7 @@ void DeleteBytesFromCutBuffer ( text )
   }
 }
 static int timer_expire = False;
-static void donothing () { timer_expire = True; }
+static RETSIGTYPE donothing () { timer_expire = True; }
 
 
 /*
@@ -731,37 +756,28 @@ static void donothing () { timer_expire = True; }
 void SmallTime ( t )
     long t; /* micros-secondes */
 {
-  struct itimerval value;
-#if defined(SVR4) || defined(UNIXWARE)  
+#if HAVE_USLEEP
   usleep(t);
-#else
-#ifdef NOTDEF
-  value.it_interval.tv_sec = 0;
-  value.it_interval.tv_usec = 0;
-  value.it_value.tv_sec = 0;
-  value.it_value.tv_usec = t;
 
-  timer_expire = False;
-  (void) signal ( SIGALRM, (void (*) ()) donothing );
-  (void) setitimer ( ITIMER_REAL, &value, (struct itimerval *) 0 );
-  while(1) {
-    sigblock(sigmask(SIGALRM));
-    if ( timer_expire )
-      break;
-    else
-      sigpause(0);
-  }
-  sigblock(0);
-  (void) signal ( SIGALRM, SIG_IGN );
-#else
-	/* best way to do it... portable, too... */
-  struct timeval timeout;
+#elif HAVE_SELECT
+  struct timeval delay;
 
-  timeout.tv_sec = 0;
-  timeout.tv_usec = t;
+  delay.tv_sec  = 0;
+  delay.tv_usec = t;
+  select(0, NULL, NULL, NULL, &delay);
+
+#elif HAVE_NANOSLEEP
+  struct timespec rqtp;
+
+  rqtp.tv_sec  = t / (unsigned long)  1000000;
+  rqtp.tv_nsec = (t % (unsigned long) 1000000) * 1000 ;
+  nanosleep(&rqtp, NULL);
+
+#else  /* Use default poll */
+  struct pollfd unused;
+
+  poll(&unused,0,(t / 1000)); 
 
-  select(0, NULL, NULL, NULL, &timeout);
-#endif
 #endif
 }
 
@@ -865,7 +881,8 @@ void ProgrammingUtil(text)
   int nw = text->win_id;
 
   StorePosition ( text );
-  msg = (char *) ie_call_function ( text, "add_header", 0, 0) ;
+/*  msg = (char *) ie_call_function ( text, "add_header", 0, 0) ;*/
+  msg = (char *) ie_call_function ( text, "programming_utilities", 0, 0) ;
   text = update_cwd(nw);
   if ( msg != 0 )
     DisplayMessage ( text -> mwin, msg );
@@ -1103,75 +1120,6 @@ void QuotedChar( text )
 	}
     }
 }
-#ifdef SVR4
-/*
- *      usleep(delay)  --
- *
- *      Possible usleep replacement. Delay in microseconds.
- *      Another possiblity is to use poll(2). On Solaris
- *      2.x, select is just a wrapper for poll, so you
- *      are better off using it directly.  If you use,
- *      poll, note that it uses millisecond resolution,
- *      and is not affected by the O_NDELAY and O_NONBLOCK 
- *      flags.
- *
- *      Note that using nanosleep has portability implications,
- *      even across different versions of Solaris 2.x. In
- *      particular, only Solaris 2.3 has libposix4, and 
- *      hence nanosleep. Select (or poll) is a better option if 
- *      you need portability across those versions.
- *
- *      If you define USE_NANOSLEEP, be sure to link with -lposix4
- *
- *      This function is taken from the Solaris 2.x Porting FAQ
- */
-#include <unistd.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include <errno.h>
-#include <time.h>
-#include <sys/time.h>
-#include <sys/param.h>
-#include <sys/types.h>
-#ifdef  USE_POLL
-#include <stropts.h>
-#include <poll.h>
-#endif  /* USE_POLL */
-
-int usleep(useconds)
-    unsigned long int useconds;
-{
-#ifdef  USE_NANOSLEEP
-  struct timespec rqtp;
-
-  rqtp.tv_sec  = useconds / (unsigned long)  1000000;
-  rqtp.tv_nsec = (useconds % (unsigned long) 1000000) * 1000 ;
-
-  if (nanosleep(&rqtp,  (struct  timespec *) NULL) == -1)
-    perror("nanosleep");
-  return (0);
-
-#elif   USE_POLL
-  struct pollfd unused;
-
-  if (poll(&unused,0,(useconds/1000)) == -1) 
-    perror("poll");
-  return(0);
-#else  /* default to select */
-  struct timeval delay;
-
-  delay.tv_sec = 0;
-  delay.tv_usec = useconds;
-  if (select(0,
-             (fd_set *) NULL,
-             (fd_set *) NULL,
-             (fd_set *) NULL,
-             &delay) == -1)
-    perror("select");
-  return (0);
-#endif /* USE_NANOSLEEP */
-}
-#endif /* SVR4 */
 
 /*
 **	Function name : Store_bytes
