@@ -41,12 +41,20 @@
 #include <stdio.h>
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
-#ifdef __FreeBSD__
-#include <stdlib.h>
-#else /* !__FreeBSD__ */
-#include <malloc.h>
+
+#if STDC_HEADERS
+#  include <stdlib.h>
+#else
+#  if HAVE_MALLOC_H
+#    include <malloc.h>
+#  endif
 #endif
+
+#if HAVE_STRING_H
 #include <string.h>
+#else
+#include <strings.h>
+#endif
 
 #include "main_text.h"
 #include "color_area.h"
@@ -58,6 +66,8 @@ extern Display *dpy;
 #define DEBUG2
 #define DEBUG
 */
+
+
 FCT (static void, InsertInsideElement, (Text *text, ColorElement *new_ce, ColorElement *ce) );
 FCT (static void, InsertWithRightElement, (Text *text, ColorElement *new_ce, ColorElement *ce) );
 FCT (static void, InsertWithLeftElement, (Text *text, ColorElement *new_ce, ColorElement *ce) );
@@ -68,6 +78,14 @@ FCT (static void, DeleteColorElement, (Text *text, ColorElement *ce ) );
 FCT (static void, IncrColorList, (Text *text, int nbytes) );
 FCT (static void, DecrColorList, (Text *text, int nbytes) );
 
+static PrivateCmap pcmap[32];
+
+InitPcmap ()
+{
+  int i=0;
+  for (i=0;i<32;i++){pcmap[i].colorname[0]='\0';pcmap[i].pixelvalue=0;}
+}
+
 /*
 **	Function name : SetColorArea
 **
@@ -85,20 +103,47 @@ void SetColorArea ( text, start, end, colorname )
     char *colorname;
 {
     ColorElement *new_ce, *tmp, *tmp1;
-    int e_file = ie_end_of_file(text);
+    int i, e_file = ie_end_of_file(text);
     extern Display *dpy;
     XColor  color, tcolor;
-    int status;
+    int status, color_status;
     
+#ifdef DEBUG    
+	(void) fprintf (stderr,"SetColorArea\n");
+#endif /* DEBUG */    
     if ( (! TextInBuf (text)) || ((e_file-1) < end) )
       return;
-    
-    status = XAllocNamedColor ( dpy,
+
+    color_status=False;
+    for (i=0;i<32;i++){
+      if (pcmap[i].colorname[0]!='\0'){
+/*	printf("cmap color=%s cmap value=%d\n",pcmap[i].colorname,pcmap[i].pixelvalue); */
+	if (strcmp(pcmap[i].colorname,colorname)==0){
+	  /* C'est la bonne couleur */
+	  color.pixel=pcmap[i].pixelvalue;
+	  color_status=True;
+	  break;
+	}
+      }
+    }
+    if (color_status==False) {
+/*      printf ("Alloc color colorname=%s\n",colorname); */
+      status = XAllocNamedColor ( dpy,
 	       DefaultColormap ( dpy, DefaultScreen ( dpy ) ), 
 	       colorname, &color, &tcolor );
+      if (status==False)
+	return;
+      for (i=0;i<32;i++){
+	if (pcmap[i].colorname[0]=='\0'){
+	  strcpy(pcmap[i].colorname,colorname);
+	  pcmap[i].pixelvalue=color.pixel;
+	  break;
+	}
+      }
+    }
 
-    if ( status == False )
-      return;
+/*    if ( status == False )
+      return; */
 
     new_ce = CreateColorElement ( start, end, (unsigned long) color.pixel );
     
@@ -378,10 +423,12 @@ static void DeleteColorElement ( text, ce )
 	   text -> current_ce = 0;
 	}
     }
+
 #ifdef DEBUG    
-    (void) fprintf (stderr,"Free %d\n", ce);
+    (void) fprintf (stderr,"DeleteColorElement Free %d\n", ce);
     DisplayColorList (text);
-#endif /* DEBUG */    
+#endif /* DEBUG */
+
     (void) free (ce);
 }
 
@@ -403,15 +450,15 @@ static void DisplayColorList (text)
       return;
     }
 
-    (void) fprintf ( stderr, "\tce = %d ce -> previous %d\n", 
-		    tmp, tmp -> previous );
+/*    (void) fprintf ( stderr, "\tce = %d ce -> previous %d\n", 
+		    tmp, tmp -> previous ); */
     while (tmp -> previous != 0) {
       tmp = tmp -> previous;
     }
 
     /* On est bien sur le premier element de la liste */
     do {
-      (void) fprintf ( stderr, "======tmp %d pos = %d len = %d\n",
+      (void) fprintf ( stderr, "DisplayColorList======tmp %d pos = %d len = %d\n",
 		      tmp, tmp -> pos, tmp -> len );
       tmp = tmp -> next;
     } while (tmp != 0);
@@ -446,7 +493,7 @@ void DeleteColorList ( text )
       todel = tmp;
       tmp = tmp -> previous;
 #ifdef DEBUG
-      (void) fprintf ( stderr, "free %d\n", todel );
+      (void) fprintf ( stderr, "DeleteColorList free %d\n", todel );
 #endif /* DEBUG */    
       (void) free (todel);
     } while (tmp != 0) ;
@@ -471,9 +518,21 @@ void UpdateColorList ( text, nbytes )
 
     if ( nbytes == 0 || tmp == 0 || text -> current_ce == 0 )
       return;
-    
-    if ( nbytes > 0 )
+
+#ifdef DEBUG    
+	    (void) fprintf (stderr,"UpdateColorList\n");
+#endif /* DEBUG */    
+
+    if ( nbytes > 0 ) {
       IncrColorList (text, nbytes);
+      if (nbytes > 1) {
+	int args[2];
+	
+	args[0] = ie_current_position(text)-nbytes;
+	args[1] = ie_current_position(text);
+	(void) ie_call_function ( text, "color_internal", 2, args);
+      }
+    }
     else
       DecrColorList (text, -nbytes);
 }
@@ -492,47 +551,37 @@ static void IncrColorList (text, nbytes)
     ColorElement *tmp = text -> last_ce;
     int pos_before;
 
-/* #define DEBUG */
-
     pos_before = ie_current_position (text) - nbytes;
+#ifdef DEBUG    
+    (void) fprintf (stderr,"IncrColorList pb = %d, nbytes = %d tmppos = %d tmplen = %d\n", 
+		    pos_before,  nbytes, tmp->pos, tmp->len);
+#endif /* DEBUG */    
 
-    /*
-       Il faut remonter jusqu'a la position
-       courante en modifiant la position de chaque element.
-    */  
+    /* Il faut remonter jusqu'a la position courante en modifiant 
+       la position de chaque element. */  
     do {
 	if ((tmp -> pos + tmp -> len -1) < pos_before) {
-	    /* L'element courant est strictement la 
-	       position de l'element ajoute.
-	       Donc on ne va pas plus loin.
-	    */
+	    /* La fin de l'element courant est strictement avant la position
+	       d'origine avant l'ajout des nbytes. Donc on ne va pas plus loin. */
 #ifdef DEBUG    
     (void) fprintf (stderr,"1 Incr. [el] est avant Pos\n");
 #endif /* DEBUG */    
 	  break;
 	}
-	else if (tmp -> pos == pos_before) {
-	    /*
-	       On est sur le debut d'un element de couleur.
-	       On change simplement la position de l'element.
-	    */
-	    tmp -> pos += nbytes;
-#ifdef DEBUG    
-    (void) fprintf (stderr,"2 Incr. Pos == debut\n");
-#endif /* DEBUG */    
-	}	    
 	else if ((tmp -> pos < pos_before)
 	    && ((tmp -> pos + tmp -> len -1) >= pos_before)) {
-	    /* 
-	       On est strictement a l'interieur d'un element de couleur.
-	       Il faut simplement incrementer la longueur de l'element.
-	    */
+	    /* On est strictement a l'interieur d'un element de couleur,
+	       ou juste sur la fin de cet element.
+	       Il faut simplement incrementer la longueur de l'element. */
 	    tmp -> len += nbytes;
 #ifdef DEBUG    
     (void) fprintf (stderr,"3 Incr in Color List. Pos est dans [el] \n");
 #endif /* DEBUG */    
 	}
-	else if (tmp -> pos > pos_before){
+	else if (tmp -> pos >= pos_before){
+	  /* La position de l'element est avant la position courante d'origine,
+	     avant d'inserer les nbytes ou elgale a celle_ci.
+	     On incremente simplement la position de cet element */
 	    tmp -> pos += nbytes;
 #ifdef DEBUG    
     (void) fprintf (stderr,"4 Incr. [el] est apre Pos\n");
@@ -541,14 +590,13 @@ static void IncrColorList (text, nbytes)
 	else
 	  ;
 #ifdef DEBUG    
-    (void) fprintf (stderr,"Incr len = %d pos = %d\n",
-		    tmp -> len, tmp -> pos);
+	(void) fprintf (stderr,"Incr len = %d pos = %d\n", tmp -> len, tmp -> pos);
 #endif /* DEBUG */    
 	tmp = tmp -> previous;
     } while (tmp != 0) ;
 
 #ifdef DEBUG    
-    /* DisplayColorList (text); */
+    DisplayColorList (text);
 #endif /* DEBUG */    
 }
 
@@ -567,11 +615,13 @@ static void DecrColorList (text, nbytes)
     ColorElement *ce;
     ColorElement *tmp = text -> last_ce;
     int pos_before, pos_after;
+
+#ifdef DEBUG    
+	    (void) fprintf (stderr,"DecrColorList\n");
+#endif /* DEBUG */
   
     pos_before = ie_current_position (text) + nbytes;
     pos_after = pos_before - nbytes;
-
-/* #define DEBUG */
     
     /* On parcout la liste de elements colories en partant
        du dernier. On s'arrete lorsque l'element courant
@@ -584,25 +634,18 @@ static void DecrColorList (text, nbytes)
 #ifdef DEBUG    
 	    (void) fprintf (stderr,"Bye [el] < pos\n");
 #endif /* DEBUG */
-	    /* 1 On se casse, la position de l'element courant est
-	       strictement avant la position courante
-	       
-	       ---++++++++++---********--------
-	                       p      pb
-	    */
+	    /* On se casse, la fin de l'element courant est strictement 
+	       avant la position courante. */
 	    break;
 	}
 	else if ((tmp -> pos >= pos_after)
 		 && ((tmp -> pos + tmp -> len -1) < pos_before)) {
-	    /* 2 On doit enlever cet element 
-	       ---++++++++++********--------
-	          p                  pb
-	    */ 
+	    /* On doit enlever cet element. La position courante est avant
+	       ou au debut de l'element mais la fin de l'element est strictement 
+	       avant la position d'origine (avant d'enlever les nbytes) */ 
 #ifdef DEBUG
-	    (void) fprintf (stderr,"Remove [el]\n");
-	    (void) fprintf (stderr,"  pos <= [el] < pos_before rm\n");
+	    (void) fprintf (stderr,"Remove [el] pos <= [el] < pos_before rm\n");
 #endif /* DEBUG */
-	    
 	    if (tmp -> previous) {
 	      (tmp -> previous) -> next = (ColorElement *) tmp -> next;
 #ifdef DEBUG    
@@ -630,7 +673,11 @@ static void DecrColorList (text, nbytes)
 	    }
 	    
 	    /* On enleve l'element et on met les liens a jour. */
-	    ce = tmp -> previous;
+/*	    if (! (ce = tmp->previous))
+	      ce = tmp->next;
+	    text -> current_ce = ce; */
+
+	    ce = tmp -> previous; 
 	    if ((text -> current_ce = tmp) != 0)
 	      text -> current_ce = tmp -> previous;
 	    (void) free (tmp);
@@ -651,7 +698,8 @@ static void DecrColorList (text, nbytes)
 	      p      pb 
 	    */
 #ifdef DEBUG    
-	    (void) fprintf (stderr,"  3 pos < [el], update pos : -nbytes\n");
+	    (void) fprintf (stderr,"  3 pos < [el], update pos[%d] - %d\n",
+			    tmp->pos, nbytes);
 #endif /* DEBUG */    
 	}
 	else if ((tmp -> pos <= pos_after)
@@ -699,12 +747,12 @@ static void DecrColorList (text, nbytes)
 #endif /* DEBUG */    
 	  ;
 	}
-
 	tmp = tmp -> previous;
     } while (tmp != 0);
 #ifdef DEBUG    
-/*    DisplayColorList (text); */
-#endif /* DEBUG */    
+    (void) fprintf (stderr,"___________\n");
+    DisplayColorList (text);
+#endif /* DEBUG */
 }
 
 /*
@@ -724,240 +772,246 @@ void ColorLineInPage ( text, x, y, line, s, n )
     char *s;
     int n;
 {
-    int pos; /* Position de s au sens SMAC */
-    ColorElement *tmp = 0;
-    int nce, fnext, fprevious;
+  int pos; /* Position de s au sens SMAC */
+  int len;
+  ColorElement *tmp = 0;
+  int nce, fnext, fprevious;
+  char *p;
+  /* #define DEBUG */
+  /* DEBUG */
+  if ( text -> current_ce == 0 )
+    return;
+  
+#ifdef DEBUG
+  (void) fprintf (stderr,"LIGNE %d n1 = %d\n", line, text -> n1);
+  (void) write (1,s,n);
+  (void) write (1,"\n",1);
+#endif /* DEBUG */
+  
+  if ( line == text -> n1 + 1 ) {
+    /*
+       *  On est sur la ligne du curseur.
+       *  Le pointeur s ne correspond pas a une position dans
+       *  le buffer. En fait il pointe sur une copie de la ligne
+       *  courante. Il faut donc rechercher le debut de la ligne
+       *  et ajouter eventuellement hs_delta dans le cas d'une
+       *  ligne scrollee horizontalement;
+       pos = ie_beginning_of_line(text) + text -> page.hs_delta;
+    */
+
+    /* On recherche le nombre de caracteres du debut de la chaine jusqu'a la
+       fin de la ligne pour calculer pos avec ou sans tab dans la ligne courante */
+    len=0;
+    p = s;
+    while (*p!='\0') {len ++;p ++;}
+    pos= ie_end_of_line(text) - len+1;
     
-    /* DEBUG */
-    if ( text -> current_ce == 0 )
-      return;
-
 #ifdef DEBUG
-    (void) fprintf (stderr,"LIGNE %d n1 = %d\n", line, text -> n1);
-    (void) write (1,s,n);
-    (void) write (1,"\n",1);
-#endif DEBUG    
-
-    if ( line == text -> n1 + 1 ) {
-	/*
-	   On est sur la ligne du curseur.
-	   Le pointeur s ne correspond pas a une position dans
-	   le buffer. En fait il pointe sur une copie de la ligne
-	   courante. Il faut donc rechercher le debut de la ligne
-	   et ajouter eventuellement hs_delta dans le cas d'une
-	   ligne scrollee horizontalement;
-	*/
-	pos = ie_beginning_of_line(text) + text -> page.hs_delta;
-
-	if (ie_the_char(text,pos) != *s) {
-	  /* on est apres un tab, il faut donc se placer apres */
-	  while (ie_the_char(text,pos) != '\t') {
-	    pos++;
-	  }
-	}
-	/*
-	   Si ya des tab au debut de la ligne ,
-	   il ne faut pas en tenir compte
-	*/
-	while (ie_the_char(text,pos) == '\t') {
-	    pos++;
-	}
+    (void) fprintf (stderr,"current line = %d n=%d pos = %d hs = %d char = %c s=%s\n",
+		    line, n, pos, text -> page.hs_delta, ie_the_char(text,pos),s);
+#endif /* DEBUG */
+  }
+  else {
+    /*
+       s correspond bien a une position dans le buffer.
+       Deux cas sont possibles : s est avant ou apres la bulle.
+    */
+    if ( s <= LeftBuf(text->buf) 
+	&& LeftBuf(text->buf) != TopBuf(text->buf)) {
+      pos = s - TopBuf(text->buf);
 #ifdef DEBUG
-    (void) fprintf (stderr,"\tcurrent line = %d pos = %d hs = %d char = %c\n",
-		    line, pos, text -> page.hs_delta, ie_the_char(text,pos));
+      (void) fprintf (stderr,"\tleft line = %d pos = %d char = %c\n",
+		      line, pos, ie_the_char(text,pos));
 #endif /* DEBUG */
     }
     else {
-	/*
-	   s correspond bien a une position dans le buffer.
-	   Deux cas sont possibles : s est avant ou apres la bulle.
-	 */
-	if ( s <= LeftBuf(text->buf) 
-	    && LeftBuf(text->buf) != TopBuf(text->buf)) {
-	    pos = s - TopBuf(text->buf);
+      if ( LeftBuf(text->buf) != TopBuf(text->buf)) {
 #ifdef DEBUG
-    (void) fprintf (stderr,"\tleft line = %d pos = %d char = %c\n",
-		    line, pos, ie_the_char(text,pos));
+	printf("!= top\n");
 #endif /* DEBUG */
-	}
-	else {
-	    if ( LeftBuf(text->buf) != TopBuf(text->buf))
-	      pos = s - RightBuf(text->buf) 
-		+ (LeftBuf(text->buf)-TopBuf(text->buf)) + 1;
-	    else
-	      pos = s - RightBuf(text->buf);
+	pos = s - RightBuf(text->buf) 
+	  + (LeftBuf(text->buf)-TopBuf(text->buf)) + 1;
+      }
+      else {
+	/* curseur au debut du buffer */
 #ifdef DEBUG
-    (void) fprintf (stderr,"\tright line = %d pos = %d char = %c\n",
-		    line, pos, ie_the_char(text,pos));
+	printf("== top\n");
+#endif /* DEBUG */
+	pos = s - RightBuf(text->buf) + 1; /* +1 16 Juillet 2000 */
+      }
+#ifdef DEBUG
+      (void) fprintf (stderr,"\tright line = %d pos = %d char = %c\n",
+		      line, pos, ie_the_char(text,pos));
 #endif /* DEBUG */
-	}
     }
-    
-    /*
-       A partir de la, on doit donc afficher une ligne
-       de 'n' caracteres commencant a la position pos (SMAC).
-       Il faut donc rechercher les elements de couleurs
-       compris totalement ou partiellement dans les 
-       bornes pos et pos + n.
-       On cherche donc le premier element concerne.
-    */
-    tmp = text -> current_ce;
-    
-    fnext = False;
-    fprevious = False;
-    for(;;) {
-	if ((pos >= tmp -> pos) && (pos <= (tmp -> pos + tmp -> len -1))) {
-	    /* 	Trouve, le debut de la ligne est a l'interieur d'un element. */
+  }
+  
+  /*
+     A partir de la, on doit donc afficher une ligne
+     de 'n' caracteres commencant a la position pos (SMAC).
+     Il faut donc rechercher les elements de couleurs
+     compris totalement ou partiellement dans les 
+     bornes pos et pos + n.
+     On cherche donc le premier element concerne.
+  */
+  /*    printf("pos = %d c=%c\n",pos, ie_the_char(text,pos)); */
+  tmp = text -> current_ce;
+  
+  fnext = False;
+  fprevious = False;
+  for(;;) {
+    if ((pos >= tmp -> pos) && (pos <= (tmp -> pos + tmp -> len -1))) {
+      /* 	Trouve, le debut de la ligne est a l'interieur d'un element. */
 #ifdef DEBUG
-    (void) fprintf (stderr,"\tLe debut de la ligne est a l'interieur d'un element\n");
+      (void) fprintf (stderr,"\tLe debut de la ligne est a l'interieur d'un element\n");
 #endif /* DEBUG */    
-	    break;
-	}
-	else if ((tmp -> pos > pos) && (tmp -> pos <= (pos + n -1))) {
-	    /* Un element de couleur commence dans la ligne. */
+      break;
+    }
+    else if ((tmp -> pos > pos) && (tmp -> pos <= (pos + n -1))) {
+      /* Un element de couleur commence dans la ligne. */
 #ifdef DEBUG
-    (void) fprintf (stderr,"\tUn element de couleur commence dans la ligne.\n");
+      (void) fprintf (stderr,"\tUn element de couleur commence dans la ligne.\n");
 #endif /* DEBUG */    
-	    if ( tmp -> previous == 0 || fnext ) {
+      if ( tmp -> previous == 0 || fnext ) {
 #ifdef DEBUG
-    (void) fprintf (stderr,"\t\tPas d'element avant ou on en vient\n");
+	(void) fprintf (stderr,"\t\tPas d'element avant ou on en vient\n");
 #endif /* DEBUG */    
-		break;
-	    }
-	    /* Allons voir si le precedent est toujours dans la ligne. */
-	    tmp = tmp -> previous;
-	    fnext = False;
-	    fprevious = False;
-	    continue;
-	}
-	else if (pos > (tmp -> pos + tmp -> len -1)) {
-	    /* On va plus loin si possible */
+	break;
+      }
+      /* Allons voir si le precedent est toujours dans la ligne. */
+      tmp = tmp -> previous;
+      fnext = False;
+      fprevious = False;
+      continue;
+    }
+    else if (pos > (tmp -> pos + tmp -> len -1)) {
+      /* On va plus loin si possible */
 #ifdef DEBUG
-    (void) fprintf (stderr,"\tOn va plus loin si possible\n");
+      (void) fprintf (stderr,"\tOn va plus loin si possible\n");
 #endif /* DEBUG */    
-	    if ( (fprevious == True)
-		|| ((tmp = tmp -> next) == 0)
-		|| ((pos + n -1) < tmp -> pos) ) {
-		/* 
-		   Pas d'element de couleur dans la ligne
-		*/
-		tmp = 0;
+      if ( (fprevious == True)
+	  || ((tmp = tmp -> next) == 0)
+	  || ((pos + n -1) < tmp -> pos) ) {
+	/* 
+	   Pas d'element de couleur dans la ligne
+	*/
+	tmp = 0;
 #ifdef DEBUG
-    (void) fprintf (stderr,"\t\tPlus loin si possible...pas d'element dans la ligne\n");
+	(void) fprintf (stderr,"\t\tPlus loin si possible...pas d'element dans la ligne\n");
 #endif /* DEBUG */    
-		break;
-	    }
-	    fnext = True;
-	}
-	else if ((pos + n -1) < tmp -> pos) {
-	    /* On va sur l'element precedent si possible */
+	break;
+      }
+      fnext = True;
+    }
+    else if ((pos + n -1) < tmp -> pos) {
+      /* On va sur l'element precedent si possible */
 #ifdef DEBUG
-    (void) fprintf (stderr,"\tOn va sur l'element precedent si possible\n");
+      (void) fprintf (stderr,"\tOn va sur l'element precedent si possible\n");
 #endif /* DEBUG */    
-	    if ( (fnext == True)
-		|| ((tmp = tmp -> previous) == 0)
-		|| ((tmp -> pos + tmp -> len -1) < pos) ) {
-		/* 
-		   Pas d'element de couleur dans la ligne.
-		*/
-		tmp = 0;
+      if ( (fnext == True)
+	  || ((tmp = tmp -> previous) == 0)
+	  || ((tmp -> pos + tmp -> len -1) < pos) ) {
+	/* 
+	   Pas d'element de couleur dans la ligne.
+	*/
+	tmp = 0;
 #ifdef DEBUG
-    (void) fprintf (stderr,"\t\tElement precedent...pas d'element dans la ligne\n");
+	(void) fprintf (stderr,"\t\tElement precedent...pas d'element dans la ligne\n");
 #endif /* DEBUG */  
-		break;
-	    }
-	    fprevious = True;
-	}
-	else {
-	  ; /* Brrrr.... */
+	break;
+      }
+      fprevious = True;
+    }
+    else {
+      ; /* Brrrr.... */
 #ifdef DEBUG
-	  (void) fprintf (stderr,"BRRR...\n");
+      (void) fprintf (stderr,"BRRR...\n");
 #endif /* DEBUG */
-	}
     }
-    
-    if ( tmp == 0 ) {
-	XDrawImageString ( dpy, text -> window, text -> Cgc, x, y, s, n );
+  }
+  
+  if ( tmp == 0 ) {
+    XDrawImageString ( dpy, text -> window, text -> Cgc, x, y, s, n );
 #ifdef DEBUG
-	(void) fprintf (stderr,"\tPas d'elements de couleur\n");
-#endif DEBUG    
-	return;
-    }
-    text -> current_ce = tmp;
-    /*
-       L'element de couleur trouve est le plus pres de la ligne
-       a afficher ou bien il se trouve a l'interieur de celle-ci,
-       partiellement ou totalement.
-    */
-    while ( n > 0 ) {
+    (void) fprintf (stderr,"\tPas d'elements de couleur\n");
+#endif /* DEBUG */
+    return;
+  }
+  text -> current_ce = tmp;
+  /*
+     L'element de couleur trouve est le plus pres de la ligne
+     a afficher ou bien il se trouve a l'interieur de celle-ci,
+     partiellement ou totalement.
+  */
+  while ( n > 0 ) {
 #ifdef DEBUG
     (void) fprintf (stderr,"tmp = %d pos = %d\n", tmp, pos);
-#endif DEBUG    
-	if (pos == tmp -> pos) {
-	    /* La position courante est sur un element de couleur */
-	    if (n >= tmp -> len)
-	      nce = tmp -> len;
-	    else
-	      nce = n;
-	    XSetForeground (dpy, text -> Cgc, tmp -> color );
-	    XDrawImageString ( dpy, text -> window, text -> Cgc, x, y, s, nce );
-	    XSetForeground ( dpy, text -> Cgc, text -> fg );
-#ifdef DEBUG
-	    (void) fprintf (stderr,"\tpos est sur le debut d'un element de couleur\n");
-	    write(1,s,nce);
-	    write(1,"\n",1);
 #endif /* DEBUG */
-	}
-	else if (pos > tmp -> pos ) {
-	    nce = tmp -> len - (pos - tmp -> pos);
-	    if (nce > n)
-	      nce = n;
-	    XSetForeground (dpy, text -> Cgc, tmp -> color );
-	    XDrawImageString ( dpy, text -> window, text -> Cgc, x, y, s, nce );
-	    XSetForeground ( dpy, text -> Cgc, text -> fg );
+    if (pos == tmp -> pos) {
+      /* La position courante est sur un element de couleur */
+      if (n >= tmp -> len)
+	nce = tmp -> len;
+      else
+	nce = n;
+      XSetForeground (dpy, text -> Cgc, tmp -> color );
+      XDrawImageString ( dpy, text -> window, text -> Cgc, x, y, s, nce );
+      XSetForeground ( dpy, text -> Cgc, text -> fg );
 #ifdef DEBUG
-	    (void) fprintf (stderr,"\tpos est apres le debut de l'element\n");
-	    write(1,s,nce);
-	    write(1,"\n",1);
+      (void) fprintf (stderr,"\tpos est sur le debut d'un element de couleur\n");
+      write(1,s,nce);
+      write(1,"\n",1);
 #endif /* DEBUG */
-	}
-	else { /* pos < tmp -> pos */
-	    nce = tmp -> pos - pos;
-	    XDrawImageString ( dpy, text -> window, text -> Cgc, x, y, s, nce );
-#ifdef DEBUG
-	    (void) fprintf (stderr,"\tpos est avant le debut de l'element\n");
-	    write (1,s,nce);
-	    write(1,"\n",1);
-#endif /* DEBUG */
-
-	    x += XTextWidth ( text -> font, s, nce );
-	    n -= nce;
-	    s += nce;
-	    pos += nce;
-	    /* Maintenenant, l'element lui-meme au prochain tour */
-	    continue;
-	}
-	
-	x += XTextWidth ( text -> font, s, nce );
-	n -= nce;
-	s += nce;
-	pos += nce;
-	if ( ((tmp = tmp -> next) == 0)
-	    || (tmp -> pos > (pos + n -1)) ) {
-	    break;
-	}
     }
-
-    XSetForeground ( dpy, text -> Cgc, text -> fg );
-    if ( n > 0) {
-	/* Il reste des caracteres a afficher */
+    else if (pos > tmp -> pos ) {
+      nce = tmp -> len - (pos - tmp -> pos);
+      if (nce > n)
+	nce = n;
+      XSetForeground (dpy, text -> Cgc, tmp -> color );
+      XDrawImageString ( dpy, text -> window, text -> Cgc, x, y, s, nce );
+      XSetForeground ( dpy, text -> Cgc, text -> fg );
 #ifdef DEBUG
-	(void) fprintf (stderr,"\tLa fin de la ligne\n");
-	write (1,s,n);
-	write(1,"\n",1);
+      (void) fprintf (stderr,"\tpos est apres le debut de l'element\n");
+      write(1,s,nce);
+      write(1,"\n",1);
 #endif /* DEBUG */
-	XDrawImageString ( dpy, text -> window, text -> Cgc, x, y, s, n );
     }
+    else { /* pos < tmp -> pos */
+      nce = tmp -> pos - pos;
+      XDrawImageString ( dpy, text -> window, text -> Cgc, x, y, s, nce );
+#ifdef DEBUG
+      (void) fprintf (stderr,"\tpos est avant le debut de l'element\n");
+      write (1,s,nce);
+      write(1,"\n",1);
+#endif /* DEBUG */
+      
+      x += XTextWidth ( text -> font, s, nce );
+      n -= nce;
+      s += nce;
+      pos += nce;
+      /* Maintenenant, l'element lui-meme au prochain tour */
+      continue;
+    }
+    
+    x += XTextWidth ( text -> font, s, nce );
+    n -= nce;
+    s += nce;
+    pos += nce;
+    if ( ((tmp = tmp -> next) == 0)
+	|| (tmp -> pos > (pos + n -1)) ) {
+      break;
+    }
+  }
+  
+  XSetForeground ( dpy, text -> Cgc, text -> fg );
+  if ( n > 0) {
+    /* Il reste des caracteres a afficher */
+#ifdef DEBUG
+    (void) fprintf (stderr,"\tLa fin de la ligne\n");
+    write (1,s,n);
+    write(1,"\n",1);
+#endif /* DEBUG */
+    XDrawImageString ( dpy, text -> window, text -> Cgc, x, y, s, n );
+  }
 }
 
 /*
@@ -1017,3 +1071,165 @@ unsigned long GetCursorColor (text)
 }
 
 
+/*
+**	Function name : UnColorArea
+**
+**	Description :
+**	Input :
+**	Output :
+*/
+void UnColorArea(text, start, end)
+    Text *text;
+    int start, end;
+{
+  int pos;
+  ColorElement  *tmp, *ori, *nce;
+  
+  if ( ((tmp = text -> current_ce) == 0) || (start==end) ) 
+    return;
+#ifdef DEBUG
+    (void) fprintf (stderr,"UnColorArea start=%d end=%d\n", start, end);
+#endif /* DEBUG */
+  
+  if(start>end){
+    pos = end;
+    end = start;
+    start = end;
+  }
+  ori = tmp;
+  /* se place sur le premier element */
+  while (tmp -> previous != 0)
+    tmp = tmp -> previous;
+  
+  for(;;) {
+#ifdef DEBUG
+    (void) fprintf (stderr,"uncolor_area 0\n");
+#endif /* DEBUG */
+    if (start < tmp -> pos){
+      if (end < tmp -> pos){
+#ifdef DEBUG
+	(void) fprintf (stderr,"uncolor_area 1\n");
+#endif /* DEBUG */
+        break;
+      }
+      else if(end == tmp -> pos){
+	tmp->pos += 1;
+	tmp->len -= 1;
+#ifdef DEBUG
+	(void) fprintf (stderr,"uncolor_area 2\n");
+#endif /* DEBUG */
+	break;
+      }
+      else if((end > tmp -> pos) && (end < (tmp -> pos + tmp -> len -1))){
+	tmp -> len -= end - tmp -> pos;
+	tmp -> pos = end + 1;
+#ifdef DEBUG
+	(void) fprintf (stderr,"uncolor_area 3\n");
+#endif /* DEBUG */
+	break;
+      }
+      else if (end == (tmp -> pos + tmp -> len -1)){
+#ifdef DEBUG
+	(void) fprintf (stderr,"uncolor_area 4\n");
+#endif /* DEBUG */
+	text -> current_ce = tmp -> previous;
+	if(text -> current_ce == 0)
+	  text -> current_ce = tmp -> next;
+	DeleteColorElement (text, tmp);
+	break;
+      }
+      else if(end > (tmp -> pos + tmp -> len -1)){
+#ifdef DEBUG
+	(void) fprintf (stderr,"uncolor_area 5\n");
+#endif /* DEBUG */
+	text -> current_ce = tmp -> previous;
+	if(text -> current_ce == 0)
+	  text -> current_ce = tmp -> next;
+	DeleteColorElement (text, tmp); 
+        if((tmp = text -> current_ce)!=0)
+	  continue;
+	break;
+      }
+      else;
+    }
+    else if (start == tmp -> pos){
+      if((end > tmp -> pos) && (end < (tmp -> pos + tmp -> len -1))){
+	tmp -> len -= end - tmp -> pos;
+	tmp -> pos = end + 1;
+#ifdef DEBUG
+	(void) fprintf (stderr,"uncolor_area 6\n");
+#endif /* DEBUG */
+	break;
+      }
+      else if(end == (tmp -> pos + tmp -> len -1)){
+#ifdef DEBUG
+	(void) fprintf (stderr,"uncolor_area 7\n");
+#endif /* DEBUG */
+	text -> current_ce = tmp -> previous;
+	if(text -> current_ce == 0)
+	  text -> current_ce = tmp -> next;
+	DeleteColorElement (text, tmp);
+	break;
+      }
+      else if(end > (tmp -> pos + tmp -> len -1)){
+	/* On supprime l'element courant */
+#ifdef DEBUG
+	(void) fprintf (stderr,"uncolor_area 8\n");
+#endif /* DEBUG */
+	text -> current_ce = tmp -> previous;
+	if(text -> current_ce == 0)
+	  text -> current_ce = tmp -> next;
+	DeleteColorElement (text, tmp);
+        if((tmp = text -> current_ce)!=0)
+	  continue;
+	break;
+      }
+      else;
+    }
+    else if ((start > tmp -> pos) && (start < (tmp -> pos + tmp -> len -1))){
+      if((end > tmp -> pos) && (end < (tmp -> pos + tmp -> len -1))){
+#ifdef DEBUG
+	(void) fprintf (stderr,"uncolor_area 9\n");
+#endif /* DEBUG */
+	nce = CreateColorElement ( end + 1, tmp -> pos + tmp -> len - 1, (unsigned long) tmp -> color );
+	tmp -> len  = start - tmp -> pos;
+	nce -> previous = tmp;
+	if(tmp -> next) {
+	  nce -> next = tmp -> next;
+	  (tmp -> next) -> previous = nce;
+	}
+	tmp -> next = nce;
+	break;
+      }
+      else if(end == (tmp -> pos + tmp -> len -1)){
+	tmp -> len = start - tmp -> pos;
+#ifdef DEBUG
+	(void) fprintf (stderr,"uncolor_area 10\n");
+#endif /* DEBUG */
+	break; 
+      }
+      else if(end > (tmp -> pos + tmp -> len -1)){
+	tmp -> len = start - tmp -> pos;
+#ifdef DEBUG
+	(void) fprintf (stderr,"uncolor_area 11\n");
+#endif /* DEBUG */
+      }
+      else;
+    }
+    else if(start == (tmp -> pos + tmp -> len -1)) {
+      tmp -> len -= 1;
+#ifdef DEBUG
+      (void) fprintf (stderr,"uncolor_area 12\n");
+#endif /* DEBUG */
+    }
+    else;
+    
+    if(tmp -> next)
+      tmp = tmp -> next;
+    else
+      break;
+  }
+#ifdef DEBUG
+    (void) fprintf (stderr,"uncolor_area End\n");
+#endif /* DEBUG */
+}
