@@ -43,14 +43,19 @@
 #include <X11/Xutil.h>
 #include <X11/Xresource.h>
 
-#ifndef apollo
-#ifdef __FreeBSD__
-#include <stdlib.h>
-#else /* !__FreeBSD__ */
-#include <malloc.h>
-#endif
+#if STDC_HEADERS
+#  include <stdlib.h>
+#else
+#  if HAVE_MALLOC_H
+#    include <malloc.h>
+#  endif
 #endif
+
+#if HAVE_STRING_H
 #include <string.h>
+#else
+#include <strings.h>
+#endif
 
 #include "main_text.h"
 #include "handle_key.h"
@@ -62,6 +67,8 @@
 ButtonWindow bw [NB_BUTTONS];
 static ResourcesButton rs;
 extern Display *dpy;
+static Pixmap pix_panel [8];
+static XImage *im_panel [8];
 
 FCT (static void, MakeButtons, (MWin *mwin,unsigned long fg, unsigned long bg) );
 
@@ -98,8 +105,7 @@ void InitControlRes ( fg, bg, ts, bs )
     rs.mess_gc = XCreateGC ( dpy, root, 0, &gcv );
     
     XSetState ( dpy, rs.mess_gc, fg, bg, GXcopy, AllPlanes );
-    rs.font = XLoadQueryFont ( dpy,
-			      "-adobe-courier-bold-r-normal--14-140-75-75-m-90-iso8859-1");
+    rs.font = XLoadQueryFont ( dpy, "-misc-fixed-bold-r-normal--13-120-75-75-c-70-iso8859-1");
     if ( rs.font != 0 ) {
 	XSetFont ( dpy, rs.mess_gc, rs.font -> fid );
     }
@@ -108,19 +114,45 @@ void InitControlRes ( fg, bg, ts, bs )
 	rs.font = XLoadQueryFont ( dpy, "fixed" );
 	XSetFont ( dpy, rs.mess_gc, rs.font -> fid );
     }
-    rs.up_pix = XCreatePixmapFromBitmapData ( dpy, root, (char *) up_bits,
-					     BUTTON_W, BUTTON_W, pfg, pbg, depth );
-    rs.down_pix = XCreatePixmapFromBitmapData ( dpy, root, (char *) down_bits,
+    if ((depth == 16)||(depth == 24)) {
+      im_panel [1] = (XImage *)LoadImage256 ((char **) xpm_up_bits);
+      rs.up_pix = XCreatePixmap (dpy, DefaultRootWindow (dpy), 24, 24, depth);
+      XPutImage (dpy, rs.up_pix, rs.mess_gc, im_panel [1], 0, 0, 0, 0, 24, 24);
+      
+      im_panel [2] = (XImage *)LoadImage256 ((char **) xpm_down_bits);
+      rs.down_pix = XCreatePixmap (dpy, DefaultRootWindow (dpy), 24, 24, depth);
+      XPutImage (dpy, rs.down_pix, rs.mess_gc, im_panel [2], 0, 0, 0, 0, 24, 24);
+
+      im_panel [3] = (XImage *)LoadImage256 ((char **) xpm_np_bits);
+      rs.np_pix = XCreatePixmap (dpy, DefaultRootWindow (dpy), 24, 24, depth);
+      XPutImage (dpy, rs.np_pix, rs.mess_gc, im_panel [3], 0, 0, 0, 0, 24, 24);
+
+      im_panel [4] = (XImage *)LoadImage256 ((char **) xpm_pp_bits);
+      rs.pp_pix = XCreatePixmap (dpy, DefaultRootWindow (dpy), 24, 24, depth);
+      XPutImage (dpy, rs.pp_pix, rs.mess_gc, im_panel [4], 0, 0, 0, 0, 24, 24);
+
+      im_panel [5] = (XImage *)LoadImage256 ((char **) xpm_q_bits);
+      rs.queue_pix = XCreatePixmap (dpy, DefaultRootWindow (dpy), 24, 24, depth);
+      XPutImage (dpy, rs.queue_pix, rs.mess_gc, im_panel [5], 0, 0, 0, 0, 24, 24);
+
+      im_panel [6] = (XImage *)LoadImage256 ((char **) xpm_head_bits);
+      rs.head_pix = XCreatePixmap (dpy, DefaultRootWindow (dpy), 24, 24, depth);
+      XPutImage (dpy, rs.head_pix, rs.mess_gc, im_panel [6], 0, 0, 0, 0, 24, 24);
+    }
+    else {
+      rs.up_pix = XCreatePixmapFromBitmapData ( dpy, root, (char *) up_bits,
 					       BUTTON_W, BUTTON_W, pfg, pbg, depth );
-    rs.np_pix = XCreatePixmapFromBitmapData ( dpy, root, (char *) np_bits,
-					     BUTTON_W, BUTTON_W, pfg, pbg, depth );
-    rs.pp_pix = XCreatePixmapFromBitmapData ( dpy, root, (char *) pp_bits,
-					     BUTTON_W, BUTTON_W, pfg, pbg, depth );
-    rs.queue_pix = XCreatePixmapFromBitmapData ( dpy, root, (char *) q_bits,
-						BUTTON_W, BUTTON_W, pfg, pbg, depth );
-    rs.head_pix = XCreatePixmapFromBitmapData ( dpy, root, (char *) head_bits,
-					       BUTTON_W, BUTTON_W, pfg, pbg ,depth );
-    
+      rs.down_pix = XCreatePixmapFromBitmapData ( dpy, root, (char *) down_bits,
+						 BUTTON_W, BUTTON_W, pfg, pbg, depth );
+      rs.np_pix = XCreatePixmapFromBitmapData ( dpy, root, (char *) np_bits,
+					       BUTTON_W, BUTTON_W, pfg, pbg, depth );
+      rs.pp_pix = XCreatePixmapFromBitmapData ( dpy, root, (char *) pp_bits,
+					       BUTTON_W, BUTTON_W, pfg, pbg, depth );
+      rs.queue_pix = XCreatePixmapFromBitmapData ( dpy, root, (char *) q_bits,
+						  BUTTON_W, BUTTON_W, pfg, pbg, depth );
+      rs.head_pix = XCreatePixmapFromBitmapData ( dpy, root, (char *) head_bits,
+						 BUTTON_W, BUTTON_W, pfg, pbg ,depth );
+    }
     rs.top_shadow = ts;
     rs.bot_shadow = bs;
 }
@@ -152,7 +184,7 @@ MWin *MakeControlPanel ( w )
     Window w;
 {
   MWin *mwin;
-  int result;
+  int result, depth;
   char *tmp_color;
   extern char *getenv ();
   
@@ -160,9 +192,16 @@ MWin *MakeControlPanel ( w )
   
   mwin -> frame = XCreateSimpleWindow ( dpy, w, 0,
 				       0, DEFAULT_SIZE, DEFAULT_SIZE, 0, rs.fg, rs.bg );
+  XSelectInput ( dpy, mwin -> frame, ExposureMask );
   
   mwin -> w_stat = XCreateSimpleWindow ( dpy, mwin -> frame,
 					1, 1, BUTTON_W, BUTTON_W, 0, rs.fg, rs.bg );
+  depth = DefaultDepth ( dpy, DefaultScreen ( dpy ));
+
+  XSetWindowBackground (dpy, mwin -> w_stat, PixelValue(dpy,"gray50", &result)); 
+  if (result==False)
+    XSetWindowBackground (dpy, mwin -> w_stat, BlackPixel (dpy, DefaultScreen (dpy)));
+
   XSelectInput ( dpy, mwin -> w_stat, ExposureMask );
   
   mwin -> mess = XCreateSimpleWindow ( dpy, mwin -> frame,
@@ -184,7 +223,8 @@ MWin *MakeControlPanel ( w )
   mwin -> theight = BUTTON_W;
   
   if ( UseColor () == False ) {
-    if ( mwin -> bg == BlackPixel ( dpy, DefaultScreen ( dpy ))) {
+/*    if ( mwin -> bg == BlackPixel ( dpy, DefaultScreen ( dpy ))) { */
+    if (result==False) {
       mwin -> red = WhitePixel ( dpy, DefaultScreen ( dpy ));
       mwin -> green = BlackPixel ( dpy, DefaultScreen ( dpy ));
     }
@@ -203,7 +243,7 @@ MWin *MakeControlPanel ( w )
       mwin -> red = BlackPixel ( dpy, DefaultScreen ( dpy ));
     
     if ( (tmp_color = (char *) getenv ( "XCORAL_SAVE_COLOR" )) == 0 )
-      mwin -> green = 0;
+      mwin -> green = PixelValue ( dpy, "green", &result );
     else
       mwin -> green = PixelValue ( dpy, tmp_color, &result );
     
@@ -231,13 +271,13 @@ void RefreshWindowStatBuf ( mwin )
     
     if ( mwin -> stat != False ) {
       XSetForeground ( dpy, mwin -> mess_gc, mwin -> red );
-      XDrawString ( dpy, mwin -> w_stat, mwin -> mess_gc, 8, 16 , "S", 1 ); 
+      XDrawString ( dpy, mwin -> w_stat, mwin -> mess_gc, 9, 16 , "S", 1 ); 
     }
     
     else {
 	if ( (UseColor () == True) && (mwin -> green != 0 ) ) {
 	    XSetForeground ( dpy, mwin -> mess_gc, mwin -> green );
-	    XDrawString ( dpy, mwin -> w_stat, mwin -> mess_gc, 8, 18 , "*", 1 );
+	    XDrawString ( dpy, mwin -> w_stat, mwin -> mess_gc, 9, 16 , "*", 1 );
 	}
     }
     
@@ -416,11 +456,7 @@ void ShowControlPanel ( mwin, width, height )
 */
 void DisplayMessage ( mwin, s ) 
     MWin *mwin;
-#ifdef __FreeBSD__
-    const char *s;
-#else
     char *s;
-#endif
 {
     if ( (s == 0) || (mwin == 0) )
       return;
@@ -431,10 +467,14 @@ void DisplayMessage ( mwin, s )
     
     XClearArea ( dpy, mwin -> mess, 2, 2, mwin -> twidth - 4,
 		mwin -> theight - 4, False );
-    
-    XDrawString ( dpy, mwin -> mess,
-		 mwin -> mess_gc, 10, 16, s, strlen (s) );
-    
+
+    if (strcmp(s, "Abort")!=0)
+      XDrawString ( dpy, mwin -> mess,
+		   mwin -> mess_gc, 10, 16, s, strlen (s) );
+    else
+      XDrawString ( dpy, mwin -> mess,
+		   mwin -> mess_gc, 10, 16, "Abort (Crtl-g)", strlen ("Abort (Crtl-g)") );
+      
 }
 
 
