@@ -91,11 +91,7 @@ typedef struct _MWin {
 
 FCT (void, ClearMessageWindow, (MWin *mwin) );
 FCT (void, DeleteControlPanel, (MWin *mwin) );
-#ifdef __FreeBSD__
-FCT (void, DisplayMessage, (MWin *mwin, const char *) );
-#else
 FCT (void, DisplayMessage, (MWin *mwin, char *) );
-#endif
 FCT (int, ExposeInControlePanel, (Window w, MWin *mwin) );
 FCT (void, InitControlRes, (unsigned long fg, unsigned long bg, unsigned long ts, unsigned long bs) );
 FCT (int, IsButtonInControl, (Window w) );
