@@ -42,24 +42,40 @@
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <X11/cursorfont.h>
-#include <string.h>
-#ifdef apollo
-#include <sys/dir.h>
-#define dirent direct
+
+#if HAVE_DIRENT_H
+#  include <dirent.h>
+#  define NAMLEN(dirent) strlen((dirent)->d_name)
 #else
-#include <dirent.h>
+#  define dirent direct
+#  define NAMLEN(dirent) (dirent)->d_namlen
+#  if HAVE_SYS_NDIR_H
+#    include <sys/ndir.h>
+#  endif
+#  if HAVE_SYS_DIR_H
+#    include <sys/dir.h>
+#  endif
+#  if HAVE_NDIR_H
+#    include <ndir.h>
+#  endif
 #endif
+
+#if HAVE_STRING_H
+#include <string.h>
+#else
+#include <strings.h>
+#endif
+
 #include <sys/param.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#ifdef apollo
-#define S_ISDIR
+
+#if STDC_HEADERS
+#  include <stdlib.h>
 #else
-#ifdef __FreeBSD__
-#include <stdlib.h>
-#else /* !__FreeBSD__ */
-#include <malloc.h>
-#endif /* __FreeBSD__ */
+#  if HAVE_MALLOC_H
+#    include <malloc.h>
+#  endif
 #endif
 
 #include "xcoral.h"
@@ -401,7 +417,7 @@ static int LoadFilesAndDirs ( dir )
   tmp_file = (char **) malloc ( (unsigned) ( sizeof (char *) * (dir_len + 2)));  
   
   for (dp = readdir(dirp); dp != 0; dp = readdir(dirp)) {
-    if ( (dp->d_name != 0) && ((tmp_len = strlen(dp->d_name)) != 0) ) {
+    if ( (dp->d_name != 0) && ((tmp_len = NAMLEN(dp)) != 0) ) {
       tmp_stat = (char *) malloc ( (unsigned) ( tmp_len + dir_str_len + 2 ));
       (void) sprintf ( tmp_stat, "%s/%s", dir, dp->d_name );
       if ( stat ( tmp_stat, &st ) != 0 ) {
@@ -410,12 +426,12 @@ static int LoadFilesAndDirs ( dir )
       }
       (void) free ( tmp_stat );
       if ( S_ISDIR ( st.st_mode )) {
-	tmp_dir [ndir] = (char *) malloc ( (unsigned) strlen (dp->d_name) + 2);
+	tmp_dir [ndir] = (char *) malloc ( (unsigned) NAMLEN(dp) + 2);
 	(void) strcpy ( (char *) tmp_dir[ndir], dp->d_name );
 	ndir ++;
       }
       else {
-	tmp_file [nfile] = (char *) malloc ( (unsigned) strlen (dp->d_name) + 2);
+	tmp_file [nfile] = (char *) malloc ( (unsigned) NAMLEN(dp) + 2);
 	(void) strcpy ( (char *) tmp_file [nfile], dp->d_name );
 	nfile ++;
       }
@@ -463,7 +479,11 @@ static int LoadFilesAndDirs ( dir )
     (void) free ( fs_box.dirname );
 
   pathname = (char *) malloc ( (unsigned) MAXPATHLEN + 2 );
+#if HAVE_GETCWD
   (void) getcwd ( (char*) pathname, MAXPATHLEN );
+#else
+  (void) getwd  ( (char*) pathname );
+#endif
   if ( strcmp ( dir, "." ) == 0 ) {
     fs_box.dirname = ( char *) malloc ( (unsigned) strlen (pathname) +2 );
     (void) strcpy ( fs_box.dirname, (char *) pathname );
