@@ -44,7 +44,8 @@
 #include <X11/Xutil.h>
 #include <X11/keysym.h>
 #include <ctype.h>
-#if defined(SYSV) || defined(UNIXWARE) || defined(SVR4)
+
+#if HAVE_STRING_H
 #include <string.h>
 #else
 #include <strings.h>
@@ -281,6 +282,7 @@ ST *automate ( text, event, current_st )
     
     bzero (buf, 32);
     n_bytes = XLookupString ( event, buf, 32, &ksym, &compose );
+
 #ifdef DEBUG
     printf ( "n_bytes = %d %X\n", n_bytes, ksym );
 #endif
@@ -355,6 +357,20 @@ static void GetInfosKey ( text, ksym, c, infos )
       infos -> ch = c;
       ClearMessageWindow ( text -> mwin );
       break;
+    /* Pour le Pave Numerique */
+    case XK_KP_0:
+    case XK_KP_1:
+    case XK_KP_2:
+    case XK_KP_3:
+    case XK_KP_4:
+    case XK_KP_5:
+    case XK_KP_6:
+    case XK_KP_7:
+    case XK_KP_8:
+    case XK_KP_9:
+      infos -> ch = c;
+      (void) GetInfosAsciiKey ( text, c, infos );
+      break;
     default:
       if ((infos -> ch = XK_ksym_to_code(ksym)) != 0) {
 	infos -> type = KEY;
