@@ -41,7 +41,12 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+
+#if HAVE_STRING_H
 #include <string.h>
+#else
+#include <strings.h>
+#endif
 
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
@@ -136,7 +141,7 @@ char ie_the_char (text, p)
     int b_len = ((text -> buf -> l_cur - text -> buf -> top) +
 		 (text -> buf -> bottom - text -> buf -> r_cur));
     
-    if ( (p >= 0) && ( p <= b_len )) {
+    if ( (p >= 0) && ( p < b_len )) {
 	if ( p > (text -> buf -> l_cur - text -> buf -> top - 1)) {
 	    /* Apres la bulle */
 	    p -= text -> buf -> l_cur - text -> buf -> top;
@@ -1843,6 +1848,25 @@ void ie_color_area ( text, start, end, colorname )
     (void) SetColorArea ( text, start, end, colorname );
 }
 
+/*
+**	Function name : ie_uncolor_area
+**
+**	Description :
+**	Input :
+**	Output :
+*/
+void ie_uncolor_area(text, start, end)
+    Text *text;
+    int start, end;
+{
+    extern Display *dpy;
+    
+    if ( DefaultDepth ( dpy, DefaultScreen ( dpy )) == 1 )
+      return;
+    (void) UnColorArea ( text, start, end);
+}
+
+
 /*
 **	Function name : ie_paste_region
 **
@@ -1895,6 +1919,19 @@ void ie_remove_colors ( text )
   (void) DeleteColorList (text);
 }
 
+/*
+**	Function name : ie_current_buffer_is_colored
+**
+**	Description :
+**	Input :
+**	Output :
+*/
+int ie_current_buffer_is_colored ( text )
+    Text *text;
+{
+  return (text->current_ce != 0);
+}
+
 /*
 **	Function name : ie_watch_on
 **
