@@ -41,12 +41,13 @@
 #include <stdio.h>
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
-#ifndef apollo
-#ifdef __FreeBSD__
-#include <stdlib.h>
-#else /* !__FreeBSD__ */
-#include <malloc.h>
-#endif
+
+#if STDC_HEADERS
+#  include <stdlib.h>
+#else
+#  if HAVE_MALLOC_H
+#    include <malloc.h>
+#  endif
 #endif
 
 #include "init_menus.h"
@@ -171,7 +172,9 @@ XYMenu *MakeMenus ( display, w, title, item, fnt )
   menu -> y_menu = menu -> bar_height + 2;		
   menu -> titlename 	= title;
   menu -> itemname 	= item;
-  menu -> y_title = rm.font -> ascent +  1;
+/*  menu -> y_title = rm.font -> ascent + 3; */
+/*  menu -> y_title = rm.font -> ascent + 2; */
+  menu -> y_title = rm.font -> ascent + 1;
   menu -> parent = w;
   menu -> n_last_unmapped = -1;
   menu -> hmax_menu = 0;
@@ -230,8 +233,10 @@ XYMenu *MakeMenus ( display, w, title, item, fnt )
       break;
   }
   menu->nb_menus = i;
-  if ( DoesSaveUnders ( DefaultScreenOfDisplay ( display ) ) != True )
+/*
+   if ( DoesSaveUnders ( DefaultScreenOfDisplay ( display ) ) != True )
     SetMenuPixmap ( display, menu, menu -> bar_width );
+*/
   show_bar ( display, menu -> parent, menu );
   return menu;
 }
@@ -270,7 +275,7 @@ void SetMenuPixmap ( display, menu, width )
     XYMenu *menu;
     int width;
 {
-  
+/*  
   if ( menu -> save != 0 ) {
 #ifdef DEBUG
     fprintf ( stderr, "Pixmap ms = %d\n", menu -> save );
@@ -280,7 +285,7 @@ void SetMenuPixmap ( display, menu, width )
   
 #ifdef SHADOW
   menu -> save = XCreatePixmap ( display,
-				menu -> w_under , width,
+				menu -> w_under, width,
 				menu -> hmax_menu + SHAD + 10,
 				DefaultDepth ( display, DefaultScreen ( display )));
 #else
@@ -289,8 +294,9 @@ void SetMenuPixmap ( display, menu, width )
 				menu -> hmax_menu + 10,
 				DefaultDepth ( display, DefaultScreen ( display )));
 #endif
-  menu -> save_ok = 0;		/* Ya rien  dans la pixmap */
+  menu -> save_ok = 0;
   menu -> pix_width = width;
+*/
 }
 
 
@@ -580,8 +586,10 @@ void DeleteMenu ( display, menu )
       free ( ( char * ) menu -> vmenu [i] );
   }
   XDestroyWindow ( display,menu -> w_bar );
-  if ( DoesSaveUnders ( DefaultScreenOfDisplay ( display ) ) != True )
+/*
+   if ( DoesSaveUnders ( DefaultScreenOfDisplay ( display ) ) != True )
     XFreePixmap ( display, menu -> save );
+*/
   if ( menu != 0 )
     (void) free ( ( char * ) menu ); 
 }
