@@ -39,14 +39,30 @@
 
 
 #include <stdio.h>
-#ifdef __NetBSD__
 #include <pwd.h>
-#include <dirent.h>
-#else
-#include <dirent.h>
-#include <pwd.h>
-#endif
+
+#if HAVE_STRING_H
 #include <string.h>
+#else
+#include <strings.h>
+#endif
+
+#if HAVE_DIRENT_H
+#  include <dirent.h>
+#  define NAMLEN(dirent) strlen((dirent)->d_name)
+#else
+#  define dirent direct
+#  define NAMLEN(dirent) (dirent)->d_namlen
+#  if HAVE_SYS_NDIR_H
+#    include <sys/ndir.h>
+#  endif
+#  if HAVE_SYS_DIR_H
+#    include <sys/dir.h>
+#  endif
+#  if HAVE_NDIR_H
+#    include <ndir.h>
+#  endif
+#endif
 
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
@@ -115,6 +131,7 @@ void InitInputString ()
     XFontStruct *font;
     int i;
     extern void ie_WR_delete ();
+    extern void ie_WR_delete_char ();
     
     input_str = (Text *) MakeTextWindow ( dpy, DefaultRootWindow(dpy), 0, 0 );
     input_str -> mwin = 0;
@@ -133,7 +150,10 @@ void InitInputString ()
     if ( input_str -> current_mode == 0 )
       (void) fprintf (stderr, "Init mode error\n" );
 
-    font = LoadFont ( dpy, "-adobe-courier-bold-r-normal--*-140-*-*-m-*-iso8859-1" );
+/*    font = LoadFont ( dpy, "-adobe-courier-bold-r-normal--*-140-*-*-m-*-iso8859-1" ); */
+/*    font = LoadFont ( dpy, "-adobe-courier-bold-r-normal--14-140-75-75-m-90-iso8859-1" ); */
+    font = LoadFont ( dpy, "-adobe-courier-medium-r-normal--12-120-75-75-m-70-iso8859-1" );
+    
     SetFontText ( dpy, input_str, font );
     input_str_stat = (ST *) &st_initial;
     
@@ -162,7 +182,7 @@ void InitInputString ()
     ie_key_def ( input_str,"input_str" , (unsigned char *)"^I", "str_tab" );
     ie_key_def ( input_str,"input_str" , (unsigned char *)"^P", "str_previous" );
 
-    input_str -> current_mode -> key [DELETE].func = ie_WR_delete;
+    input_str -> current_mode -> key [DELETE].func = ie_WR_delete_char;
     
     input_str -> current_mode -> key [CtrA].type = BUILTIN_FUNC;
     input_str -> current_mode -> key [CtrB].type = BUILTIN_FUNC;
@@ -178,7 +198,7 @@ void InitInputString ()
     input_str -> current_mode -> key [DELETE].type = BUILTIN_FUNC;
     
     str_buf = (char *) malloc ( (unsigned) STR_BUF_LEN );
-    
+    str_buf[0] = 0;
     str_buf_len = STR_BUF_LEN;
 }
 
@@ -640,7 +660,8 @@ void InputStrPrevious ( text )
     TextCursorOff ( input_str );
     (void) CleanInputStr ();
     XClearWindow ( dpy, input_str -> window );
-    InsertNchar ( input_str -> buf, str_buf, strlen(str_buf) );
+    if (str_buf[0]!=0)
+      InsertNchar ( input_str -> buf, str_buf, strlen(str_buf) );
     input_str -> modif = True;
     SetCurrentLine ( input_str );
     TextCursorOn ( input_str );
@@ -750,7 +771,7 @@ static char * ExpandFileName (s, n, common)
     while ((entry = readdir(dp)))
       if (strstr(entry->d_name, s) == entry->d_name) {
 	char * nresult =
-	  (char *) malloc((unsigned int) rlength + strlen(entry->d_name) + 1 + 1);
+	  (char *) malloc((unsigned int) rlength + NAMLEN(entry) + 1 + 1);
 	
 	if (! nresult) {
 	    (void) closedir (dp);
@@ -760,11 +781,11 @@ static char * ExpandFileName (s, n, common)
 	
 	bcopy(result, nresult, rlength);
 	(void) strcpy(nresult + rlength, entry->d_name);
-	rlength += strlen(entry->d_name) + 1;
+	rlength += NAMLEN(entry) + 1;
 	*n += 1;
 	{
 	  struct stat st;
-	  char * f = malloc(strlen(current_dir) + 1 + strlen(entry->d_name) + 1);
+	  char * f = malloc(strlen(current_dir) + 1 + NAMLEN(entry) + 1);
 	  
 	  if (f) {
 	    sprintf(f, "%s/%s", current_dir, entry->d_name);
