@@ -13,8 +13,13 @@
 */
 
 
-#include <stdio.h>
+#if HAVE_STRING_H
 #include <string.h>
+#else
+#include <strings.h>
+#endif
+
+#include <stdio.h>
 #include <limits.h>
 
 #include "justify.h"
@@ -111,7 +116,7 @@ FCT(static void, inserer,(unsigned int)	);
 
 extern FCT ( char *, stringdup,(char *)		);
 
-#ifdef UNIXWARE
+#if !HAVE_STRCASECMP
 int strcasecmp ();
 
 int
@@ -789,20 +794,21 @@ static void justifier_line()
 	  while (strchr(" *+-", *pl))
 	    pl += 1;
       
-	while (pl != psup) if (*pl++ == ' ') nplace += 1;
+	while (pl < psup)
+	  if (*pl++ == ' ') nplace += 1;
 
 	pl = Line;
 	if (Itemize)
 	  while (strchr(" *+-", *pl))
 	    InsertNchar(TextBuf, (char *) pl++, 1);
       
-	for (; pl != psup; pl += 1)
+	for (; pl < psup; pl += 1)
 	  switch (*pl) {
 	  case ConstantSpace:
 	    InsertNchar(TextBuf, " ", 1);
 	    break;
 	  case ' ':
-	    if (nspace) {
+	    if (nspace && nplace) {
 	      int n  = (nspace + nplace - 1) / nplace;
 	      
 	      nspace -= n;
@@ -838,10 +844,7 @@ static void justifier_line()
 static void inserer(c)
      unsigned int c;
 {
-#ifdef __osf__
   c &= 0xff ;
-#endif
-
   if (c >= ' ') {
     if ((c != ' ') ||
 	((pLine != Line) && (*(pLine - 1) != ' '))) {
