@@ -44,7 +44,7 @@
 #include <sys/types.h>
 #include <fcntl.h>
 #include <sys/time.h>
-#ifdef _AIX
+#ifdef HAVE_SYS_SELECT_H
 #include <sys/select.h>
 #endif
 
@@ -72,6 +72,7 @@
 #include "cb_names.h"
 #include "get_file.h"
 #include "selection.h"
+#include "tbox.h"
 
 EdWin	*CreateWindow ();
 Window	HandleMenu ();
@@ -83,6 +84,7 @@ extern LBox l_box;
 extern DBox dial_box;
 extern FBox fs_box;
 extern MBox man_box;
+extern TBox tbox;
 
 XEvent event;
 static XEvent *ev = &event;
@@ -109,9 +111,17 @@ static Text *lock_buttons = 0;
 Window w_sel = None;
 Atom prop_sel;
 jmp_buf br_env;
-fd_set readfds, save_readfds; 
 int width_fd;
 
+fd_set readfds, save_readfds;
+
+#if defined(fd_set)
+#define FD_SET(n, p)    ((*p) |= (1 << (n)))
+#define FD_CLR(n, p)    ((*p) &= ~(1 << (n)))
+#define FD_ISSET(n, p)  ((*p) & (1 << (n)))
+#define FD_ZERO(p)      ((*p) = 0)
+#endif
+
 /*
 **	Function name : InitEvent
 **
@@ -152,7 +162,7 @@ void InitEvent ()
 */
 void WaitForEvent ()
 {
-#if defined(SVR4) || defined(UNIXWARE)
+#if HAVE_SIGPROCMASK
 	sigset_t block, oblock;
 #else
     int old_mask;
@@ -167,7 +177,7 @@ void WaitForEvent ()
     for (;;) {
 	while ( XPending ( dpy ) == 0 ) {
 	    /* Pour un ^C eventuel */
-#if defined(SVR4) || defined(UNIXWARE)
+#if HAVE_SIGPROCMASK
 		(void)sigemptyset(&block);
 		(void)sigaddset(&block, SIGINT);
 		if (sigprocmask(SIG_BLOCK, &block, &oblock) < 0)
@@ -195,12 +205,12 @@ void WaitForEvent ()
 		  }
 	      }
 	      if ( text != 0 ) {
-		  ReadFromShell ( text );
-		  text = 0;
+		ReadFromShell ( text );
+		text = 0;
 	      }
 	      break;
 	    }
-#if defined(SVR4) || defined(UNIXWARE)
+#if HAVE_SIGPROCMASK
 		(void)sigprocmask(SIG_SETMASK, &oblock, (sigset_t *)NULL);
 #else
 		(void) sigsetmask(old_mask);
@@ -366,6 +376,9 @@ static void HandleMessage ()
 {
     EdWin **t;
     
+#ifdef DEBUG			
+    (void) fprintf ( stderr, "Handle Message\n" );
+#endif
     if ( strcmp (XGetAtomName(dpy,ev -> xclient.message_type), "WM_PROTOCOLS") != 0 )
       return;
     
@@ -414,16 +427,18 @@ static void HandleSelectionRequest()
   XEvent ev_not;
   int nbytes = 0;
   char *s;
-  
 #ifdef DEBUG
-  (void) fprintf ( stderr, "SelectionRequest\n" );
+  (void) fprintf ( stderr, "Selection Request\n" );
+  (void) fprintf ( stderr, "   Requestor = %d\n",ev -> xselectionrequest.requestor );
+  (void) fprintf ( stderr, "   Selection type = %d\n",ev -> xselectionrequest.selection );
+  (void) fprintf ( stderr, "   Selection property = %d\n",ev -> xselectionrequest.property );
 #endif
 
   s = Fetch_bytes (&nbytes);
 
   if (s == 0 || nbytes == 0) {
 #ifdef DEBUG
-  (void) fprintf ( stderr, "SelectionRequest null\n" );
+  (void) fprintf ( stderr, "Selection Request null\n" );
 #endif
     return;
   }
@@ -436,15 +451,10 @@ static void HandleSelectionRequest()
   ev_not.xselection.property = ev -> xselectionrequest.property;
 
   if ((ev -> xselectionrequest.selection == XA_PRIMARY)
-      &&(ev -> xselectionrequest.target)
+      &&(ev -> xselectionrequest.target == XA_STRING)
       &&(ev -> xselectionrequest.property)) {
-    XChangeProperty (dpy, ev_not.xselection.requestor,
-		   ev_not.xselection.property,
-		   ev_not.xselection.target,
-		     8,
-		     PropModeReplace,
-		     s,
-		     nbytes );
+    XChangeProperty (dpy, ev_not.xselection.requestor,ev_not.xselection.property,
+		   ev_not.xselection.target, 8, PropModeReplace, s, nbytes );
   }
   else {
     ev_not.xselection.property = None;
@@ -463,9 +473,8 @@ static void HandleSelectionRequest()
 static void HandleSelectionNotify()
 {
 #ifdef DEBUG
-  (void) fprintf ( stderr, "SelectionNotify\n" );
+  (void) fprintf ( stderr, "Selection Notify\n" );
 #endif
-
   if (ev -> xselection.property == None){
     klaxon();
     return;
@@ -494,20 +503,6 @@ static void HandleSelectionNotify()
   }
 }
 
-/*
-**	Function name : HandlePropertyNotify
-**
-**	Description :
-**	Input :
-**	Output :
-*/
-static void HandlePropertyNotify()
-{
-#ifdef DEBUG
-  (void) fprintf ( stderr, "PropertyNotify\n" );
-#endif
-}
-
 /*
 **	Function name : HandleSelectionClear
 **
@@ -519,7 +514,7 @@ void HandleSelectionClear()
 {
   EdWin	**t;
 #ifdef DEBUG
-  (void) fprintf ( stderr, "SelectionClear\n" );
+  (void) fprintf ( stderr, "Selection Clear\n" );
 #endif
 /*  Clear_bytes(); */
   w_sel = None;
@@ -538,6 +533,20 @@ void HandleSelectionClear()
   }
 }
 
+/*
+**	Function name : HandlePropertyNotify
+**
+**	Description :
+**	Input :
+**	Output :
+*/
+static void HandlePropertyNotify()
+{
+#ifdef DEBUG
+  (void) fprintf ( stderr, "PropertyNotify\n" );
+#endif
+}
+
 /*
 **	Function name : HandleConfigure
 **
@@ -608,6 +617,11 @@ void HandleConfigure ()
 			     ev -> xconfigure.height );
 	return;
     }
+    if ( ev -> xconfigure.window == GetTrombinesBoxFrame () ) {
+	(void) ConfigTrombinesBox ( ev -> xconfigure.width,
+			     ev -> xconfigure.height );
+	return;
+    }
 }
 
 
@@ -622,7 +636,8 @@ void HandleEnter ()
 {
     EdWin **t;
     int trouve = False;
-
+    int ccontext;
+    
 #ifdef DEBUG
     ( void ) fprintf ( stderr, "Enter Notify %d mode = %d\n", 
 		      ev -> xcrossing.window,
@@ -653,8 +668,18 @@ void HandleEnter ()
 	ChangeDir ( edwin -> text );
 	trouve = True;
     }
-    if ( trouve == True )
+    if ( trouve == True ) {
       SetButton ( edwin -> mwin );
+    }
+
+    ccontext=0;
+    for ( t = TWin; t < TWin + MAXWIN; t++ ) {
+	if ( *t == 0 ) continue;
+	if ( *t == edwin )
+	  ccontext=1; /* Le context courant existe */
+    }
+    if (ccontext)
+      EnterInToolBar (edwin, ev -> xcrossing.window);
 }
 
 
@@ -793,11 +818,21 @@ void HandleButtonPress ()
     Window w_stat;
     int result;
     EdWin **t;
+    Time selection_time;
+    int selection,ccontext;
     
 #ifdef DEBUG
     ( void ) fprintf ( stderr, "ButtonPress %d\n", ev -> xbutton.window );
 #endif
-    
+    ccontext=0;
+    for ( t = TWin; t < TWin + MAXWIN; t++ ) {
+	if ( *t == 0 ) continue;
+	if ( *t == edwin )
+	  ccontext=1; /* Le context courant existe */
+    }
+    if (ccontext)
+      selection = edwin -> text-> selection -> select;
+   
     if ( ButtonBrowser ( (XButtonEvent *) ev ) == True )
       return;
     
@@ -812,6 +847,9 @@ void HandleButtonPress ()
     
     if ( ButtonManBox ( (XButtonEvent *) ev ) == True )
       return;
+     
+    if ( ButtonTrombinesBox ( (XButtonEvent *) ev ) == True )
+      return;
     
     if ( lock_buttons == edwin -> text ) {
 	klaxon ();
@@ -854,8 +892,14 @@ void HandleButtonPress ()
     */
     if ( ButtonPressInScroll ( edwin -> scroll, ev -> xbutton.window, 
 			      ev -> xbutton.y, &result ) == True) {
+	if ( lock_menus == True ) {
+	    klaxon ();
+	    return;
+	}
 	switch ( result ) {
 	case CURSOR:
+	  if (edwin->text->selection->select == True)
+	    ClearSelection(edwin->text, True);
 	  if ( GetCursorStat ( edwin -> text ) != OFF )
 	    TextCursorOff ( edwin -> text );
 	  if ( GetScrollStat( edwin -> text ))
@@ -866,6 +910,10 @@ void HandleButtonPress ()
 	  if ( GetCursorStat ( edwin -> text ) != ON )
 	    TextCursorOn ( edwin -> text );
 	  RefreshScrollBar ( dpy, edwin -> scroll ); 
+	  if (selection==True){
+	    edwin->text-> selection -> select = True;
+	    (void) RefreshSelection(edwin->text); 
+	  }
 	  break;
 	case NEXT:
 	  TextCursorOff ( edwin -> text );
@@ -885,6 +933,10 @@ void HandleButtonPress ()
      * Button press in current text window
      */
     if ( ev -> xbutton.window == edwin -> text -> window ) {
+	if ( lock_menus == True ) {
+	    klaxon ();
+	    return;
+	}
 	switch ( ev -> xbutton.button ) {
 	case Button1:
 	  switch ( ev -> xbutton.state ) {
@@ -907,7 +959,7 @@ void HandleButtonPress ()
 	      UpdatePage ( edwin -> text );
 	    }
 	    TextCursorOn ( edwin -> text );
-	    (void) HandleSelection (edwin -> text, ev);
+	    selection_time = HandleSelection (edwin -> text, ev);
 	    if (edwin -> text -> selection -> select == True) {
 	      /* Il faut effacer la derniere selection si elle existe */
 	      for ( t = TWin; t < TWin + MAXWIN; t++ ) {
@@ -923,13 +975,14 @@ void HandleButtonPress ()
 		  }
 		}
 	      }
+	      TextCursorOn ( edwin -> text );
 	      (void) BrowserClearSelection();
 	      w_sel = ev -> xbutton.window;
-	      XSetSelectionOwner ( dpy, XA_PRIMARY, w_sel, ev -> xbutton.time);
+	      XSetSelectionOwner ( dpy, XA_PRIMARY, w_sel, selection_time);
 	      if ( w_sel == XGetSelectionOwner ( dpy, XA_PRIMARY )) {
 #ifdef DEBUG
 		(void) fprintf (stderr, "Selection owner OK\n");
-#endif /* DEBUG */	      
+#endif /* DEBUG */
 	      }
 	      else {
 #ifdef DEBUG
@@ -1057,7 +1110,6 @@ static void ButtonUserFunc ( text, x, y, func_name )
 void HandleExpose ()
 {
     EdWin **t;
-    
 #ifdef DEBUG
     ( void ) fprintf ( stderr, "Expose %d\n", ev -> xexpose.window );
 #endif
@@ -1113,6 +1165,8 @@ void HandleExpose ()
       return;
     if ( ExposeManBox ( ev ) == True )
       return;
+    if ( ExposeTrombinesBox ( ev ) == True )
+      return;
 }
 
 /*
@@ -1188,6 +1242,9 @@ void UnFreezeButtons ()
 void PasteSelection(text)
     Text *text;
 {
+#ifdef DEBUG
+  ( void ) fprintf ( stderr, "Paste Selection\n" );
+#endif
   if ( w_sel != None ) { /* xcoral a la selection */
     SetCurrentLine (text);
     ClearSelection(text, True);
