@@ -44,14 +44,19 @@
 #include <sys/types.h>
 #include <sys/time.h>
 #include <signal.h>
-#include <string.h>
 
-#ifndef apollo
-#ifdef __FreeBSD__
-#include <stdlib.h>
-#else /* !__FreeBSD__ */
-#include <malloc.h>
+#if HAVE_STRING_H
+#include <string.h>
+#else
+#include <strings.h>
 #endif
+
+#if STDC_HEADERS
+#  include <stdlib.h>
+#else
+#  if HAVE_MALLOC_H
+#    include <malloc.h>
+#  endif
 #endif
 
 #include "xcoral.h"
@@ -67,12 +72,14 @@
 #include "shadow.h"
 
 static TextResources	tr;
+int _startup = 0;
 extern char *getenv ();
 
 FCT (static int, GetNbLinesInPage, (Text *text, XFontStruct *font) );
 FCT (static void, Set_mode_internal, (Text *text, char *mode_name) );
 
 void ie_WR_delete ( text ) Text *text; { f_delete ( text ); }
+void ie_WR_delete_char ( text ) Text *text; { TextCursorOff (text);Control_D ( text );TextCursorOn (text);}
 
 /*
 **	Function name : InitTextRes
@@ -974,6 +981,10 @@ void ExposeTextWindow ( dpy, text, ev )
     else
       FreezeTextCursor ( text ); 
     
+    if (_startup) {
+      ColorBuffer(text);
+      _startup --;
+    }
     return;
 }
 
