@@ -163,6 +163,7 @@ FCT (void, SetTextSave, (Text *text) );
 FCT (void, ShowWindowText, (Display *dpy, Text *text, int width, int height) );
 FCT (int, TextInBuf, (Text *text) );
 FCT (void, ie_WR_delete, (Text *text) );
+FCT (void, ie_WR_delete_char, (Text *text) );
 
 FCT (void, DeleteUndo, (Text *text) );
 FCT (void, DoUndo, (Text *text) );
@@ -178,6 +179,7 @@ FCT (void, SetEdirMode, (Text *text) );
 FCT (void, SetshellMode, (Text *text) );
 
 FCT (void, SetColorArea, (Text *text, int start, int end, char *colorname) );
+FCT (void, UnColorArea, (Text *text, int start, int end) );
 FCT (void, DeleteColorList, (Text *text) );
 FCT (void, UpdateColorList, (Text *text, int nbytes) );
 FCT (void, ColorLineInPage, (Text *text,  int x, int y, int li, char *s, int n) );
