@@ -42,7 +42,12 @@
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <X11/cursorfont.h>
+
+#if HAVE_STRING_H
 #include <string.h>
+#else
+#include <strings.h>
+#endif
 
 #include "xcoral.h"
 #include "main_text.h"
@@ -55,7 +60,7 @@
 #include "text_cursor.h"
 #include "shadow.h"
 #include "bm_search.h"
-
+
 extern Display *dpy;
 MBox man_box;
 static  Atom man_del;
@@ -103,7 +108,7 @@ void InitManBox ()
     screen = DefaultScreen ( dpy );
     root = RootWindow ( dpy, screen );
     XGetWindowAttributes ( dpy, root, &att );
-    man_box.width = att.width / 2 ;
+    man_box.width = (6 * att.width) / 10 ;
     man_box.height = ( 4 * att.height ) / 5 ;
     man_box.t_height = man_box.font -> ascent + man_box.font -> descent + MB_SPACE;
     man_box.b_width = XTextWidth ( man_box.font, MB_SEARCH, strlen (MB_SEARCH) ) + (2 * MB_SPACE);
@@ -361,6 +366,7 @@ void ConfigManBox ( width, height )
     static int man_first_conf = True;
     int m_height, u_height, t_height;
     int mf_width,if_width,tf_width,mt_width,it_width,tt_width;
+    XEvent ev;
 
     if ( (width == man_box.width) 
 	&& (height == man_box.height) 
@@ -376,6 +382,8 @@ void ConfigManBox ( width, height )
     XResizeWindow ( dpy, man_box.frame, man_box.width, man_box.height );
     XResizeWindow ( dpy, man_box.title, man_box.width, man_box.t_height );
 
+    while ( XCheckWindowEvent ( dpy, man_box.frame, StructureNotifyMask, &ev ));
+
     mf_width = man_box.width; /* man frame width */
     if_width = man_box.width / 2; /* index frame width */
     tf_width = man_box.width - if_width; /* toc frame width */
