@@ -911,6 +911,24 @@ void ColorBuffer(text)
   ie_redisplay ( text );
 }
 
+/*
+**	Function name : RemoveColor
+**	Description :
+**	Input :
+**	Output :
+*/
+void RemoveColors(text)
+    Text *text;
+{
+  char *msg;
+
+  StorePosition (text);
+  msg = (char *) ie_call_function ( text, "remove_colors", 0, 0);
+  if ( msg != 0 )
+    DisplayMessage ( text -> mwin, msg );
+  ie_redisplay ( text );
+}
+
 /*
 **	Function name : Yank
 **
