@@ -39,14 +39,22 @@
 
 
 #include <stdio.h>
-#include <string.h>
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <X11/keysym.h>
-#ifdef __FreeBSD__
-#include <stdlib.h>
-#else /* !__FreeBSD__ */
-#include <malloc.h>
+
+#if HAVE_STRING_H
+#include <string.h>
+#else
+#include <strings.h>
+#endif
+
+#if STDC_HEADERS
+#  include <stdlib.h>
+#else
+#  if HAVE_MALLOC_H
+#    include <malloc.h>
+#  endif
 #endif
 
 #include "xcoral.h"
@@ -79,7 +87,7 @@ FCT (static void, SetModeName, (Mode *mode, char *mode_name) );
 FCT (static void, ie_WR_setmark, (Text *text) );
 FCT (static void, ie_WR_goto_beginning_of_line , (Text *text) );
 FCT (static void, ie_WR_goto_previous_char, (Text *text) );
-FCT (static void, ie_WR_delete_char, (Text *text) );
+/* FCT (static void, ie_WR_delete_char, (Text *text) ); */
 FCT (static void, ie_WR_goto_end_of_line, (Text *text) );
 FCT (static void, ie_WR_goto_next_char, (Text *text) );
 FCT (static void, ie_WR_abort, (Text *text) );
@@ -128,6 +136,10 @@ FCT (static void, ie_WR_shell_CtrD, (Text *text) );
 FCT (static void, ie_WR_shell_key, (Text *text) );
 FCT (static void, ie_WR_yank, (Text *text) );
 
+#if !HAVE_STRDUP
+extern FCT (char*, strdup, (char*) );
+#endif
+
 /*
 **	Function name : AllocMode
 **
@@ -425,7 +437,7 @@ Mode *SearchMode ( filename )
 static void ie_WR_setmark ( text ) Text *text; { C_OFF;SetMark ( text );C_ON;}
 static void ie_WR_goto_beginning_of_line ( text ) Text *text; { C_OFF;MoveToBline ( text );C_ON;}
 static void ie_WR_goto_previous_char ( text ) Text *text; { C_OFF;BackwardChar ( text );C_ON;}
-static void ie_WR_delete_char ( text ) Text *text; { C_OFF;Control_D ( text );C_ON;}
+/* static void ie_WR_delete_char ( text ) Text *text; { C_OFF;Control_D ( text );C_ON;} */
 static void ie_WR_goto_end_of_line ( text ) Text *text; { C_OFF;MoveToEline ( text );C_ON;}
 static void ie_WR_goto_next_char ( text ) Text *text; { C_OFF;ForwardChar ( text );C_ON;}
 static void ie_WR_abort ( text ) Text *text; { C_OFF;AbortCurrentCmd ( text );C_ON;}
@@ -550,22 +562,14 @@ f2s func_string [NB_BUILTIN_FUNC] = {
 **	Input : 
 **	Ouput :
 */
-#ifdef __alpha
 long GetFuncNameFromString ( s )
-#else
-int GetFuncNameFromString ( s )
-#endif    
     char *s;
 {
     int i = 0;
 
     while ( func_string [i].f != 0 ) {
 	if ( strcmp ( (char *) func_string [i].s, s ) == 0 )
-#ifdef __alpha	  
 	  return ((long) func_string [i].f);
-#else	
-	  return ((int) func_string [i].f);
-#endif	  
 	i++;
     }
     return (0);
@@ -635,8 +639,9 @@ static void SetDefaultModeValues ( mode )
     mode -> key [CtrV].func = ie_WR_next_page;
     mode -> key [CtrW].func = ie_WR_kill_region;
     mode -> key [CtrY].func =  ie_WR_yank;
-    mode -> key [DELETE].func = ie_WR_delete;
-
+/*    mode -> key [DELETE].func = ie_WR_delete; */
+    mode -> key [DELETE].func = ie_WR_delete_char;
+    
     mode -> key [Ctr_sp].type = BUILTIN_FUNC; 
     mode -> key [CtrA].type = BUILTIN_FUNC; 
     mode -> key [CtrB].type = BUILTIN_FUNC; 
