@@ -48,7 +48,13 @@
 #include <stdio.h>
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
+
+#if HAVE_STRING_H
 #include <string.h>
+#else
+#include <strings.h>
+#endif
+#include <signal.h>
 
 #include "options.h"
 #include "xcoral.h"
@@ -69,7 +75,8 @@ extern Trans st_initial;
 FCT (static void, SetProp, (Window w) );
 FCT (static int, add_window, (EdWin *e) );
 
-static Pixmap text_icon;
+static Pixmap xcoral_icon, xcoral_icon_mask;
+static XImage *logo_image;
 
 /*
 **	Function name : InitIconPixmap
@@ -80,12 +87,27 @@ static Pixmap text_icon;
 */
 void InitIconPixmap()
 {
-    text_icon = XCreatePixmapFromBitmapData ( dpy, DefaultRootWindow ( dpy ),
-		(char *) icon_bits,
-		icon_width, icon_height,
-		BlackPixel ( dpy, DefaultScreen ( dpy )),
-		WhitePixel ( dpy, DefaultScreen ( dpy )),
-		DefaultDepth ( dpy, DefaultScreen ( dpy )));
+  int depth = DefaultDepth ( dpy, DefaultScreen ( dpy ));
+  
+  if ((depth == 16)||(depth == 24)) {
+    logo_image = (XImage *)LoadImage256 ((char **)xpm_logo);
+    xcoral_icon = XCreatePixmap (dpy, DefaultRootWindow(dpy), 32, 32,depth);
+    xcoral_icon_mask = XCreatePixmapFromBitmapData ( dpy, DefaultRootWindow (dpy), 
+						    logo_bits, 32, 32,
+						    BlackPixel(dpy, DefaultScreen(dpy)),
+						    WhitePixel(dpy, DefaultScreen(dpy)), 1 );
+    
+    XPutImage (dpy, xcoral_icon,DefaultGC (dpy, DefaultScreen(dpy)),
+	       logo_image, 0, 0, 0, 0, 32, 32);
+  }
+  else {
+    xcoral_icon = XCreatePixmapFromBitmapData ( dpy, DefaultRootWindow ( dpy ),
+					     (char *) logo_bits,
+					     icon_width, icon_height,
+					     BlackPixel ( dpy, DefaultScreen ( dpy )),
+					     WhitePixel ( dpy, DefaultScreen ( dpy )),
+					     DefaultDepth ( dpy, DefaultScreen ( dpy )));
+  }
 }
 
 /*
@@ -193,14 +215,14 @@ void ConfigWindow ( e, width, height )
     wscroll = GetScrollWidth ();
 
     htb = TOOL_WINDOW_SIZE;
-    
+
 #ifdef DEBUG
     fprintf ( stderr, "ConfigWindow width = %d, height = %d\n",
 	     width, height );
     fprintf ( stderr, "ConfigWindow hbar = %d, hmess = %d, wscroll = %d\n",
 	     hbar, hmess, wscroll );
 #endif
-    
+
     x = height - ( hbar + hmess + 2 ) - ( 2 * W_SPACE ) - htb;
     x -= ( 2 * e -> text -> y_or );
     i = x / e -> text -> font_height;
@@ -210,10 +232,11 @@ void ConfigWindow ( e, width, height )
     ShowControlPanel ( e -> mwin, width, height );
     ShowWindowText ( dpy, e -> text, width - wscroll - 1 - ( 2 * W_SPACE ) ,
 		    height - hbar - hmess - 2 - ( 2 * W_SPACE) - htb);
-    
-    if ( DoesSaveUnders ( DefaultScreenOfDisplay ( dpy ) ) != True )
-      SetMenuPixmap ( dpy, e -> menu, width - wscroll - 1 );
-    
+/*    
+    if ( DoesSaveUnders ( DefaultScreenOfDisplay ( dpy ) ) != True ){
+      SetMenuPixmap ( dpy, e -> menu, width );
+    }
+*/    
     i = e -> text -> no_current_line - e -> text -> n1 - 1;
 #ifdef DEBUG
     fprintf ( stderr, "no_current = %d n1 = %d\n", 
@@ -239,7 +262,8 @@ static void SetProp ( w )
     XSizeHints sizehints;
     XWMHints wm_hints;
     
-    wm_hints.icon_pixmap = text_icon;
+    wm_hints.icon_pixmap = xcoral_icon;
+    wm_hints.icon_mask = xcoral_icon_mask;
     
     sizehints.flags = PMinSize | PMaxSize;
     
@@ -258,7 +282,7 @@ static void SetProp ( w )
     sizehints.max_width = DisplayWidth (dpy,DefaultScreen (dpy));
     sizehints.max_height = DisplayHeight (dpy,DefaultScreen (dpy));
     
-    wm_hints.flags = InputHint | StateHint | IconPixmapHint;
+    wm_hints.flags = InputHint | StateHint | IconPixmapHint | IconMaskHint;
     wm_hints.input = True;
     wm_hints.initial_state = NormalState;
     
@@ -439,12 +463,14 @@ int DeleteWindow ( text )
     Window the_frame;
     
     if ( GetModif ( text ) == True ) {
+      /* Si on est en mode Edir ou shell, on sauvegarde rien */
+      if((strcmp(text -> current_mode -> name,"Edir")!= 0) &&
+	 (strcmp(text -> current_mode -> name,"Shell")!= 0)){
 	if ( SaveCurrentBuffer ( text, F_MENU ) != True )
 	  return -1;
+      }
     }
-    if ( IsLastWindow ( 1 ) == True )
-      exit(0);
-    
+
     for ( t = TWin; t < TWin + MAXWIN; t++ ) {
 	if ( *t == 0 ) continue;
 	if ( text == ( *t ) -> text ) {
@@ -452,8 +478,13 @@ int DeleteWindow ( text )
 	    break;
 	}
     }
-    if ( tmp -> text -> shell_id != 0 )
-      KillShell ( tmp -> text );
+    if ( tmp -> text -> shell_id != 0 ) {
+      int statusp, pid;
+      void CleanFd();
+      (void) kill ( tmp -> text -> shell_id, SIGKILL );
+      pid = wait ( &statusp );
+      (void) CleanFd ( tmp -> text ); 
+    }
 
     if ((tmp -> text -> selection -> select == True)
 	&&(tmp -> text -> window == w_sel)) {
@@ -484,6 +515,12 @@ int DeleteWindow ( text )
 	}
     }
     XDestroyWindow ( dpy, the_frame );
+
+    if ( IsLastWindow (0) == True ) {
+      XFlush(dpy);
+      exit(0);
+    }
+
     return 0;
 }
 
@@ -546,6 +583,33 @@ void Help ( text )
     DisplayManBox ();
 }
 
+/*
+**	Function name : Hanoi
+**
+**	Description : 
+**	Input : 
+**	Ouput :
+*/
+void Hanoi ( text )
+    Text *text;
+{
+  char *msg;
+  int nw = text->win_id;
+  int tn = 5; /* Nombre de tours */
+
+  StorePosition ( text );
+  msg = (char *) ie_call_function ( text, "hanoi", 1, &tn) ;
+  text = update_cwd(nw);
+  if ( msg != 0 )
+    DisplayMessage ( text -> mwin, msg );
+  ie_redisplay ( text );
+  if(TextInBuf(text)==False){
+     TextCursorOff(text);
+     ClearPage(text);
+     TextCursorOn(text);
+  }  
+}
+
 
 
 
