@@ -61,7 +61,7 @@ FCT (static void, ScrollUpFewLines, (Text *text, int n) );
 FCT (static void, ScrollDownFewLines, (Text *text, int n) );
 FCT (static void, ShiftLinesTable, (Text *text, int dir) );
 
-#define S_DELAY 25000
+#define S_DELAY 15000
 
 /*
 **	Function name : FirstPage
@@ -890,7 +890,7 @@ static void ScrollUpFewLines ( text, n )
     }
     ClipOff ( text );
     
-    DisplayMessage ( text -> mwin, " " );
+/*    DisplayMessage ( text -> mwin, " " ); */
     MCLEAR ( text -> stat, MESSAGE );
     MCLEAR ( text -> stat, FIRSTPAGE );
     MCLEAR ( text -> stat, LASTPAGE );
@@ -946,7 +946,7 @@ static void ScrollDownFewLines ( text, n )
       SmallTime(S_DELAY);
     }
     ClipOff ( text );
-    DisplayMessage ( text -> mwin, " " );
+/*    DisplayMessage ( text -> mwin, " " ); */
     MCLEAR ( text -> stat, MESSAGE );
     MCLEAR ( text -> stat, FIRSTPAGE );
     MCLEAR ( text -> stat, LASTPAGE );
@@ -1079,17 +1079,26 @@ void SetAndDisplayPage ( text )
 void ScrollDownCont ( text )
     Text *text;
 {
-    XEvent event;
-    
-    for (;;) {
-	if ( XCheckMaskEvent ( dpy,  ButtonReleaseMask, &event ) == True )
-	  break;
-	if ( text -> no_current_line == text -> lines_in_buf ) continue;
-	ScrollNLine ( 1, text );
-	(void) MoveScrollBar ( dpy, text -> swin, CURRENT,
-			      text -> no_current_line - text -> n1 - 1 );
-	XSync ( dpy, False );
-    }
+  XEvent event;
+  int selection = text-> selection -> select;
+  
+  if (text->selection->select == True)
+    ClearSelection(text, True);
+  
+  for (;;) {
+    if ( XCheckMaskEvent ( dpy,  ButtonReleaseMask, &event ) == True )
+      break;
+    if ( text -> no_current_line == text -> lines_in_buf ) continue;
+    ScrollNLine ( 1, text );
+    (void) MoveScrollBar ( dpy, text -> swin, CURRENT,
+			  text -> no_current_line - text -> n1 - 1 );
+    XSync ( dpy, False );
+    SmallTime(S_DELAY);
+  }
+  if (selection==True){
+    text-> selection -> select = True;
+    (void) RefreshSelection(text);
+  }
 }
 
 
@@ -1105,20 +1114,30 @@ void ScrollDownCont ( text )
 void ScrollUpCont ( text )
     Text *text;
 {
-    XEvent event;
-    
-    for (;;) {
-	if ( XCheckMaskEvent ( dpy,  ButtonReleaseMask, &event ) == True )
-	  break;
-	if ( (text -> no_current_line - text -> n1) == 1 ) {
-	    (void) MoveScrollBar ( dpy, text -> swin, FIRST, 0 );
-	    continue;
-	}
-	ScrollNLine ( -1, text );
-	(void) MoveScrollBar ( dpy, text -> swin, CURRENT,
-			      text -> no_current_line - text -> n1 - 1 );
-	XSync ( dpy, False );
+  XEvent event;
+  int selection = text-> selection -> select;
+  
+  if (text->selection->select == True)
+    ClearSelection(text, True);
+  
+  for (;;) {
+    if ( XCheckMaskEvent ( dpy,  ButtonReleaseMask, &event ) == True )
+      break;
+    if ( (text -> no_current_line - text -> n1) == 1 ) {
+      (void) MoveScrollBar ( dpy, text -> swin, FIRST, 0 );
+      continue;
     }
+    ScrollNLine ( -1, text );
+    (void) MoveScrollBar ( dpy, text -> swin, CURRENT,
+			  text -> no_current_line - text -> n1 - 1 );
+    XSync ( dpy, False );
+    SmallTime(S_DELAY);
+  }
+
+  if (selection==True){
+    text-> selection -> select = True;
+    (void) RefreshSelection(text);
+  }
 }
 
 
