@@ -65,15 +65,20 @@
 #include <X11/cursorfont.h>
 #include <X11/Xutil.h>
 #include <X11/keysym.h>
-#include <string.h>
 #include <pwd.h>
 
-#ifndef apollo
-#ifdef __FreeBSD__
-#include <stdlib.h>
-#else /* !__FreeBSD__ */
-#include <malloc.h>
+#if HAVE_STRING_H
+#include <string.h>
+#else
+#include <strings.h>
 #endif
+
+#if STDC_HEADERS
+#  include <stdlib.h>
+#else
+#  if HAVE_MALLOC_H
+#    include <malloc.h>
+#  endif
 #endif
 
 #include "xc_conf.h"
@@ -109,10 +114,10 @@ static XrmOptionDescRec opTable [] = {
   {"-display",	"*display",	XrmoptionSepArg,	(caddr_t) 0 },
   {"-fn",	"*font",	XrmoptionSepArg,	(caddr_t) 0 },
   {"-font",	"*font",	XrmoptionSepArg,	(caddr_t) 0 },
-  {"-fg",	"*foreground",	XrmoptionSepArg,	(caddr_t) 0 },
-  {"-foreground",	"*foreground",	XrmoptionSepArg,	(caddr_t) 0 },
-  {"-bg",		"*background",	XrmoptionSepArg,	(caddr_t) 0 },
-  {"-background",	"*background",	XrmoptionSepArg,	(caddr_t) 0 },
+  {"-fg",	"tforeground",	XrmoptionSepArg,	(caddr_t) 0 },
+  {"-foreground",	"tforeground",	XrmoptionSepArg,	(caddr_t) 0 },
+  {"-bg",		"tbackground",	XrmoptionSepArg,	(caddr_t) 0 },
+  {"-background",	"tbackground",	XrmoptionSepArg,	(caddr_t) 0 },
   {"-mfn",	"*mfont",	XrmoptionSepArg,	(caddr_t) 0 },
   {"-mfont",	"*mfont",	XrmoptionSepArg,	(caddr_t) 0 },
   {"-mfg",	"*mfg",		XrmoptionSepArg,	(caddr_t) 0 },
@@ -353,9 +358,12 @@ static void SetDefaultBG ( bg, fg, bwbg, bwfg, colorbg, colorfg)
     }
     else { /* color */
 	*bg = PixelValue ( dpy, colorbg, &result );
-	if ( result == False )
-	  *bg = BlackPixel ( dpy, DefaultScreen (dpy));
-	if ( *bg == *fg ) {
+	if ( result == False ) {
+	  *bg = WhitePixel ( dpy, DefaultScreen (dpy));
+	  *fg = BlackPixel ( dpy, DefaultScreen (dpy));
+	  
+	}
+	else if ( *bg == *fg ) {
 	    *bg = PixelValue ( dpy, colorfg, &result );
 	    if ( result == False )
 	      *bg = WhitePixel ( dpy, DefaultScreen (dpy));
@@ -616,7 +624,7 @@ static void SetTextFG ()
     int result;
     
     if ( XrmGetResource ( rDB, "xcoral.fg",
-			 "xcoral.foreground", str_type,&value ) == True ) {
+			 "xcoral.tforeground", str_type,&value ) == True ) {
 	
 	buf = (char *) malloc ( (unsigned) (value.size + 1) );
 	bzero ( buf, (int) (value.size + 1));
@@ -685,7 +693,7 @@ static void SetTextBG ()
     /* Le Foreground est deja connu */
     
     if ( XrmGetResource ( rDB, "xcoral.bg",
-			 "xcoral.background", str_type,&value ) == True ) {
+			 "xcoral.tbackground", str_type,&value ) == True ) {
 	/* 
 	 * Le bg/background est defini dans les resources ou dans
 	 * la ligne de commande
@@ -811,7 +819,7 @@ static void SetFont ()
 **	Function name : SetGeometry
 **
 **	Description : Initialisation de la geometrie de 
-**		la feneter printcipale.
+**		la fenetre principale.
 **	Input : 
 **	Ouput :
 */
@@ -879,8 +887,10 @@ static void SetGeometry2 (opt,name,class)
 	 *	Largeur par defaut =  13/20 de l'ecran.
 	 *	Hauteur par defaut =  12/20 de l'ecran.
 	 */
-	opt->width = (DisplayWidth ( dpy, DefaultScreen (dpy ) ) * 13) / 20;
-	opt->height = (DisplayHeight ( dpy, DefaultScreen (dpy ) ) * 12) / 20;
+/*	opt->width = (DisplayWidth ( dpy, DefaultScreen (dpy ) ) * 14) / 20; */
+      opt->width = 700;
+/*	opt->height = (DisplayHeight ( dpy, DefaultScreen (dpy ) ) * 12) / 20; */
+      opt->height = 460; /* 24 lignes avec la police par defaut */
 	opt->x = -1;
 	opt->y = -1;
 	
