@@ -62,7 +62,7 @@ FCT (static void, display_one_line, (Text *text));
 
 FCT (void, ClearSelection, (Text *text, int select) );
 FCT (void, RefreshSelection, (Text *text) );
-FCT (void, HandleSelection, (Text *text, XEvent *ev) );
+FCT (Time, HandleSelection, (Text *text, XEvent *ev) );
 FCT (void, StartSelection, (Text *text) );
 FCT (void, EndSelection, (Text *text) );
 FCT (void, UpdateSelection, (Text *text) );
@@ -75,6 +75,7 @@ static int root_x, root_y, win_x, win_y;
 static int select_run = False;
 static XEvent event;
 static scroll_x = 0;
+static scroll_run = False;
 static GC sgc;
 
 /*
@@ -135,7 +136,7 @@ void InitSelection(dpy, fg, bg)
 **	Input :
 **	Output :
 */
-void HandleSelection(text, ev)
+Time HandleSelection(text, ev)
     Text *text;
     XEvent *ev;
 {
@@ -176,7 +177,11 @@ void HandleSelection(text, ev)
       }
       TextCursorOn (text);
       select_run = False;
-      return;
+      if(scroll_run){
+	scroll_run = False;
+	(void) RefreshSelection(text);
+      }
+      return event.xbutton.time;
     case MotionNotify:
       text -> selection -> select = True;
       select_run = True;
@@ -190,9 +195,11 @@ void HandleSelection(text, ev)
       else if (win_y < text -> y_or) {
 	if(text->sl)
 	  continue;
+	scroll_run = True;
 	while (XCheckMaskEvent ( dpy,  ButtonReleaseMask | ButtonMotionMask, 
 				&event ) == False){
 	  if ( (text -> no_current_line - text -> n1) != 1 ) {
+	    ClearSelection(text, True);
 	    ScrollNLine ( -1, text );
 	    (void) MoveScrollBar ( dpy, text -> swin, CURRENT,
 				  text -> no_current_line - text -> n1 - 1 );
@@ -210,9 +217,11 @@ void HandleSelection(text, ev)
       else if (win_y > mh ){
 	if(text->sl)
 	  continue;
+	scroll_run = True;
 	while (XCheckMaskEvent ( dpy,  ButtonReleaseMask | ButtonMotionMask, 
 				&event ) == False){
 	  if ( text -> no_current_line != text -> lines_in_buf ){
+	    ClearSelection(text, True);
 	    ScrollNLine ( 1, text ); 
 	    (void) MoveScrollBar ( dpy, text -> swin, CURRENT,
 				  text -> no_current_line - text -> n1 - 1 );
@@ -225,8 +234,13 @@ void HandleSelection(text, ev)
 	  XPutBackEvent (dpy, &event);
 	TextCursorOn (text);
       }
-      else
+      else {
+	if(scroll_run){
+	  scroll_run = False;
+	  (void) RefreshSelection(text);
+	}
 	(void) handle_select_internal (text);
+      }
     }
   }
 }
@@ -267,7 +281,8 @@ static void handle_select_internal(text)
     XWarpPointer (dpy, None, text -> window, 0,0,0,0, 
 		  text -> x_pos + 4, text -> y_pos + 4);
     text -> selection -> x_el = text -> x_pos;
-    (void) RefreshSelection(text);
+ /*   if (scroll_run==True) */
+      (void) RefreshSelection(text);
     while ( XCheckMaskEvent ( dpy, ButtonMotionMask, &event ));
     TextCursorOff (text);
     FreezeTextCursor (text);
@@ -305,10 +320,12 @@ static void handle_select_internal(text)
     
     r[0].y = text -> y_or;
     r[0].height = text -> lines_in_page * text -> font_height;
-    
-    XSetClipRectangles ( dpy, sgc, 0, 0, r, 1, False );
-    XFillRectangles (dpy, text -> window, sgc, rect, nrect);
-    XSetClipMask ( dpy, sgc, None );
+
+    if (scroll_run==False) {
+      XSetClipRectangles ( dpy, sgc, 0, 0, r, 1, False );
+      XFillRectangles (dpy, text -> window, sgc, rect, nrect);
+      XSetClipMask ( dpy, sgc, None );
+    }
     for (i=0;i<8;i++) {
       rect[i].x = rect[i].y = rect[i].width;
       rect[i].height = text -> font_height;
@@ -366,7 +383,8 @@ static void video_after_cursor(text)
     Text *text;
 {
 /* #define DEBUG9 */
-  if (text -> x_pos > text -> selection -> x_el) {
+/*  if (text -> x_pos > text -> selection -> x_el) { */
+  if (text -> x_pos >= text -> selection -> x_el) {
     /* vers la droite */
 #ifdef DEBUG9
     (void) fprintf (stderr, "91\n");
@@ -383,8 +401,11 @@ static void video_after_cursor(text)
   }
   else {
     /* vers la gauche */
+/*    
     if ((text -> x_pos + text -> cursor_width) != text -> selection -> x_sl 
 	&& (text -> x_pos + text -> cursor_width) != text -> selection -> x_el){
+*/
+    if (text -> x_pos < text -> selection -> x_el) {
 #ifdef DEBUG9
       (void) fprintf (stderr, "92\n");
 #endif /* DEBUG9 */
@@ -770,9 +791,11 @@ void RefreshSelection(text)
     r[0].y = text -> y_or;
     r[0].height = text -> lines_in_page * text -> font_height;
 
-    XSetClipRectangles ( dpy, sgc, 0, 0, r, 1, False );
-    XFillRectangles (dpy, text -> window, sgc, rect, nrect);
-    XSetClipMask ( dpy, sgc, None );
+    if (scroll_run==False) {    
+      XSetClipRectangles ( dpy, sgc, 0, 0, r, 1, False );
+      XFillRectangles (dpy, text -> window, sgc, rect, nrect);
+      XSetClipMask ( dpy, sgc, None );
+    }
 
     for (i=0;i<8;i++) {
       rect[i].height = text -> font_height;
@@ -1007,7 +1030,7 @@ static void get_bytes_selection(text)
 #ifdef DEBUG11
       (void) fprintf (stderr, "111 s equal e, sl sup el\n");
 #endif /* DEBUG11 */
-      Store_bytes((char *)(RightBuf(text->buf)+1),nc-1);
+      Store_bytes((char *)(RightBuf(text->buf)/*+1*/),nc/*-1*/);
     }
     else { /* nc<0 */
 #ifdef DEBUG11
@@ -1030,8 +1053,8 @@ static void get_bytes_selection(text)
 	nl--;
       p++;
     }
-    if(*start != '\n')
-      start ++;
+/*    if(*start != '\n')
+      start ++; */
     Store_bytes(start, p - start + text -> selection -> ncfl_sl);
   }
   
