@@ -43,8 +43,12 @@
 #include <sys/types.h>
 #include <sys/time.h>
 #include <signal.h>
-#include <string.h>
 
+#if HAVE_STRING_H
+#include <string.h>
+#else
+#include <strings.h>
+#endif
 
 #include "xcoral.h"
 #include "get_file.h"
@@ -59,6 +63,7 @@
 
 #include "tool_bar.h"
 #include "buttons_bits.h"
+#include "browser_init.h"
 
 extern Display *dpy;
 
@@ -74,14 +79,37 @@ void (*f_tb_window []) () = {
   SetCCMode,
   SetJavaMode,
   SetLatexMode,
+  DisplayBrowser,
   ColorBuffer,
-  CurrentLineToTopFromMenu,
   DisplayManBox,
   ProgrammingUtil,
   LatexMacros,
   HtmlMacros,
   RcsCommands,
-  MiscCommands,
+/*  MiscCommands, */
+  0
+};
+
+static unsigned char *bname [] = {
+  "Open file",
+  "New window",
+  "Save file",
+  "Cut",
+  "Paste",
+  "Undo",
+  "Default mode",
+  "C mode",
+  "C++ mode",
+  "Java mode",
+  "LaTeX mode",
+  "Class Browser",
+  "Syntax highlight",
+  "Manual",
+  "Programming utilities",
+  "LaTeX utilities",
+  "Html utilities",
+  "Rcs utilities",
+/*  "Utils cmds", */
   0
 };
 
@@ -97,14 +125,37 @@ static unsigned char *bitmap_name [] = {
   cplus_bits,
   java_bits,
   latex_bits,
+  browser_bits,
   color_bits,
-  top_bits,
   man_bits,
   cc_util_bits,
   latex_util_bits,
   html_bits,
   rcs_bits,
-  cmds_bits,
+/*  cmds_bits, */
+  0
+};
+
+static unsigned char **xpm_name [] = {
+  xpm_dired_bits,
+  xpm_new_window_bits,
+  xpm_save_bits,
+  xpm_cut_bits,
+  xpm_paste_bits,
+  xpm_undo_bits,
+  xpm_dlt_bits,
+  xpm_c_bits,
+  xpm_cplus_bits,
+  xpm_java_bits,
+  xpm_latex_bits,
+  xpm_browser_bits,
+  xpm_color_bits,
+  xpm_man_bits,
+  xpm_cc_util_bits,
+  xpm_latex_util_bits,
+  xpm_html_bits,
+  xpm_rcs_bits,
+/*  xpm_cmds_bits, */
   0
 };
 
@@ -112,6 +163,8 @@ static   unsigned long tb_fg, tb_bg, tb_top_sh,
   tb_bot_sh, bg_parent, tb_green, tb_red, tb_blue;
 static GC tb_gc;
 static Pixmap logo_pix, slogo_pix;
+static Pixmap b_pix [24], logo_pixmap,logo_mask;
+static XImage *b_image [24], *logo_image;
 
 /*
 **	Function name : InitToolBar
@@ -126,10 +179,11 @@ void InitToolBar(bg, ts, bs)
   XGCValues 	gcv;
   Window		root;
   unsigned long gray, gainsboro, dimgray;
-  int result;
+  int result, depth, i;
   
   root = DefaultRootWindow ( dpy );
   tb_gc = XCreateGC ( dpy, root, 0, &gcv );
+  depth = DefaultDepth ( dpy, DefaultScreen ( dpy ));
 
   gray = PixelValue ( dpy, "lightgrey", &result );
   if ( result == False )
@@ -166,6 +220,20 @@ void InitToolBar(bg, ts, bs)
   bg_parent = bg;
 
   XSetState ( dpy, tb_gc, tb_fg, tb_bg, GXcopy, AllPlanes );
+  for (i=0;i<N_BTOOLS;i++) {
+    if ((depth == 16)||(depth == 24)) {
+      b_image [i] = (XImage *)LoadImage256 ((char **)xpm_name [i]);
+      b_pix [i] = XCreatePixmap (dpy, root, 32, 32, depth);
+      XPutImage (dpy, b_pix [i], tb_gc, b_image[i], 0, 0, 0, 0, 32, 32);
+    }
+    else {
+      b_pix [i] = XCreatePixmapFromBitmapData ( dpy, root, 
+				   (char *) bitmap_name [i],
+				   TOOL_WINDOW_SIZE,
+				   TOOL_WINDOW_SIZE, 
+				   tb_fg, tb_bg, depth );
+    }
+  }
 }
 
 
@@ -201,15 +269,12 @@ ToolBar *CreateToolBar(parent, x, y)
 			  WhitePixel(dpy, DefaultScreen(dpy)));
     
     tb -> tw [i].f = f_tb_window[i];
-    XSelectInput ( dpy, tb -> tw [i].w, ExposureMask | ButtonPressMask | ButtonReleaseMask );
+    XSelectInput ( dpy, tb -> tw [i].w, ExposureMask | ButtonPressMask | ButtonReleaseMask  
+		  | EnterWindowMask );
 
-    tb -> tw [i].pix = 
-      XCreatePixmapFromBitmapData ( dpy, root, 
-				   (char *) bitmap_name [i],
-				   TOOL_WINDOW_SIZE,
-				   TOOL_WINDOW_SIZE, 
-				   tb_fg, tb_bg, depth );
+    tb -> tw [i].pix = b_pix [i];
     XSetWindowBackgroundPixmap ( dpy, tb -> tw [i].w, tb -> tw [i].pix );
+    tb -> tw [i].title = bname [i];
   }
   
   XGetWindowAttributes ( dpy, parent, &att );
@@ -225,15 +290,31 @@ ToolBar *CreateToolBar(parent, x, y)
   
   XSelectInput ( dpy, tb -> w_logo, ExposureMask );
 
-  logo_pix = XCreatePixmapFromBitmapData ( dpy, root, 
-				   xlogo32_bits,
+  if ((depth == 16)||(depth == 24)) {
+    logo_image = (XImage *)LoadImage256 ((char **)xpm_logo);
+    logo_pixmap = XCreatePixmap (dpy, root, 32, 32, depth);
+    /* Le mask */
+    logo_mask = XCreatePixmapFromBitmapData ( dpy, root, 
+				   logo_bits,
 				   TOOL_WINDOW_SIZE,
 				   TOOL_WINDOW_SIZE, 
-				   tb_green, bg_parent, depth );
+				   BlackPixel(dpy, DefaultScreen(dpy)),
+					     bg_parent, 1 );
+    XPutImage (dpy, logo_pixmap, tb_gc, logo_image, 0, 0, 0, 0, 32, 32);
+  }
+
+/*  XSetWindowBackgroundPixmap ( dpy, tb -> w_logo, logo_pixmap); */
+  logo_pix = XCreatePixmapFromBitmapData ( dpy, root, 
+				   /* xlogo32_bits, */
+					  bwlogo_bits,
+				   TOOL_WINDOW_SIZE,
+				   TOOL_WINDOW_SIZE, 
+				   BlackPixel(dpy, DefaultScreen(dpy)),
+					  bg_parent, depth);
  
   slogo_pix = XCreatePixmapFromBitmapData ( dpy, root,
 					   slogo_bits,
-					   34, 8,
+					   40, 8,
 					   BlackPixel(dpy, DefaultScreen(dpy)),
 					   bg_parent, depth );
  
@@ -278,8 +359,13 @@ int ExposeToolBar(tool_bar, ev)
 
   for (i=0;i<N_BTOOLS;i++) {
     if (tool_bar -> tw [i].w == ev -> xexpose.window) {
-      Display3D ( dpy, ev -> xexpose.window, tb_top_sh, tb_bot_sh, 2, 0 );
-      if ( i == COLOR_BUTTON ) {
+      if ((DefaultDepth(dpy,DefaultScreen(dpy)) == 16)
+	  ||(DefaultDepth(dpy,DefaultScreen(dpy)) == 24))
+	Display3D ( dpy, ev -> xexpose.window, tb_top_sh, tb_bot_sh, 1, 0 );
+      else
+	Display3D ( dpy, ev -> xexpose.window, tb_top_sh, tb_bot_sh, 2, 0 );
+	
+      if ((i==COLOR_BUTTON)&&(DefaultDepth(dpy,DefaultScreen(dpy))==8)) {
 	XSetForeground (dpy, tb_gc, tb_red);
 	XFillRectangle(dpy, tool_bar -> tw [i].w, tb_gc, 7, 7, 11, 5);
 	XSetForeground (dpy, tb_gc, tb_green);
@@ -288,16 +374,26 @@ int ExposeToolBar(tool_bar, ev)
 	XFillRectangle(dpy, tool_bar -> tw [i].w, tb_gc, 8, 21, 11, 5);
 	XSetForeground (dpy, tb_gc, tb_fg);
       }
+
       return (True);
     }
   }
   if (tool_bar -> w_logo == ev -> xexpose.window) {
-    /* Affiche le X */
-    XCopyArea (dpy, logo_pix, tool_bar -> w_logo, tb_gc, 0, 0, 32, 32, 0, 0);
-    
-    /* Affiche coral */
-    XCopyArea (dpy, slogo_pix, tool_bar -> w_logo, tb_gc, 0, 0, 34, 8, 22, 15);
-    return (True);
+    if ((DefaultDepth(dpy,DefaultScreen(dpy)) == 16)
+	||(DefaultDepth(dpy,DefaultScreen(dpy)) == 24)) {
+      XSetClipMask(dpy, tb_gc, logo_mask);
+      XCopyArea (dpy, logo_pixmap, tool_bar -> w_logo, tb_gc, 0, 0, 32, 32, 0, 0);
+      XSetClipMask(dpy, tb_gc, None);
+      XCopyArea (dpy, slogo_pix, tool_bar -> w_logo, tb_gc, 0, 0, 40, 8, 12, 22);
+      return (True);
+    }
+    else {
+      /* Affiche le logo en noir et blanc */
+      XCopyArea (dpy, logo_pix, tool_bar -> w_logo, tb_gc, 0, 0, 32, 32, 0, 0);
+      /* Affiche la chaine xcoral */
+      XCopyArea (dpy, slogo_pix, tool_bar -> w_logo, tb_gc, 0, 0, 40, 8, 12, 24);
+      return (True);
+    }
   }
   return (False);
 }
@@ -326,3 +422,19 @@ int ToolBarButton(edwin, ev)
   }
   return (False);
 }
+
+int EnterInToolBar (t, w)
+    EdWin *t;
+    Window w;
+{
+  int i = 0;
+
+  for (i=0;i<N_BTOOLS;i++) {
+    if (w == t -> tool_bar -> tw [i].w) {
+        DisplayMessage ( t -> mwin, t -> tool_bar -> tw [i].title );
+	return True;
+    }
+  }
+  return False;
+}
+
