@@ -41,12 +41,20 @@
 #include <stdio.h>
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
-#ifdef __FreeBSD__
-#include <stdlib.h>
-#else /* !__FreeBSD__ */
-#include <malloc.h>
+
+#if STDC_HEADERS
+#  include <stdlib.h>
+#else
+#  if HAVE_MALLOC_H
+#    include <malloc.h>
+#  endif
 #endif
+
+#if HAVE_STRING_H
 #include <string.h>
+#else
+#include <strings.h>
+#endif
 
 #include "main_text.h"
 #include "page.h"
@@ -636,10 +644,11 @@ void DoUndo ( text )
 	}
     }
     else {
-	if ( tmp -> op == U_ADD ) 
-	  (void) Do_UDelChars ( text );
-	else 
-	  (void) Do_UAddChars ( text );
+      if ( tmp -> op == U_ADD ) 
+	(void) Do_UDelChars ( text );
+      else {
+	(void) Do_UAddChars ( text );
+      }
     }
     text -> u_index ++;
     text -> current_mode = save_mode;
@@ -728,7 +737,7 @@ static void Do_UReplace ( text, type, old_line, old_pos )
 	SetTextModif ( text );
     }
     
-    tmp = (char *) malloc ( (unsigned) strlen ( str_old ) + 1 );
+    tmp = (char *) malloc ( (unsigned) strlen ( current_u  -> str_old ) + 1 );
 #ifdef U_TRACE
     (void) fprintf ( stderr, "Do_UReplace : malloc (tmp) %d\n", tmp );
 #endif /* U_TRACE */
