@@ -165,6 +165,7 @@ static void MapWarningBox ()
     XMapSubwindows ( dpy, w_box.frame );
     XMapSubwindows ( dpy, w_box.ctr );
     XMapRaised ( dpy, w_box.frame );
+
 }
 
 /*
@@ -194,6 +195,7 @@ void ConfigWarningBox ( width, height )
 {
     int m_height, bx, by;
     static int wb_first_conf = True;
+    XEvent ev;
 
     if ( (width == w_box.width) 
 	&& (height == w_box.height) 
@@ -217,6 +219,7 @@ void ConfigWarningBox ( width, height )
     XMoveWindow ( dpy, w_box.save, bx, by );
     XMoveWindow ( dpy, w_box.close, ( 3 * bx ) + w_box.b_width, by );
     
+    while ( XCheckWindowEvent ( dpy, w_box.frame,StructureNotifyMask, &ev ));
     ConfigTextAndScroll ( w_box.text, width, m_height, WB_SPACE );
 		   
 }
