@@ -44,19 +44,47 @@
 /*
  *	Les Fontes
  */
-#define TEXT_FONT "-adobe-courier-medium-r-normal--14-140-75-75-m-90-iso8859-1"
-#define MENU_FONT "-adobe-times-medium-r-normal--18-180-75-75-p-94-iso8859-1"
 
-#define B_FONT 	   "-adobe-courier-bold-r-normal--14-140-75-75-m-90-iso8859-1"
+#define TEXT_FONT "-adobe-courier-medium-r-normal--12-120-75-75-m-70-iso8859-1"
+/*#define TEXT_FONT "-misc-fixed-medium-r-normal--13-120-75-75-c-70-iso8859-1" */
+
+#define MENU_FONT   "-misc-fixed-bold-r-normal--13-120-75-75-c-70-iso8859-1"
+#define B_FONT     "-misc-fixed-bold-r-normal--13-120-75-75-c-70-iso8859-1"
+#define WBOX_FONT  "-misc-fixed-bold-r-normal--13-120-75-75-c-70-iso8859-1"
+#define DBOX_FONT  "-misc-fixed-bold-r-normal--13-120-75-75-c-70-iso8859-1"
+#define FSBOX_FONT "-misc-fixed-bold-r-normal--13-120-75-75-c-70-iso8859-1"
+#define LBOX_FONT  "-misc-fixed-bold-r-normal--13-120-75-75-c-70-iso8859-1"
+#define MBOX_FONT  "-misc-fixed-bold-r-normal--13-120-75-75-c-70-iso8859-1"
+#define TBOX_FONT  "-misc-fixed-bold-r-normal--13-120-75-75-c-70-iso8859-1"
+
+/*
+#define TEXT_FONT "-adobe-courier-medium-r-normal--12-120-75-75-m-70-iso8859-1"
+#define MENU_FONT   "-adobe-courier-medium-r-normal--12-120-75-75-m-70-iso8859-1"
+
+#define B_FONT 	   "-adobe-courier-medium-r-normal--12-120-75-75-m-70-iso8859-1"
+#define WBOX_FONT  "-adobe-courier-medium-r-normal--12-120-75-75-m-70-iso8859-1"
+#define DBOX_FONT  "-adobe-courier-medium-r-normal--12-120-75-75-m-70-iso8859-1"
+#define FSBOX_FONT "-adobe-courier-medium-r-normal--12-120-75-75-m-70-iso8859-1"
+#define LBOX_FONT  "-adobe-courier-medium-r-normal--12-120-75-75-m-70-iso8859-1"
+#define MBOX_FONT  "-adobe-courier-medium-r-normal--12-120-75-75-m-70-iso8859-1"
+
+#define MENU_FONT   "-adobe-courier-bold-r-normal--14-140-75-75-m-90-iso8859-1"
+#define TEXT_FONT "-adobe-courier-medium-r-normal--14-140-75-75-m-90-iso8859-1"
+#define B_FONT     "-adobe-courier-bold-r-normal--14-140-75-75-m-90-iso8859-1"
 #define WBOX_FONT  "-adobe-courier-bold-r-normal--14-140-75-75-m-90-iso8859-1"
 #define DBOX_FONT  "-adobe-courier-bold-r-normal--14-140-75-75-m-90-iso8859-1"
 #define FSBOX_FONT "-adobe-courier-bold-r-normal--14-140-75-75-m-90-iso8859-1"
 #define LBOX_FONT  "-adobe-courier-bold-r-normal--14-140-75-75-m-90-iso8859-1"
 #define MBOX_FONT  "-adobe-courier-bold-r-normal--14-140-75-75-m-90-iso8859-1"
+*/
+
 
 /* Dark background (default) */
-#define COLOR_TEXT_BG		"midnightblue"
-#define COLOR_TEXT_FG		"lemonchiffon"
+/* #define COLOR_TEXT_BG		"midnightblue" */
+#define COLOR_TEXT_BG		"ivory"
+/* #define COLOR_TEXT_BG		"honeydew" */
+/* #define COLOR_TEXT_FG		"lemonchiffon" */
+#define COLOR_TEXT_FG		"black"
 
 /* Light background */
 /*
@@ -64,10 +92,12 @@
 #define COLOR_TEXT_FG		"black"
 */
 
-#define COLOR_MENU_BG		"gray60"  /*"lightslategray"*/
+#define COLOR_MENU_BG		"gray60"  /*"slategray"*/
 #define COLOR_MENU_FG		"lemonchiffon"
-#define COLOR_CONTROL_BG	"gray60"  /*"lightslategray"*/
+/* #define COLOR_MENU_FG		"black" */
+#define COLOR_CONTROL_BG	"gray60"  /*"slategray"*/
 #define COLOR_CONTROL_FG	"lemonchiffon"
+/* #define COLOR_CONTROL_FG	"black" */
 
 /*
  *	Mono
