@@ -45,15 +45,10 @@
 #include <X11/Xutil.h>
 #include <X11/keysym.h>
 #include <sys/param.h>
-#if defined(SVR4) || defined(UNIXWARE) || defined(SVR4)
-#include <string.h>
-extern void bzero();
-#else
-#include <strings.h>
-#endif
 
 #include <ctype.h>
 #include <locale.h>
+#include <unistd.h>
 
 #include "options.h"
 #include "xcoral.h"
@@ -72,13 +67,23 @@ extern void bzero();
 #include "new_window.h"
 #include "tool_bar.h"
 
+#if HAVE_STRING_H
+#  include <string.h>
+#  if !HAVE_BZERO
+extern FCT (void, bzero, (char *dst, int len) );
+extern FCT (void, bcopy, (char *src, char *dst, int len) );
+#  endif
+#else
+#  include <strings.h>
+#endif
+
 Display		*dpy;
 EdWin		*TWin [MAXWIN], *edwin; /* La table des fenetres */
 XContext	EdContext; /* Pour switcher */
 int no_window;
 
-FCT (static void, contHandler, () );
-FCT (static void, stopHandler, () );
+FCT (static RETSIGTYPE, contHandler, () );
+FCT (static RETSIGTYPE, stopHandler, () );
 
 extern init_smac();
 
@@ -87,7 +92,7 @@ extern init_smac();
  **	Creer la premiere fenetre de texte et entre dans
  **	la boucle d'evenements.
  */
-void main ( argc, argv ) 
+main ( argc, argv ) 
     int argc;
     char **argv;
 {
@@ -99,8 +104,11 @@ void main ( argc, argv )
   extern char *ie_load_file ();
   extern void exit ();
   extern char  *getcwd();
-  extern FCT(void, error_ctrl_c,(int));
+  extern FCT(RETSIGTYPE, error_ctrl_c,(int));
   extern char *getenv ();
+  extern int _startup;
+  FILE *fd;
+  char pp[BUFSIZ];
   
 #if defined(DEBUG) && defined(sparc)
   malloc_debug(2);
@@ -110,7 +118,11 @@ void main ( argc, argv )
   /*
    * Ou suis-je dans quelle etagere.
    */
+#if HAVE_GETCWD
   if ( getcwd ( (char *) pathname, MAXPATHLEN ) == 0 ) {
+#else
+  if ( getwd  ( (char *) pathname) == 0 ) {
+#endif
     (void) fprintf ( stderr, "Getwd error\n" );
     (void) exit ( 1 );
   }
@@ -168,25 +180,58 @@ void main ( argc, argv )
   InitSelection (dpy,GetOpColor ( OP_TEXT_FG ), GetOpColor ( OP_TEXT_BG ));
   InitToolBar(GetOpColor ( OP_MENU_BG ), GetOpColor ( OP_MENU_TS ),
 	      GetOpColor ( OP_MENU_BS ));
+  InitTrombinesBox ();
+  InitPcmap ();
   
-  /* 
-   * Chargement de '.xcoralrc'
-   */
-  bzero ( tmp, MAXPATHLEN );
-  xcoralrc = (char *) getenv ("XCORALRC");
-  if (!xcoralrc) {
-    (void) sprintf ( tmp, (char *) getenv ( "HOME" ) );
-    (void) strcat ( tmp, "/.xcoralrc" );
+  /* Chargement de .xcoralrc et SmacLib */
+  /* On verifie d'abord l'existence de SmacLib */
+  (void) sprintf(tmp,"%s/xcoralrc.lf",XCORAL_LIB_DIR);
+  if (access(tmp,R_OK)==0){
+    /* SmacLib Ok */
+    bzero ( tmp, MAXPATHLEN );
+    xcoralrc = (char *) getenv ("XCORALRC");
+    if (!xcoralrc) {
+      (void) sprintf ( tmp, (char *) getenv ( "HOME" ) );
+      (void) strcat ( tmp, "/.xcoralrc" );
+    }
+    else 
+      (void) strcpy ( tmp, xcoralrc );
+
+    if (access(tmp,R_OK)!=0){
+      /* pas de xcoralrc defini, ca craint */
+      /* On copie celui qui est dans SmacLib */
+      (void) sprintf (tmp, "cp %s/xcoralrc.lf %s/.xcoralrc\n",
+		      XCORAL_LIB_DIR,(char *)getenv ("HOME"));
+      system(tmp);
+      (void) sprintf (tmp, (char *) getenv ("HOME"));
+      (void) strcat (tmp, "/.xcoralrc");
+    }
+    else {
+      /* On verifie que la version est correcte */
+      if ((fd = fopen((char *)tmp,"r"))!=0){
+	fgets(pp,8,fd);
+	if (strncmp((char *)(pp+3),CURRENT_VERSION,4)!=0){
+	  /* .xcoralrc ne correspond pas a la version courante. Copie */
+	  (void) sprintf(pp,"%s/.xcoralrc.old",(char *)getenv ("HOME"));
+	  rename (tmp,pp);
+	  /* On copie celui qui est dans SmacLib */
+	  (void) sprintf (tmp, "cp %s/xcoralrc.lf %s/.xcoralrc\n",
+			  XCORAL_LIB_DIR,(char *)getenv ("HOME"));
+	  system(tmp);
+	  (void) sprintf (tmp, (char *) getenv ("HOME"));
+	  (void) strcat (tmp, "/.xcoralrc");
+	  (void) fprintf (stderr,"Your .xcoralrc file is obsolete so it has been moved as .xcoralrc.old\n");
+	  (void) fprintf (stderr,"A new .xcoralrc file has been created in your home directory\n");
+	}
+      }
+    }
+    msg = (char *) ie_load_file ( (Text *) 0, tmp ) ;      
   }
   else {
-    (void) strcpy ( tmp, xcoralrc );
+    (void) fprintf ( stderr, "%s\n", "Warning: SmacLib not installed");    
   }
-  msg = (char *) ie_load_file ( (Text *) 0, tmp ) ;
+  
   chdir(pathname );
-  
-  
-  if ( msg)
-    (void) fprintf ( stderr, "%s\n", msg );    
   /*
    * Le mode 'input_str'
    */
@@ -219,6 +264,7 @@ void main ( argc, argv )
       SetCtrMode ( win -> text -> mwin, win -> text -> current_mode );
       (void) strcpy ( win -> text -> filename, *argv );
       (void) strcpy ( win -> text -> current_dir, pathname );
+      _startup ++;
       if ( LoadFile ( win -> text, (char *) *argv, NEW ) != -1 )
 	chdir(pathname);
       else
@@ -231,9 +277,11 @@ void main ( argc, argv )
    * le continue (pour des raisons tordues).
    */
   (void) signal ( SIGINT, error_ctrl_c );
+/* #define DEBUG */
 #ifndef DEBUG
   (void) signal ( SIGQUIT, SIG_IGN );
 #endif
+#undef DEBUG
   /* 
    * Affichage des premieres fenetres et on attend que les Events y se
    * pointent.
@@ -247,6 +295,7 @@ void main ( argc, argv )
     }
   }
   no_window = False;
+
   WaitForEvent ();
   
   /*NOTREACHED*/
@@ -259,7 +308,7 @@ void main ( argc, argv )
 **		ou des	evenements on ignore le signal.
 **
 */
-static void stopHandler ()
+static RETSIGTYPE stopHandler ()
 {
 #ifdef DEBUG
   (void) fprintf ( stderr, "Stop\n" );
@@ -272,7 +321,7 @@ static void stopHandler ()
     (void) kill ( getpid(), SIGTSTP );
   }
   else
-    (void) signal ( SIGTSTP,  (void (*)()) stopHandler );
+    (void) signal ( SIGTSTP, stopHandler );
 }
 
 
@@ -283,7 +332,7 @@ static void stopHandler ()
 **		les evenements de type ButtonPress recus pendant que le
 **		process etait stoppe. 
 */
-static void contHandler ()
+static RETSIGTYPE contHandler ()
 {
   XEvent event;
 #ifdef DEBUG
@@ -295,21 +344,48 @@ static void contHandler ()
   if ( QLength ( dpy ) != 0 ) 
     while ( XCheckMaskEvent ( dpy, ButtonPress, &event ));
   
-  (void) signal ( SIGTSTP, (void (*) ()) stopHandler );
+  (void) signal ( SIGTSTP, stopHandler );
   (void) signal ( SIGCONT, SIG_DFL );
   (void) kill ( getpid (), SIGCONT );
   
   XFlush ( dpy ); 
 }
 
-#ifdef SYSV
-#include <memory.h>
-void bzero(char *dst, int len)
+#if HAVE_STRING_H
+
+#if !HAVE_BZERO
+#  if HAVE_MEMORY_H
+#    include <memory.h>
+#  endif
+void bzero(dst, len)
+  char *dst;
+  int   len;
 {
   memset((char *)dst, 0, len);
 }
-void bcopy(char *src, char *dst, int len)
+
+void bcopy(src, dst, len)
+  char *src;
+  char *dst;
+  int   len;
 {
   memmove((char *)dst, (char *)src, len);
 }
 #endif
+#endif
+
+#if !HAVE_STRDUP
+char*
+strdup(src)
+  char* src;
+{
+  int   len;
+  char* dst;
+
+  len = strlen(src) + 1;
+  dst = (char*) malloc(len);
+  bcopy(src, dst, len);
+
+  return(dst);
+}
+#endif
